(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    613434,      14240]
NotebookOptionsPosition[    602978,      13917]
NotebookOutlinePosition[    603315,      13932]
CellTagsIndexPosition[    603272,      13929]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Supplemental ",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 StyleBox["Mathematica",
  FontWeight->"Bold"],
 StyleBox[" Notebook for Joseph P. Dexter and Jeremy Gunawardena, \
\[OpenCurlyDoubleQuote]Dimerization and bifunctionality confer robustness to \
the isocitrate dehydrogenase regulatory system in ",
  FontWeight->"Bold",
  FontSlant->"Plain"],
 StyleBox["Escherichia coli",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\[CloseCurlyDoubleQuote] ",
  FontWeight->"Bold",
  FontSlant->"Plain"]
}], "Subtitle",
 CellChangeTimes->{{3.411233933774623*^9, 3.41123393949896*^9}, {
   3.41141701217196*^9, 3.411417044299642*^9}, 3.559068498574*^9, {
   3.562448220179*^9, 3.562448229223*^9}},
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 StyleBox["This Mathematica notebook is intended to provide details about the \
derivation of the key invariant, the numerical calculations with the \
invariant, and the analysis of alternative models that are omitted from the \
main paper. It should be read in parallel with the relevant sections of the \
paper. The notation is the same as in the main paper except that R is used in \
place of E to denote IDHKP and ",
  FontFamily->"Bitstream Vera Sans"],
 Cell[BoxData[
  SubscriptBox["x", "1"]],
  FontFamily->"Bitstream Vera Sans"],
 StyleBox["...",
  FontFamily->"Bitstream Vera Sans"],
 Cell[BoxData[
  SubscriptBox["x", "10"]],
  FontFamily->"Bitstream Vera Sans"],
 StyleBox[" are used to refer to the species in the network, as defined below \
and in Table 1 in the main paper. ",
  FontFamily->"Bitstream Vera Sans"]
}], "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.5624471648459997`*^9, 3.562447254615*^9}, {3.562447284741*^9, 
   3.562447296183*^9}, {3.5624481139449997`*^9, 3.562448116829*^9}, {
   3.562469183605*^9, 3.562469185186*^9}, 3.562470173847*^9},
 TextJustification->1.],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"R\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(1\\)]\\)\"\>"},
    {"\<\"Ioo\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(2\\)]\\)\"\>"},
    {"\<\"Iop\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(3\\)]\\)\"\>"},
    {"\<\"RIoo\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(4\\)]\\)\"\>"},
    {"\<\"RIpp\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(5\\)]\\)\"\>"},
    {"\<\"RIop\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(6\\)]\\)\"\>"},
    {"\<\"RIooR\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(7\\)]\\)\"\>"},
    {"\<\"RIopR\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(8\\)]\\)\"\>"},
    {"\<\"RIppR\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(9\\)]\\)\"\>"},
    {"\<\"Ipp\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(x\\), \\(10\\)]\\)\"\>"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{"Text"}}, "Rows" -> {{"Text"}}},
   GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.562448269125*^9, 3.562448279031*^9}}],

Cell[TextData[{
 StyleBox["The notebook requires custom ",
  FontFamily->"Bitstream Vera Sans"],
 StyleBox["Mathematica",
  FontFamily->"Bitstream Vera Sans",
  FontSlant->"Italic"],
 StyleBox[" functions which are provided in the accompanying file ",
  FontFamily->"Bitstream Vera Sans"],
 StyleBox["CRN-functions.m",
  FontFamily->"Courier"],
 StyleBox[", which is obtainable from our website at ",
  FontFamily->"Bitstream Vera Sans"],
 ButtonBox["http://vcp.med.harvard.edu/papers.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://vcp.med.harvard.edu/papers.html"], None},
  ButtonNote->"http://vcp.med.harvard.edu/papers.html"],
 StyleBox[". ",
  FontFamily->"Bitstream Vera Sans"]
}], "Text",
 CellChangeTimes->{{3.595035916638728*^9, 3.5950359293553467`*^9}, {
   3.5950359861721687`*^9, 3.595036035162273*^9}, {3.595036089775938*^9, 
   3.595036144810709*^9}, {3.595036189631421*^9, 3.5950362121043158`*^9}, {
   3.595036420407159*^9, 3.595036422771778*^9}, {3.595037909124859*^9, 
   3.595037915112247*^9}, 3.595038890665049*^9},
 TextJustification->1.],

Cell[CellGroupData[{

Cell["1) Reaction network for the IDH regulatory system", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9}],

Cell[TextData[{
 StyleBox["Ensure that the path to the directory containing the package ",
  FontFamily->"Bitstream Vera Sans",
  FontSize->12],
 StyleBox["CRN-functions.m",
  FontFamily->"Courier",
  FontSize->12],
 StyleBox[" is entered between the quotes in the next command: if the package \
is in \[OpenCurlyDoubleQuote]/home/user/foobar/\[CloseCurlyDoubleQuote], then \
SetDirectory[\[OpenCurlyDoubleQuote]/home/user/foobar\[CloseCurlyDoubleQuote]]\
. ",
  FontFamily->"Bitstream Vera Sans",
  FontSize->12]
}], "Text",
 CellChangeTimes->{{3.595035916638728*^9, 3.5950359293553467`*^9}, {
  3.5950359861721687`*^9, 3.595036035162273*^9}, {3.595036089775938*^9, 
  3.595036144810709*^9}, {3.595036189631421*^9, 3.5950362121043158`*^9}, {
  3.595036420407159*^9, 3.595036422771778*^9}, {3.595037909124859*^9, 
  3.595037915112247*^9}, {3.595038140169035*^9, 3.595038345962242*^9}, {
  3.5950384541087027`*^9, 3.595038457893907*^9}},
 TextJustification->1.],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.5950380731159353`*^9, 3.595038097875808*^9}, {
  3.5950383006390247`*^9, 3.595038303592305*^9}}],

Cell[BoxData[
 RowBox[{"<<", "CRN-functions.m"}]], "Input",
 CellChangeTimes->{{3.5601392319049997`*^9, 3.5601392405769997`*^9}, 
   3.560139284969*^9, {3.595036219541833*^9, 3.595036222404407*^9}, {
   3.5950364588553343`*^9, 3.595036479096046*^9}, {3.595036512207212*^9, 
   3.595036520837448*^9}, {3.595036677145247*^9, 3.5950366799079*^9}, {
   3.595036939834921*^9, 3.5950370052408743`*^9}, {3.5950370872845907`*^9, 
   3.595037088064609*^9}, {3.5950379372333813`*^9, 3.595037941307886*^9}, 
   3.595038069402892*^9, {3.59503810023947*^9, 3.595038115952104*^9}}],

Cell[CellGroupData[{

Cell["Reaction network for the model ", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
  3.559069487443*^9, 3.559069505935*^9}, {3.559075952868*^9, 
  3.559075958936*^9}}],

Cell[TextData[{
 "MakeCRN is a custom  Mathematica function to display a chemical reaction \
network, which is provided in the accompanying package ",
 StyleBox["CRN-functions.m",
  FontFamily->"Courier"],
 "."
}], "Text",
 CellChangeTimes->{{3.411417062002872*^9, 3.411417340835867*^9}, {
   3.411441616525317*^9, 3.411441622328849*^9}, {3.559068515785*^9, 
   3.559068518189*^9}, {3.559068560531*^9, 3.5590689223310003`*^9}, 
   3.559069016726*^9, {3.559069079335*^9, 3.559069249358*^9}, {
   3.559074064737*^9, 3.5590741259040003`*^9}, {3.560134752667*^9, 
   3.560134798727*^9}, {3.560142007744*^9, 3.5601420334779997`*^9}, {
   3.560285217422*^9, 3.560285268289*^9}, {3.5624471259849997`*^9, 
   3.562447138999*^9}, {3.5624483744300003`*^9, 3.562448377133*^9}, {
   3.5950379596671352`*^9, 3.595037973010894*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MakeCRN", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Ioo", " ", "+", " ", "R"}], ",", " ", "RIoo", ",", "  ", 
       "r"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIoo", ",", " ", 
       RowBox[{"R", " ", "+", " ", "Iop"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", " ", "+", " ", "Iop"}], ",", " ", "RIop", ",", " ", "r"}],
       "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIop", ",", " ", 
       RowBox[{"Ioo", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIop", ",", " ", 
       RowBox[{"Ipp", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", " ", "+", " ", "Ipp"}], ",", " ", "RIpp", ",", " ", "r"}],
       "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIpp", ",", " ", 
       RowBox[{"R", " ", "+", " ", "Iop"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RIop", " ", "+", " ", "R"}], ",", " ", "RIopR", ",", " ", 
       "r"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"RIopR", ",", " ", 
       RowBox[{"RIpp", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIopR", ",", " ", 
       RowBox[{"RIoo", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RIpp", " ", "+", " ", "R"}], ",", " ", "RIppR", ",", " ", 
       "r"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RIoo", " ", "+", " ", "R"}], ",", " ", "RIooR", ",", " ", 
       "r"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIppR", ",", " ", 
       RowBox[{"RIop", " ", "+", " ", "R"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"RIooR", ",", " ", 
       RowBox[{"RIop", " ", "+", "  ", "R"}]}], "}"}]}], "}"}], ",", " ", 
   "True", ",", " ", "True"}], "]"}]], "Input",
 CellChangeTimes->{3.560136977759*^9},
 FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Deficiency: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Deficiency: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.56013918281*^9, {3.560139313219*^9, 3.5601393363780003`*^9}, 
   3.560139375913*^9, 3.560217269861*^9, 3.560285287775*^9, 
   3.5603859753129997`*^9, 3.560386305663*^9, 3.5603865931870003`*^9, 
   3.560388057457*^9, 3.562470206523*^9, 3.595037097724139*^9, 
   3.595037950050989*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SteadyState: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ioo"}], " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
      RowBox[{"RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{"RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
      RowBox[{"Iop", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
      RowBox[{"RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "5"}]]}], "-", 
      RowBox[{"Ipp", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], "+", 
      RowBox[{"RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Ioo"}], " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]]}], "+", 
      RowBox[{"RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "1"}]]}], "+", 
      RowBox[{"RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"2", "\[Rule]", "3"}]]}], "-", 
      RowBox[{"Iop", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]]}], "+", 
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "1"}]]}], "+", 
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "3"}]]}], "+", 
      RowBox[{"RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"4", "\[Rule]", "5"}]]}], "-", 
      RowBox[{"Ipp", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], "+", 
      RowBox[{"RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "3"}]]}], "+", 
      RowBox[{"RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"6", "\[Rule]", "5"}]]}], "-", 
      RowBox[{"R", " ", "RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "8"}]]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "7"}]]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "9"}]]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "10"}]]}], "-", 
      RowBox[{"R", " ", "RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "11"}]]}], "-", 
      RowBox[{"R", " ", "RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"10", "\[Rule]", "12"}]]}], "+", 
      RowBox[{"RIppR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"11", "\[Rule]", "7"}]]}], "+", 
      RowBox[{"RIppR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"11", "\[Rule]", "9"}]]}], "+", 
      RowBox[{"RIooR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"12", "\[Rule]", "7"}]]}], "+", 
      RowBox[{"RIooR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"12", "\[Rule]", "10"}]]}]}], ",", 
     RowBox[{
      RowBox[{"Ioo", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"1", "\[Rule]", "2"}]]}], "-", 
      RowBox[{"RIoo", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"2", "\[Rule]", "3"}]]}], ")"}]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "10"}]]}], "-", 
      RowBox[{"R", " ", "RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"10", "\[Rule]", "12"}]]}], "+", 
      RowBox[{"RIooR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"12", "\[Rule]", "10"}]]}]}], ",", 
     RowBox[{
      RowBox[{"R", " ", "RIoo", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"10", "\[Rule]", "12"}]]}], "-", 
      RowBox[{"RIooR", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"12", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"12", "\[Rule]", "10"}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Iop", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"3", "\[Rule]", "4"}]]}], "-", 
      RowBox[{"RIop", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "1"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "3"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"4", "\[Rule]", "5"}]]}], ")"}]}], "-", 
      RowBox[{"R", " ", "RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "8"}]]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "7"}]]}], "+", 
      RowBox[{"RIppR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"11", "\[Rule]", "7"}]]}], "+", 
      RowBox[{"RIooR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"12", "\[Rule]", "7"}]]}]}], ",", 
     RowBox[{
      RowBox[{"R", " ", "RIop", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"7", "\[Rule]", "8"}]]}], "-", 
      RowBox[{"RIopR", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"8", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"8", "\[Rule]", "9"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"8", "\[Rule]", "10"}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Ipp", " ", "R", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"5", "\[Rule]", "6"}]]}], "-", 
      RowBox[{"RIpp", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "3"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"6", "\[Rule]", "5"}]]}], ")"}]}], "+", 
      RowBox[{"RIopR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"8", "\[Rule]", "9"}]]}], "-", 
      RowBox[{"R", " ", "RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "11"}]]}], "+", 
      RowBox[{"RIppR", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"11", "\[Rule]", "9"}]]}]}], ",", 
     RowBox[{
      RowBox[{"R", " ", "RIpp", " ", 
       SubscriptBox["\[Kappa]", 
        RowBox[{"9", "\[Rule]", "11"}]]}], "-", 
      RowBox[{"RIppR", " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Kappa]", 
          RowBox[{"11", "\[Rule]", "7"}]], "+", 
         SubscriptBox["\[Kappa]", 
          RowBox[{"11", "\[Rule]", "9"}]]}], ")"}]}]}]}], "}"}]}],
  SequenceForm[
  "SteadyState: ", {-$CellContext`Ioo $CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RIoo 
     Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 1], $CellContext`RIoo 
     Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`Iop $CellContext`R 
    Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RIpp 
     Subscript[CRN`\[Kappa], 6 -> 3], $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 5] - $CellContext`Ipp $CellContext`R 
    Subscript[CRN`\[Kappa], 5 -> 6] + $CellContext`RIpp 
     Subscript[CRN`\[Kappa], 6 -> 5], -$CellContext`Ioo $CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] + $CellContext`RIoo 
     Subscript[CRN`\[Kappa], 2 -> 1] + $CellContext`RIoo 
     Subscript[CRN`\[Kappa], 2 -> 3] - $CellContext`Iop $CellContext`R 
    Subscript[CRN`\[Kappa], 3 -> 4] + $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 1] + $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 3] + $CellContext`RIop 
     Subscript[CRN`\[Kappa], 4 -> 5] - $CellContext`Ipp $CellContext`R 
    Subscript[CRN`\[Kappa], 5 -> 6] + $CellContext`RIpp 
     Subscript[CRN`\[Kappa], 6 -> 3] + $CellContext`RIpp 
     Subscript[CRN`\[Kappa], 6 -> 5] - $CellContext`R $CellContext`RIop 
    Subscript[CRN`\[Kappa], 7 -> 8] + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 7] + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 9] + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 10] - $CellContext`R $CellContext`RIpp 
    Subscript[CRN`\[Kappa], 9 -> 11] - $CellContext`R $CellContext`RIoo 
    Subscript[CRN`\[Kappa], 10 -> 12] + $CellContext`RIppR 
     Subscript[CRN`\[Kappa], 11 -> 7] + $CellContext`RIppR 
     Subscript[CRN`\[Kappa], 11 -> 9] + $CellContext`RIooR 
     Subscript[CRN`\[Kappa], 12 -> 7] + $CellContext`RIooR 
     Subscript[CRN`\[Kappa], 12 -> 10], $CellContext`Ioo $CellContext`R 
     Subscript[CRN`\[Kappa], 1 -> 2] - $CellContext`RIoo (
     Subscript[CRN`\[Kappa], 2 -> 1] + 
     Subscript[CRN`\[Kappa], 2 -> 3]) + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 10] - $CellContext`R $CellContext`RIoo 
    Subscript[CRN`\[Kappa], 10 -> 12] + $CellContext`RIooR 
     Subscript[CRN`\[Kappa], 12 -> 10], $CellContext`R $CellContext`RIoo 
     Subscript[CRN`\[Kappa], 10 -> 12] - $CellContext`RIooR (
     Subscript[CRN`\[Kappa], 12 -> 7] + 
     Subscript[CRN`\[Kappa], 12 -> 10]), $CellContext`Iop $CellContext`R 
     Subscript[CRN`\[Kappa], 3 -> 4] - $CellContext`RIop (
     Subscript[CRN`\[Kappa], 4 -> 1] + Subscript[CRN`\[Kappa], 4 -> 3] + 
     Subscript[CRN`\[Kappa], 4 -> 5]) - $CellContext`R $CellContext`RIop 
    Subscript[CRN`\[Kappa], 7 -> 8] + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 7] + $CellContext`RIppR 
     Subscript[CRN`\[Kappa], 11 -> 7] + $CellContext`RIooR 
     Subscript[CRN`\[Kappa], 12 -> 7], $CellContext`R $CellContext`RIop 
     Subscript[CRN`\[Kappa], 7 -> 8] - $CellContext`RIopR (
     Subscript[CRN`\[Kappa], 8 -> 7] + Subscript[CRN`\[Kappa], 8 -> 9] + 
     Subscript[CRN`\[Kappa], 8 -> 10]), $CellContext`Ipp $CellContext`R 
     Subscript[CRN`\[Kappa], 5 -> 6] - $CellContext`RIpp (
     Subscript[CRN`\[Kappa], 6 -> 3] + 
     Subscript[CRN`\[Kappa], 6 -> 5]) + $CellContext`RIopR 
     Subscript[CRN`\[Kappa], 8 -> 9] - $CellContext`R $CellContext`RIpp 
    Subscript[CRN`\[Kappa], 9 -> 11] + $CellContext`RIppR 
     Subscript[CRN`\[Kappa], 11 -> 9], $CellContext`R $CellContext`RIpp 
     Subscript[CRN`\[Kappa], 9 -> 11] - $CellContext`RIppR (
     Subscript[CRN`\[Kappa], 11 -> 7] + Subscript[CRN`\[Kappa], 11 -> 9])}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.56013918281*^9, {3.560139313219*^9, 3.5601393363780003`*^9}, 
   3.560139375913*^9, 3.560217269861*^9, 3.560285287775*^9, 
   3.5603859753129997`*^9, 3.560386305663*^9, 3.5603865931870003`*^9, 
   3.560388057457*^9, 3.562470206523*^9, 3.595037097724139*^9, 
   3.595037950088628*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1Vnk4lO33Z54xKiprVNqk7FqokOZ+tKBIXtGqEomQQknhjchWJNmF3kpN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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.030338254802146226`, 0.7}}], 
      ArrowBox[{1, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27,
        28, 2}], 
      ArrowBox[{2, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43,
        44, 1}], ArrowBox[{2, 3}], 
      ArrowBox[{3, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
        60, 4}], 
      ArrowBox[{4, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75,
        76, 3}], ArrowBox[{4, 1}], ArrowBox[{4, 5}], 
      ArrowBox[{5, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
        92, 6}], 
      ArrowBox[{6, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 
       106, 107, 108, 5}], ArrowBox[{6, 3}], 
      ArrowBox[{7, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
        121, 122, 123, 124, 8}], 
      ArrowBox[{8, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
        137, 138, 139, 140, 7}], ArrowBox[{8, 9}], ArrowBox[{8, 10}], 
      ArrowBox[{9, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
        153, 154, 155, 156, 11}], 
      ArrowBox[{10, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 
       168, 169, 170, 171, 172, 12}], 
      ArrowBox[{11, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 
       184, 185, 186, 187, 188, 9}], ArrowBox[{11, 7}], 
      ArrowBox[{12, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 
       200, 201, 202, 203, 204, 10}], ArrowBox[{12, 7}]}, {InsetBox[
       FrameBox[
        RowBox[{"Ioo", "+", "R", "-", "1"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox[
        RowBox[{"RIoo", "-", "2"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox[
        RowBox[{"Iop", "+", "R", "-", "3"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox[
        RowBox[{"RIop", "-", "4"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox[
        RowBox[{"Ipp", "+", "R", "-", "5"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5], InsetBox[
       FrameBox[
        RowBox[{"RIpp", "-", "6"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 6], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "RIop", "-", "7"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 7], InsetBox[
       FrameBox[
        RowBox[{"RIopR", "-", "8"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 8], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "RIpp", "-", "9"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 9], InsetBox[
       FrameBox[
        RowBox[{"R", "+", "RIoo", "-", "10"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 10], InsetBox[
       FrameBox[
        RowBox[{"RIppR", "-", "11"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 11], InsetBox[
       FrameBox[
        RowBox[{"RIooR", "-", "12"}],
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 12]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0.3822892512419669, -3.033133680476734}, {
     0.38325991222719313`, -2.1208989360329267`}, {
     1.4344306658151031`, -2.1003225159082266`}, {
     1.4340449651133367`, -3.0540618909409982`}, {
     2.4865441928347196`, -3.033125793234369}, {
     2.486210220071008, -2.1213578970086115`}, {
     1.4350248087078181`, -0.382289251241967}, {
     1.4358584155427725`, -1.3357440134242928`}, {
     2.487308192305589, -1.3144472791652944`}, {
     0.3832742901510522, -1.3150929613426743`}, {
     2.4864109866974298`, -0.4028976695086892}, {
     0.3822892512419669, -0.40344525982623625`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.5624702069449997`*^9, 3.595037097894218*^9, 
  3.5950379501551733`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2) Derivation of the key invariant (Eq. (2) in the main paper)\
\>", "Section",
 CellChangeTimes->{{3.411417401057521*^9, 3.411417428220966*^9}, 
   3.5590689641359997`*^9, {3.559069396748*^9, 3.559069396888*^9}, {
   3.559069462065*^9, 3.559069474888*^9}, {3.562470462124*^9, 
   3.562470463526*^9}}],

Cell[CellGroupData[{

Cell["Replacement rules", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
  3.559069487443*^9, 3.559069505935*^9}, {3.55999592375*^9, 
  3.559995932374*^9}}],

Cell["\<\
For later use, we introduce the following replacement rule to assign \
numerical values to the rate constants. Parameter values are from Table 2 in \
the main text.    \
\>", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.559995944648*^9, 
  3.559995969377*^9}, {3.560024179571*^9, 3.560024189131*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"parameterClasses", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["k", "1"], "\[Rule]", 
       SubscriptBox["k", "on"]}], ",", 
      RowBox[{
       SubscriptBox["k", "2"], "\[Rule]", 
       SubscriptBox["k", "off"]}], ",", 
      RowBox[{
       SubscriptBox["k", "3"], "\[Rule]", 
       SubscriptBox["k", "cat"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "4"], "\[Rule]", 
       SubscriptBox["k", "on"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "5"], "\[Rule]", 
       SubscriptBox["k", "off"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "6"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "7"], "\[Rule]", 
       SubscriptBox["k", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "8"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "on"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "9"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "off"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "10"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "11"], "\[Rule]", 
       SubscriptBox["k", "on"]}], ",", 
      RowBox[{
       SubscriptBox["k", "12"], "\[Rule]", 
       SubscriptBox["k", "off"]}], ",", 
      RowBox[{
       SubscriptBox["k", "13"], "\[Rule]", 
       SubscriptBox["k", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "14"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "15"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "on"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "16"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "off"]}], ",", " ", 
      RowBox[{
       SubscriptBox["k", "17"], "\[Rule]", 
       SubscriptBox["k", "on"]}], ",", 
      RowBox[{
       SubscriptBox["k", "18"], " ", "\[Rule]", 
       SubscriptBox["k", "off"]}], ",", 
      RowBox[{
       SubscriptBox["k", "19"], "\[Rule]", 
       SubscriptBox["\[Kappa]", "cat"]}], ",", 
      RowBox[{
       SubscriptBox["k", "20"], "\[Rule]", 
       SubscriptBox["k", "cat"]}]}], "}"}]}], ";"}], "         "}]], "Input",
 CellChangeTimes->{{3.560021690951*^9, 3.56002203135*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"numericalValues", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "on"], "\[Rule]", 
      RowBox[{"1", "*", 
       RowBox[{"10", "^", "8"}]}]}], ",", " ", 
     RowBox[{
      SubscriptBox["k", "off"], "\[Rule]", "23"}], ",", " ", 
     RowBox[{
      SubscriptBox["k", "cat"], "\[Rule]", 
      RowBox[{"9.8", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "2"}]}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Kappa]", "on"], "\[Rule]", 
      RowBox[{"1", "*", 
       RowBox[{"10", "^", "8"}]}]}], " ", ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", "off"], "\[Rule]", "40"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[Kappa]", "cat"], "\[Rule]", 
      RowBox[{"6.5", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "2"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.56002207783*^9, 3.560022098167*^9}, {
  3.5600241097209997`*^9, 3.560024172402*^9}}],

Cell[TextData[{
 "Replacement rule for ",
 Cell[BoxData[
  SubscriptBox["x", "3"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]]],
 " at the midpoint in the grid of values considered. "
}], "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590722689969997`*^9, 
  3.559072344686*^9}, {3.559072495887*^9, 3.559072508594*^9}, {
  3.560026746849*^9, 3.5600267478719997`*^9}, {3.560026887901*^9, 
  3.560026918267*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xValues", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "3"], "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{
      SubscriptBox["x", "10"], "\[Rule]", "17.5"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5600269288570004`*^9, 3.560026987808*^9}, {
  3.560027517363*^9, 3.560027520217*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Groebner basis calculation on the polynomial system describing the reaction \
network\
\>", "Subsection",
 CellChangeTimes->{{3.411441668282763*^9, 3.411441699457004*^9}, {
  3.559069487443*^9, 3.559069505935*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["f", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["x", "2"]}], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "2"]}], "+", 
    RowBox[{
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "3"]}], "-", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "4"]}], "+", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "6"]}], "+", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "5"]}], "+", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "7"]}], "-", 
    RowBox[{
     SubscriptBox["x", "10"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "8"]}], "+", 
    RowBox[{
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "10"]}], "+", 
    RowBox[{
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "9"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "11"]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "12"]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "13"]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "14"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "15"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "17"]}], "+", 
    RowBox[{
     SubscriptBox["x", "9"], " ", 
     SubscriptBox["k", "19"]}], "+", 
    RowBox[{
     SubscriptBox["x", "9"], " ", 
     SubscriptBox["k", "16"]}], "+", 
    RowBox[{
     SubscriptBox["x", "7"], " ", 
     SubscriptBox["k", "20"]}], "+", 
    RowBox[{
     SubscriptBox["x", "7"], " ", 
     SubscriptBox["k", "18"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "2"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["x", "2"]}], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "2"]}], "+", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "6"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "3"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "3"]}], "-", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "4"]}], "+", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "5"]}], "+", 
    RowBox[{
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "10"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "4"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "1"]}], "-", 
    RowBox[{
     SubscriptBox["x", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "2"], "+", 
       SubscriptBox["k", "3"]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "14"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "17"]}], "+", 
    RowBox[{
     SubscriptBox["x", "7"], " ", 
     SubscriptBox["k", "18"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "5"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "10"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "8"]}], "-", 
    RowBox[{
     SubscriptBox["x", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "10"], "+", 
       SubscriptBox["k", "9"]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "13"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "15"]}], "+", 
    RowBox[{
     SubscriptBox["x", "9"], " ", 
     SubscriptBox["k", "16"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "6"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "4"]}], "-", 
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "6"], "+", 
       SubscriptBox["k", "5"], "+", 
       SubscriptBox["k", "7"]}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "11"]}], "+", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     SubscriptBox["k", "12"]}], "+", 
    RowBox[{
     SubscriptBox["x", "9"], " ", 
     SubscriptBox["k", "19"]}], "+", 
    RowBox[{
     SubscriptBox["x", "7"], " ", 
     SubscriptBox["k", "20"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "7"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "4"], " ", 
     SubscriptBox["k", "17"]}], "-", 
    RowBox[{
     SubscriptBox["x", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "20"], "+", 
       SubscriptBox["k", "18"]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "8"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "11"]}], "-", 
    RowBox[{
     SubscriptBox["x", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "12"], "+", 
       SubscriptBox["k", "13"], "+", 
       SubscriptBox["k", "14"]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "9"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "15"]}], "-", 
    RowBox[{
     SubscriptBox["x", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "19"], "+", 
       SubscriptBox["k", "16"]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "10"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "6"], " ", 
     SubscriptBox["k", "7"]}], "-", 
    RowBox[{
     SubscriptBox["x", "10"], " ", 
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["k", "8"]}], "+", 
    RowBox[{
     SubscriptBox["x", "5"], " ", 
     SubscriptBox["k", "9"]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5601236948269997`*^9, 3.560123769255*^9}, {
  3.5601238029440002`*^9, 3.560123866949*^9}, {3.560124015053*^9, 
  3.56012406175*^9}, {3.560142084358*^9, 3.56014208684*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", " ", 
    RowBox[{
     SubscriptBox["x", "4"], ",", " ", 
     SubscriptBox["x", "5"], ",", 
     SubscriptBox["x", "6"], ",", " ", 
     SubscriptBox["x", "7"], ",", " ", 
     SubscriptBox["x", "8"], ",", " ", 
     SubscriptBox["x", "9"], ",", " ", 
     SubscriptBox["x", "1"], ",", " ", 
     SubscriptBox["x", "3"], ",", " ", 
     SubscriptBox["x", "10"], ",", 
     SubscriptBox["x", "2"]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "10"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Part", "[", 
     RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
  3.559952374724*^9, 3.559952382855*^9}, {3.560726035016549*^9, 
  3.5607260672085495`*^9}}],

Cell["The Groebner basis has nine terms. ", "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
  3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
  3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
  3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
  3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.5600334395290003`*^9, 3.560124115271*^9, 
  3.560139380023*^9, 3.560217275593*^9, 3.560285314337*^9, 3.560385980043*^9, 
  3.560386310766*^9, 3.5603865976359997`*^9, 3.5603880619849997`*^9}]
}, Open  ]],

Cell[TextData[{
 "There is no invariant in terms of just ",
 Cell[BoxData[
  SubscriptBox["x", "2"]],
  CellChangeTimes->{{3.5487820496940002`*^9, 3.5487821674519997`*^9}, {
    3.5487822316949997`*^9, 3.548782289854*^9}, {3.549277748284*^9, 
    3.549277816869*^9}, {3.54927835302*^9, 3.5492783537539997`*^9}, {
    3.5492783979049997`*^9, 3.549278636573*^9}, 3.549290259198*^9, {
    3.5518182279276*^9, 3.5518182281496*^9}, {3.5589282498644*^9, 
    3.5589282714863997`*^9}}],
 " and the rate constants. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
   3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
   3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
   3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
   3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
   3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
   3.56002454641*^9}, {3.560024843624*^9, 3.560024848526*^9}, 
   3.5600252019189997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "1", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "2", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "3", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "4", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "5", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "6", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "7", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "8", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Variables", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gr", "[", "9", "]"}], "/.", "parameterClasses"}], "/.", 
   "numericalValues"}], "]"}]}], "Input",
 CellChangeTimes->{{3.55997124398*^9, 3.559971374855*^9}, {3.560024477741*^9, 
  3.5600245167139997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.5603880695150003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388072907*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388075566*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "9"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388076201*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "8"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388076376*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "7"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.5603880765550003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "6"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388076605*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "5"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388076606*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["x", "1"], ",", 
   SubscriptBox["x", "2"], ",", 
   SubscriptBox["x", "3"], ",", 
   SubscriptBox["x", "4"], ",", 
   SubscriptBox["x", "10"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559971255722*^9, 3.559971282999*^9}, {
   3.5599713176870003`*^9, 3.559971336843*^9}, 3.5599713753710003`*^9, 
   3.559971599001*^9, 3.560024465792*^9, {3.560024499259*^9, 
   3.5600245171949997`*^9}, 3.5600334511610003`*^9, 3.56012412367*^9, 
   3.560139386543*^9, 3.5602172846029997`*^9, 3.560385987278*^9, 
   3.560386318276*^9, 3.5603866049379997`*^9, 3.560388076626*^9}]
}, Open  ]],

Cell[TextData[{
 "The first three terms contain ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "1"], ",", " ", 
   SubscriptBox["x", "2"], ",", " ", 
   SubscriptBox["x", "3"]}]],
  CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
   3.559952374724*^9, 3.559952382855*^9}}],
 ",  and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]],
  CellChangeTimes->{{3.5590695712460003`*^9, 3.559069629409*^9}, {
   3.559952374724*^9, 3.559952382855*^9}}],
 ", but ",
 Cell[BoxData[
  SubscriptBox["x", "1"]],
  CellChangeTimes->{3.560024659615*^9, 3.560024804657*^9}],
 " can only be factored out of the first term. As such, we focus on this \
invariant for the rest of the notebook. "
}], "Text",
 CellChangeTimes->{{3.411441754619909*^9, 3.411441846164827*^9}, {
  3.411441886549143*^9, 3.411441971328922*^9}, {3.4114881851551*^9, 
  3.41148829480333*^9}, {3.411488348240992*^9, 3.411488362302175*^9}, {
  3.559068991917*^9, 3.5590689995810003`*^9}, {3.559069671023*^9, 
  3.55906971698*^9}, {3.559069790791*^9, 3.559069793774*^9}, {
  3.560024314175*^9, 3.560024455422*^9}, {3.560024540623*^9, 
  3.56002454641*^9}, {3.560024843624*^9, 3.5600249139630003`*^9}, {
  3.560025205851*^9, 3.560025219457*^9}, {3.560142121659*^9, 
  3.5601421252139997`*^9}, {3.560217058002*^9, 3.560217058276*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], ",", 
   SubscriptBox["x", "1"], ",", "Simplify"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"gr", "[", "2", "]"}], ",", 
   SubscriptBox["x", "1"], ",", "Simplify"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"gr", "[", "3", "]"}], ",", 
   SubscriptBox["x", "1"], ",", "Simplify"}], "]"}]}], "Input",
 CellChangeTimes->{{3.560285579505*^9, 3.560285670073*^9}, {3.560285888505*^9,
   3.560285914833*^9}, {3.5602860874700003`*^9, 3.56028613233*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["x", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["k", "1", "2"]}], " ", 
     SubscriptBox["k", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "9"], "+", 
          SubscriptBox["k", "10"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "5"]}], " ", 
           SubscriptBox["k", "9"]}], "+", 
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           SubscriptBox["k", "10"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "12"], "+", 
          SubscriptBox["k", "13"], "+", 
          SubscriptBox["k", "14"]}], ")"}], " ", 
        SubscriptBox["k", "17"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "16"], "+", 
          SubscriptBox["k", "19"]}], ")"}], " ", 
        SubscriptBox["k", "20"]}], "+", 
       RowBox[{
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "5"], " ", 
           SubscriptBox["k", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "6"], " ", 
           SubscriptBox["k", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubsuperscriptBox["k", "9", "2"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "14"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "10"], " ", 
              SubscriptBox["k", "11"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "18"], "+", 
          SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["x", "2", "2"]}], "+", 
    RowBox[{
     SubscriptBox["k", "1"], " ", 
     SubscriptBox["k", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "3"], " ", 
        SubscriptBox["k", "6"], " ", 
        SubscriptBox["k", "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "7"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{"2", " ", 
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "14"]}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "3"]}], "+", 
    RowBox[{
     SubscriptBox["k", "2"], " ", 
     SubsuperscriptBox["k", "4", "2"], " ", 
     SubscriptBox["k", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["k", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "7"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           SubscriptBox["k", "11"], " ", 
           SubscriptBox["k", "14"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "18"], "+", 
          SubscriptBox["k", "20"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "-", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["x", "3", "2"]}], "+", 
    RowBox[{
     SubscriptBox["k", "1"], " ", 
     SubscriptBox["k", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "3"], " ", 
        SubscriptBox["k", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "10"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "9"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["k", "10"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "-", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    SubscriptBox["k", "6"]}], ")"}]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "5"], "+", 
              SubscriptBox["k", "7"]}], ")"}]}], " ", 
           SubscriptBox["k", "10"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["k", "5", "2"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "-", 
             RowBox[{
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "14"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}]}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "-", 
                RowBox[{
                 SubscriptBox["k", "6"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "13"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["k", "7"]}], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "6"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "-", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["x", "10"]}], "+", 
    RowBox[{
     SubscriptBox["k", "4"], " ", 
     SubscriptBox["k", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "10"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["k", "9"]}], "+", 
                SubscriptBox["k", "10"]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["k", "11"], " ", 
           SubscriptBox["k", "14"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}],
          ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "18"], "+", 
          SubscriptBox["k", "20"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["k", "3"], " ", 
        SubsuperscriptBox["k", "6", "2"], " ", 
        SubscriptBox["k", "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "12"], "+", 
          SubscriptBox["k", "13"], "+", 
          SubscriptBox["k", "14"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "10"]}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubscriptBox["k", "15"], " ", 
           SubscriptBox["k", "19"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["k", "2"], " ", 
        SubscriptBox["k", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "10"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["k", "9"]}], "+", 
                SubscriptBox["k", "10"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "-", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "5"], "-", 
                   SubscriptBox["k", "6"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "13"]}], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["x", "10"]}], "+", 
    RowBox[{
     SubsuperscriptBox["k", "8", "2"], " ", 
     SubscriptBox["k", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["k", "2", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "5"], "+", 
              SubscriptBox["k", "7"]}], ")"}]}], " ", 
           SubscriptBox["k", "10"], " ", 
           SubscriptBox["k", "11"], " ", 
           SubscriptBox["k", "14"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "10"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "13"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "18"], "+", 
          SubscriptBox["k", "20"]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "3"], " ", 
        SubsuperscriptBox["k", "6", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "12"], "+", 
          SubscriptBox["k", "13"], "+", 
          SubscriptBox["k", "14"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "10"]}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubscriptBox["k", "15"], " ", 
           SubscriptBox["k", "19"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "2"], " ", 
        SubscriptBox["k", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "5"], "+", 
             SubscriptBox["k", "7"]}], ")"}], " ", 
           SubscriptBox["k", "10"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "-", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "5"], "-", 
                SubscriptBox["k", "6"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"]}], "+", 
             RowBox[{
              SubscriptBox["k", "10"], " ", 
              SubscriptBox["k", "11"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     SubsuperscriptBox["x", "10", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5602855825690002`*^9, 3.5602856705290003`*^9}, {
   3.560285898676*^9, 3.560285905949*^9}, 3.5602859457320004`*^9, {
   3.560286103458*^9, 3.560286132733*^9}, 3.560385994593*^9, 
   3.560386325852*^9, 3.560386612295*^9, 3.5603880766949997`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["k", "3"]}], " ", 
      SubscriptBox["k", "6"], " ", 
      SubscriptBox["k", "9"]}], "+", 
     RowBox[{
      SubscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "5"], " ", 
         SubscriptBox["k", "9"]}], "-", 
        RowBox[{
         SubscriptBox["k", "7"], " ", 
         SubscriptBox["k", "10"]}]}], ")"}]}]}], ")"}], " ", 
   SubsuperscriptBox["x", "1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["k", "1"]}], " ", 
      SubscriptBox["k", "17"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "7"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "15"], " ", 
         SubscriptBox["k", "19"]}], "+", 
        RowBox[{
         SubscriptBox["k", "9"], " ", 
         SubscriptBox["k", "11"], " ", 
         SubscriptBox["k", "13"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["k", "20"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["k", "8"], " ", 
      SubscriptBox["k", "15"], " ", 
      SubscriptBox["k", "19"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         SubscriptBox["k", "20"]}], "+", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         SubscriptBox["k", "11"], " ", 
         SubscriptBox["k", "14"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "10"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "1"], " ", 
      SubscriptBox["k", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "6"], " ", 
         SubscriptBox["k", "7"], " ", 
         SubscriptBox["k", "9"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "9"], "+", 
           SubscriptBox["k", "10"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"]}], "-", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "5"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               SubscriptBox["k", "10"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubsuperscriptBox["k", "9", "2"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "14"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["k", "2"], " ", 
      SubscriptBox["k", "4"], " ", 
      SubscriptBox["k", "9"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "7"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "7"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "+", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "3"]}], "-", 
     RowBox[{
      SubscriptBox["k", "8"], " ", 
      SubscriptBox["k", "10"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         SubsuperscriptBox["k", "6", "2"], " ", 
         SubscriptBox["k", "9"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"]}], "+", 
        RowBox[{
         SubsuperscriptBox["k", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["k", "5"], "+", 
               SubscriptBox["k", "7"]}], ")"}]}], " ", 
            SubscriptBox["k", "9"], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["k", "5"], "+", 
               SubscriptBox["k", "7"]}], ")"}]}], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "+", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "10"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5602855825690002`*^9, 3.5602856705290003`*^9}, {
   3.560285898676*^9, 3.560285905949*^9}, 3.5602859457320004`*^9, {
   3.560286103458*^9, 3.560286132733*^9}, 3.560385994593*^9, 
   3.560386325852*^9, 3.560386612295*^9, 3.560388076976*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["k", "3"]}], " ", 
      SubscriptBox["k", "6"], " ", 
      SubscriptBox["k", "9"]}], "+", 
     RowBox[{
      SubscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "5"], " ", 
         SubscriptBox["k", "9"]}], "-", 
        RowBox[{
         SubscriptBox["k", "7"], " ", 
         SubscriptBox["k", "10"]}]}], ")"}]}]}], ")"}], " ", 
   SubsuperscriptBox["x", "1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["k", "1"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "5"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "15"], " ", 
            SubscriptBox["k", "19"]}], "+", 
           RowBox[{
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "13"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["k", "20"]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         SubscriptBox["k", "11"], " ", 
         SubscriptBox["k", "14"], " ", 
         SubscriptBox["k", "15"], " ", 
         SubscriptBox["k", "19"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["k", "4"], " ", 
      SubscriptBox["k", "15"], " ", 
      SubscriptBox["k", "19"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         SubscriptBox["k", "20"]}], "+", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         SubscriptBox["k", "11"], " ", 
         SubscriptBox["k", "14"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "3"]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["x", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "1"], " ", 
      SubscriptBox["k", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["k", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox["k", "5", "2"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "15"], " ", 
            SubscriptBox["k", "19"]}], "-", 
           RowBox[{
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["k", "11"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["k", "6"]}], " ", 
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "13"]}], "+", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["k", "9"], " ", 
                  SubscriptBox["k", "14"]}], "+", 
                 RowBox[{
                  SubscriptBox["k", "10"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}]}]}], ")"}]}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "5"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["k", "7"]}], " ", 
               SubscriptBox["k", "10"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["k", "6"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                  SubscriptBox["k", "15"], " ", 
                  SubscriptBox["k", "19"]}], "+", 
                 RowBox[{
                  SubscriptBox["k", "10"], " ", 
                  SubscriptBox["k", "11"], " ", 
                  SubscriptBox["k", "13"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            SubscriptBox["k", "10"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "+", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "5"], " ", 
               SubscriptBox["k", "9"]}], "+", 
              RowBox[{
               SubscriptBox["k", "6"], " ", 
               SubscriptBox["k", "9"]}], "-", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               SubscriptBox["k", "10"]}]}], ")"}], " ", 
            SubscriptBox["k", "15"], " ", 
            SubscriptBox["k", "19"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{
      SubscriptBox["k", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["k", "3", "2"]}], " ", 
         SubsuperscriptBox["k", "6", "2"], " ", 
         SubscriptBox["k", "9"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "15"], " ", 
         SubscriptBox["k", "19"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["k", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "7"]}], " ", 
            SubscriptBox["k", "10"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "-", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            SubscriptBox["k", "10"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "-", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "-", 
                 SubscriptBox["k", "6"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "3"]}], "+", 
     RowBox[{
      SubscriptBox["k", "8"], " ", 
      SubscriptBox["k", "10"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["k", "2", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["k", "5"], "+", 
               SubscriptBox["k", "7"]}], ")"}]}], " ", 
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         SubsuperscriptBox["k", "6", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "10"]}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "+", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            SubscriptBox["k", "15"], " ", 
            SubscriptBox["k", "19"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "2"], " ", 
         SubscriptBox["k", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "5"], "+", 
              SubscriptBox["k", "7"]}], ")"}], " ", 
            SubscriptBox["k", "10"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "17"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}], " ", 
            SubscriptBox["k", "20"]}], "-", 
           RowBox[{
            SubscriptBox["k", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "-", 
                 SubscriptBox["k", "6"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "18"], "+", 
              SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "10"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5602855825690002`*^9, 3.5602856705290003`*^9}, {
   3.560285898676*^9, 3.560285905949*^9}, 3.5602859457320004`*^9, {
   3.560286103458*^9, 3.560286132733*^9}, 3.560385994593*^9, 
   3.560386325852*^9, 3.560386612295*^9, 3.560388077525*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Eq. (2) is obtained by dividing the first term of the Groebner basis by ",
 Cell[BoxData[
  SubscriptBox["x", "1"]], "Input",
  CellChangeTimes->{{3.5487820496940002`*^9, 3.5487821674519997`*^9}, {
    3.5487822316949997`*^9, 3.548782289854*^9}, {3.549277748284*^9, 
    3.549277816869*^9}, {3.54927835302*^9, 3.5492783537539997`*^9}, {
    3.5492783979049997`*^9, 3.549278636573*^9}, 3.549290259198*^9, {
    3.5518182279276*^9, 3.5518182281496*^9}, {3.5589282498644*^9, 
    3.5589282714863997`*^9}}],
 " "
}], "Subsection",
 CellChangeTimes->{{3.411442604891555*^9, 3.411442633440817*^9}, {
  3.411443210320794*^9, 3.411443218877493*^9}, {3.413475719000139*^9, 
  3.413475721720263*^9}, {3.559069798248*^9, 3.559069828189*^9}, {
  3.5590717401*^9, 3.559071743994*^9}, {3.56247047005*^9, 3.562470471293*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gr", "[", "1", "]"}], "/", 
   SubscriptBox["x", "1"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["k", "1", "2"]}], " ", 
   SubscriptBox["k", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "7"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "9"], "+", 
        SubscriptBox["k", "10"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["k", "5"]}], " ", 
         SubscriptBox["k", "9"]}], "+", 
        RowBox[{
         SubscriptBox["k", "7"], " ", 
         SubscriptBox["k", "10"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "12"], "+", 
        SubscriptBox["k", "13"], "+", 
        SubscriptBox["k", "14"]}], ")"}], " ", 
      SubscriptBox["k", "17"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "16"], "+", 
        SubscriptBox["k", "19"]}], ")"}], " ", 
      SubscriptBox["k", "20"]}], "+", 
     RowBox[{
      SubscriptBox["k", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "9"], " ", 
         SubscriptBox["k", "11"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "+", 
                 SubscriptBox["k", "6"]}], ")"}], " ", 
               SubscriptBox["k", "9"]}], "-", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               SubscriptBox["k", "10"]}]}], ")"}], " ", 
            SubscriptBox["k", "13"]}], "-", 
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["k", "14"]}]}], ")"}], " ", 
         SubscriptBox["k", "16"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "9"], " ", 
            SubscriptBox["k", "11"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    SubscriptBox["k", "6"]}], ")"}], " ", 
                  SubscriptBox["k", "9"]}], "-", 
                 RowBox[{
                  SubscriptBox["k", "7"], " ", 
                  SubscriptBox["k", "10"]}]}], ")"}], " ", 
               SubscriptBox["k", "13"]}], "-", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "9"], "+", 
                 SubscriptBox["k", "10"]}], ")"}], " ", 
               SubscriptBox["k", "14"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "+", 
                 SubscriptBox["k", "6"]}], ")"}], " ", 
               SubscriptBox["k", "9"]}], "-", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               SubscriptBox["k", "10"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "12"], "+", 
              SubscriptBox["k", "13"], "+", 
              SubscriptBox["k", "14"]}], ")"}], " ", 
            SubscriptBox["k", "15"]}]}], ")"}], " ", 
         SubscriptBox["k", "19"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "18"], "+", 
        SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
   SubsuperscriptBox["x", "2", "2"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "4"], " ", 
      SubscriptBox["k", "9"], " ", 
      SubscriptBox["x", "3"]}], "-", 
     RowBox[{
      SubscriptBox["k", "8"], " ", 
      SubscriptBox["k", "10"], " ", 
      SubscriptBox["x", "10"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "3"], " ", 
      SubsuperscriptBox["k", "6", "2"], " ", 
      SubscriptBox["k", "8"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "12"], "+", 
        SubscriptBox["k", "13"], "+", 
        SubscriptBox["k", "14"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["k", "10"]}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         SubscriptBox["k", "15"], " ", 
         SubscriptBox["k", "19"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["x", "10"]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", "2", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "18"], "+", 
        SubscriptBox["k", "20"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "7"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["x", "3"]}], "-", 
        RowBox[{
         SubscriptBox["k", "8"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["k", "5"], "+", 
               SubscriptBox["k", "7"]}], ")"}]}], " ", 
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["k", "11"], " ", 
            SubscriptBox["k", "14"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "16"], "+", 
              SubscriptBox["k", "19"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["k", "6"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["x", "10"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["k", "2"], " ", 
      SubscriptBox["k", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "4"]}], " ", 
            SubscriptBox["k", "7"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "5"], "+", 
              SubscriptBox["k", "7"]}], ")"}], " ", 
            SubscriptBox["k", "8"], " ", 
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "-", 
           RowBox[{
            SubscriptBox["k", "8"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "-", 
                 SubscriptBox["k", "6"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "10"], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["k", "1"], " ", 
   SubscriptBox["x", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "5"], " ", 
            SubscriptBox["k", "9"]}], "-", 
           RowBox[{
            SubscriptBox["k", "7"], " ", 
            SubscriptBox["k", "10"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "12"], "+", 
           SubscriptBox["k", "13"], "+", 
           SubscriptBox["k", "14"]}], ")"}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["k", "4"]}], " ", 
            SubscriptBox["k", "7"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "5"], "+", 
              SubscriptBox["k", "7"]}], ")"}], " ", 
            SubscriptBox["k", "8"], " ", 
            SubscriptBox["k", "10"], " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "6"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "-", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                  SubscriptBox["k", "13"]}], "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["k", "7"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "9"], "+", 
                    SubscriptBox["k", "10"]}], ")"}], " ", 
                  SubscriptBox["k", "14"]}]}], ")"}], " ", 
               SubscriptBox["k", "16"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["k", "9"], " ", 
                  SubscriptBox["k", "11"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "6"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "-", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                    SubscriptBox["k", "13"]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "9"], "+", 
                    SubscriptBox["k", "10"]}], ")"}], " ", 
                    SubscriptBox["k", "14"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["k", "7"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "6"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "-", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                  SubscriptBox["k", "15"]}]}], ")"}], " ", 
               SubscriptBox["k", "19"]}]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "-", 
           RowBox[{
            SubscriptBox["k", "8"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["k", "10"]}], " ", 
               SubscriptBox["k", "11"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "6"]}]}], ")"}]}], " ", 
                    SubscriptBox["k", "9"]}], "+", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                  SubscriptBox["k", "13"]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "7"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "+", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                  SubscriptBox["k", "14"]}]}], ")"}], " ", 
               SubscriptBox["k", "16"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["k", "10"], " ", 
                  SubscriptBox["k", "11"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "6"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "-", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                    SubscriptBox["k", "13"]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "7"]}]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "+", 
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                    SubscriptBox["k", "14"]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["k", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    SubscriptBox["k", "6"]}], ")"}], " ", 
                    SubscriptBox["k", "9"]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["k", "5"]}], "+", 
                    SubscriptBox["k", "6"]}], ")"}], " ", 
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                  SubscriptBox["k", "15"]}]}], ")"}], " ", 
               SubscriptBox["k", "19"]}]}], ")"}], " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["k", "3"], " ", 
      SubscriptBox["k", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["k", "12"], "+", 
            SubscriptBox["k", "13"], "+", 
            SubscriptBox["k", "14"]}], ")"}]}], " ", 
         SubscriptBox["k", "17"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "16"], "+", 
           SubscriptBox["k", "19"]}], ")"}], " ", 
         SubscriptBox["k", "20"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "4"], " ", 
            SubscriptBox["k", "7"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "9"], "+", 
              SubscriptBox["k", "10"]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "+", 
           RowBox[{
            SubscriptBox["k", "8"], " ", 
            SubscriptBox["k", "10"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "5"], " ", 
               SubscriptBox["k", "9"]}], "-", 
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "9"], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["k", "10"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["k", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "18"], "+", 
           SubscriptBox["k", "20"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "4"], " ", 
            SubscriptBox["k", "9"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "7"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               SubscriptBox["k", "11"], " ", 
               SubscriptBox["k", "13"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "16"], "+", 
                 SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["x", "3"]}], "+", 
           RowBox[{
            SubscriptBox["k", "8"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SubscriptBox["k", "7"], " ", 
               SubscriptBox["k", "10"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "12"], "+", 
                 SubscriptBox["k", "13"], "+", 
                 SubscriptBox["k", "14"]}], ")"}], " ", 
               SubscriptBox["k", "15"], " ", 
               SubscriptBox["k", "19"]}], "+", 
              RowBox[{
               SubscriptBox["k", "9"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    SubscriptBox["k", "6"]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                  SubscriptBox["k", "15"], " ", 
                  SubscriptBox["k", "19"]}], "-", 
                 RowBox[{
                  SubscriptBox["k", "10"], " ", 
                  SubscriptBox["k", "11"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
            " ", 
            SubscriptBox["x", "10"]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.559070148439*^9, 3.559075298359*^9, 3.559076381748*^9, 
  3.5601395354119997`*^9, 3.560217508692*^9, 3.560386092843*^9, 
  3.5603864226870003`*^9, 3.560386710065*^9, 3.5603881718719997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficients of the terms in the invariant ", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.55907180913*^9, 3.5590718183710003`*^9}}],

Cell[TextData[{
 "The invariant has the form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["x", "2", "2"], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "2"], 
     SubsuperscriptBox["x", "3", "2"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "3"], 
     SubsuperscriptBox["x", "10", "2"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "4"], 
     SubscriptBox["x", "2"], "*", 
     SubscriptBox["x", "3"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "5"], 
     SubscriptBox["x", "2"], "*", 
     SubscriptBox["x", "10"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "6"], 
     SubscriptBox["x", "3"], "*", 
     SubscriptBox["x", "10"]}]}], " ", "=", " ", "0"}]], "Input",
  CellChangeTimes->{{3.5505804587841997`*^9, 3.5505804797032003`*^9}, {
   3.5505805412822*^9, 3.5505806376482*^9}, {3.5518184054986*^9, 
   3.5518184439156*^9}, {3.5518185418556004`*^9, 3.5518185777316*^9}, {
   3.5558028234370003`*^9, 3.5558028261140003`*^9}, {3.558875329409*^9, 
   3.5588753651949997`*^9}}],
 " when normalized by ",
 Cell[BoxData[
  SubscriptBox["a", "1"]], "Input",
  CellChangeTimes->{{3.5505804587841997`*^9, 3.5505804797032003`*^9}, {
   3.5505805412822*^9, 3.5505806376482*^9}, {3.5518184054986*^9, 
   3.5518184439156*^9}, {3.5518185418556004`*^9, 3.5518185777316*^9}, {
   3.5558028234370003`*^9, 3.5558028261140003`*^9}, {3.558875329409*^9, 
   3.5588753651949997`*^9}}],
 " (the coefficient of ",
 Cell[BoxData[
  SubsuperscriptBox["x", "2", "2"]], "Input",
  CellChangeTimes->{{3.5505804587841997`*^9, 3.5505804797032003`*^9}, {
   3.5505805412822*^9, 3.5505806376482*^9}, {3.5518184054986*^9, 
   3.5518184439156*^9}, {3.5518185418556004`*^9, 3.5518185777316*^9}, {
   3.5558028234370003`*^9, 3.5558028261140003`*^9}, {3.558875329409*^9, 
   3.5588753651949997`*^9}}],
 ").  "
}], "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590718349630003`*^9, 
  3.559071895552*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"invar1", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"gr", "[", "1", "]"}], "/", 
     SubscriptBox["x", "1"]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.550577787865*^9, 3.550577805389*^9}, {3.550577852448*^9,
    3.5505778532860003`*^9}, {3.5505788060558*^9, 3.5505788082028*^9}, {
   3.5505792217258*^9, 3.5505792234308*^9}, {3.5505793116548*^9, 
   3.5505793134458*^9}, {3.5518183714695997`*^9, 3.5518183726506*^9}, 
   3.5518184599086*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"norm", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      SubscriptBox["x", "2"], ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5589744528450003`*^9, 3.558974471834*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"num1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      SubscriptBox["x", "2"], ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"num2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      SubscriptBox["x", "3"], ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"num3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      SubscriptBox["x", "10"], ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"num4", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      RowBox[{
       SubscriptBox["x", "2"], 
       SubscriptBox["x", "3"]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"num5", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      RowBox[{
       SubscriptBox["x", "2"], 
       SubscriptBox["x", "10"]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"num6", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", " ", 
      RowBox[{
       SubscriptBox["x", "3"], 
       SubscriptBox["x", "10"]}], ",", "1"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.558994694416*^9, 3.558994774359*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coefficients", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a1", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num1", "/", "norm"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"a2", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num2", "/", "norm"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"a3", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num3", "/", "norm"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"a4", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num4", "/", "norm"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"a5", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num5", "/", "norm"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"a6", "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"num6", "/", "norm"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5505792176668*^9, 3.5505792984588003`*^9}, {
   3.5505793313808002`*^9, 3.5505793480838003`*^9}, {3.5505793940878*^9, 
   3.5505794790608*^9}, {3.5505796065738*^9, 3.5505796173468*^9}, {
   3.5518184885586*^9, 3.5518185265866003`*^9}, {3.55887276121*^9, 
   3.558872805322*^9}, {3.558875225899*^9, 3.558875271426*^9}, 
   3.5588753027679996`*^9, {3.5588754221809998`*^9, 3.558875435988*^9}, {
   3.5588950359700003`*^9, 3.558895046139*^9}, {3.5589744762*^9, 
   3.558974498473*^9}, {3.5589948040699997`*^9, 3.5589948462469997`*^9}, {
   3.558994916527*^9, 3.5589949250629997`*^9}, {3.5589949644700003`*^9, 
   3.558995006242*^9}, {3.55906454162*^9, 3.5590645459049997`*^9}, {
   3.560025851757*^9, 3.560025916109*^9}, {3.5600260012460003`*^9, 
   3.560026033887*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Rule]", "1"}], ",", 
   RowBox[{"a2", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "2"], " ", 
        SubsuperscriptBox["k", "4", "2"], " ", 
        SubscriptBox["k", "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "7"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "9"], "+", 
                SubscriptBox["k", "10"]}], ")"}], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "14"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "9"], "+", 
                SubscriptBox["k", "10"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "-", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", "1", "2"], " ", 
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], ",", 
   RowBox[{"a3", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", "8", "2"], " ", 
        SubscriptBox["k", "10"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "2", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "+", 
                 SubscriptBox["k", "7"]}], ")"}]}], " ", 
              SubscriptBox["k", "10"], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "14"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubsuperscriptBox["k", "6", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "10"]}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "+", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "2"], " ", 
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "5"], "+", 
                SubscriptBox["k", "7"]}], ")"}], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "-", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "5"], "-", 
                   SubscriptBox["k", "6"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", "1", "2"], " ", 
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], ",", 
   RowBox[{"a4", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubscriptBox["k", "6"], " ", 
           SubscriptBox["k", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "7"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "9"], "+", 
                SubscriptBox["k", "10"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "+", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "9"], "+", 
                SubscriptBox["k", "10"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["k", "5"]}], " ", 
                 SubscriptBox["k", "9"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "+", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "13"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["k", "6"], " ", 
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "13"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "10"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{"2", " ", 
                    SubsuperscriptBox["k", "9", "2"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "14"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "14"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "1"], " ", 
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], ",", 
   RowBox[{"a5", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["k", "5"]}], " ", 
                 SubscriptBox["k", "9"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "9"], "+", 
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "10"]}]}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "-", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "+", 
                    SubscriptBox["k", "6"]}], ")"}]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "5"], "+", 
                 SubscriptBox["k", "7"]}], ")"}]}], " ", 
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 SubscriptBox["k", "9"]}], "-", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "+", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubsuperscriptBox["k", "5", "2"], " ", 
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "-", 
                RowBox[{
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "14"]}], "+", 
                    RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}], "-", 
                   RowBox[{
                    SubscriptBox["k", "6"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["k", "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "9"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "13"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["k", "7"]}], " ", 
                    SubscriptBox["k", "10"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "9"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["k", "6"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                    RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "13"], "-", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "1"], " ", 
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], ",", 
   RowBox[{"a6", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "4"], " ", 
        SubscriptBox["k", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["k", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "10"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 SubscriptBox["k", "9"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "9"]}], "+", 
                   SubscriptBox["k", "10"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["k", "11"], " ", 
              SubscriptBox["k", "14"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["k", "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    SubscriptBox["k", "13"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           SubsuperscriptBox["k", "6", "2"], " ", 
           SubscriptBox["k", "9"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "10"]}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "+", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              SubscriptBox["k", "15"], " ", 
              SubscriptBox["k", "19"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "2"], " ", 
           SubscriptBox["k", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "10"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "5"], " ", 
                 SubscriptBox["k", "9"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "9"]}], "+", 
                   SubscriptBox["k", "10"]}], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "12"], "+", 
                SubscriptBox["k", "13"], "+", 
                SubscriptBox["k", "14"]}], ")"}], " ", 
              SubscriptBox["k", "17"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "16"], "+", 
                SubscriptBox["k", "19"]}], ")"}], " ", 
              SubscriptBox["k", "20"]}], "-", 
             RowBox[{
              SubscriptBox["k", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "5"], "-", 
                    SubscriptBox["k", "6"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "12"], "+", 
                    SubscriptBox["k", "13"], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    SubscriptBox["k", "15"], " ", 
                    SubscriptBox["k", "19"]}], "+", 
                   RowBox[{
                    SubscriptBox["k", "10"], " ", 
                    SubscriptBox["k", "11"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["k", "13"]}], "+", 
                    SubscriptBox["k", "14"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["k", "16"], "+", 
                    SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "18"], "+", 
                SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", "1", "2"], " ", 
        SubscriptBox["k", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "7"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "9"], "+", 
             SubscriptBox["k", "10"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "5"]}], " ", 
              SubscriptBox["k", "9"]}], "+", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              SubscriptBox["k", "10"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "12"], "+", 
             SubscriptBox["k", "13"], "+", 
             SubscriptBox["k", "14"]}], ")"}], " ", 
           SubscriptBox["k", "17"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "16"], "+", 
             SubscriptBox["k", "19"]}], ")"}], " ", 
           SubscriptBox["k", "20"]}], "+", 
          RowBox[{
           SubscriptBox["k", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "5"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["k", "6"], " ", 
              SubscriptBox["k", "9"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "13"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "7"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "7"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "12"], "+", 
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 SubscriptBox["k", "15"], " ", 
                 SubscriptBox["k", "19"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["k", "9", "2"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 SubscriptBox["k", "14"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["k", "9"], " ", 
                 SubscriptBox["k", "10"], " ", 
                 SubscriptBox["k", "11"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "13"], "+", 
                   SubscriptBox["k", "14"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "16"], "+", 
                   SubscriptBox["k", "19"]}], ")"}]}]}], ")"}]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "18"], "+", 
             SubscriptBox["k", "20"]}], ")"}]}]}], ")"}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.559071937476*^9, 3.5590752984820004`*^9, 3.5590763820880003`*^9, 
   3.559952430422*^9, 3.560024965936*^9, {3.560025854991*^9, 
   3.560025883323*^9}, {3.560025916509*^9, 3.560025936392*^9}, {
   3.5600260079119997`*^9, 3.5600260351689997`*^9}, 3.560033479559*^9, 
   3.560139537064*^9, 3.560217510981*^9, 3.5602874519849997`*^9, 
   3.560386094361*^9, 3.560386424171*^9, 3.560386711468*^9, 3.560388173466*^9}
  ]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficients in terms of the six parameter classes ", "Subsection",
 CellChangeTimes->{{3.411442604891555*^9, 3.411442633440817*^9}, {
  3.411443210320794*^9, 3.411443218877493*^9}, {3.413475719000139*^9, 
  3.413475721720263*^9}, {3.559072046521*^9, 3.559072054002*^9}}],

Cell["\<\
For clarity, the invariant will be written in terms of the six classes of \
parameters (rather than the underlying 20 rate constants) throughout the \
remainder of the notebook.   \
\>", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.559072062102*^9, 
  3.559072121705*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a1", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a2", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a3", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a4", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a5", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a6", "/.", "coefficients"}], "/.", "parameterClasses"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.55887559035*^9, 3.558875611649*^9}, {
  3.5588757617139997`*^9, 3.558875783192*^9}, {3.559002839528*^9, 
  3.559002868498*^9}, {3.560024984467*^9, 3.560025015304*^9}, {
  3.56002606602*^9, 3.560026093432*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.560388173587*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["k", "off"], " ", 
     SubscriptBox["\[Kappa]", "cat"], " ", 
     SubscriptBox["\[Kappa]", "off"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", "cat", "3"], " ", 
        SubscriptBox["\[Kappa]", "on"]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", "off", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "off"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", "cat", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SubscriptBox["k", "off"]}], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "cat"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], "+", 
              SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["k", "off", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["k", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", "cat", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", "cat", "3"], " ", 
        SubscriptBox["\[Kappa]", "cat"], " ", 
        SubscriptBox["\[Kappa]", "on"]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", "cat", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "on"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SubscriptBox["\[Kappa]", "cat"]}], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["\[Kappa]", "cat"]}], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "off"], " ", 
        SubscriptBox["\[Kappa]", "off"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "on"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubsuperscriptBox["\[Kappa]", "cat", "2"]}], "+", 
             RowBox[{"3", " ", 
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SubscriptBox["\[Kappa]", "off"]}], "+", 
             SubsuperscriptBox["\[Kappa]", "off", "2"]}], ")"}]}], "-", 
          RowBox[{
           SubsuperscriptBox["k", "off", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "cat"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["k", "off", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Kappa]", "off"]}]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubsuperscriptBox["\[Kappa]", "cat", "2"]}], "+", 
                SubsuperscriptBox["\[Kappa]", "off", "2"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "-", 
                RowBox[{"3", " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "off"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.5603881738*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
     SubsuperscriptBox["\[Kappa]", "on", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", "cat", "2"], " ", 
        SubscriptBox["\[Kappa]", "cat"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", "off", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["k", "cat"], " ", 
        SubscriptBox["k", "off"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "off", "2"]}], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["k", "cat"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", "cat", "3"], " ", 
     SubsuperscriptBox["k", "on", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "on"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", "cat"], "+", 
           SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"]}], "-", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "cat", "2"]}], " ", 
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "on"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["\[Kappa]", "cat", "2"], "-", 
                RowBox[{
                 SubscriptBox["k", "off"], " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "off"], "+", 
                 SubscriptBox["\[Kappa]", "cat"]}], ")"}], "2"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "-", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.560388174184*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "cat"], " ", 
      SubscriptBox["\[Kappa]", "cat"], " ", 
      SubscriptBox["\[Kappa]", "off"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["k", "on"]}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "cat"], "+", 
           SubscriptBox["k", "off"], "+", 
           SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Kappa]", "cat"], "+", 
            SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "cat"], "+", 
           SubscriptBox["k", "off"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "on"], " ", 
            SubscriptBox["\[Kappa]", "off"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], "+", 
              SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["\[Kappa]", "cat"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["k", "cat"], "+", 
              SubscriptBox["k", "off"], "+", 
              SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
            SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["k", "off"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["k", "on"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "cat"], "+", 
           SubscriptBox["k", "off"], "+", 
           SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Kappa]", "cat"], "+", 
            SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["k", "cat"], " ", 
            SubscriptBox["\[Kappa]", "cat"]}], "-", 
           RowBox[{
            SubscriptBox["k", "off"], " ", 
            SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["k", "cat"], "+", 
           SubscriptBox["k", "off"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["k", "cat", "2"]}], " ", 
            SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
            SubscriptBox["\[Kappa]", "on"]}], "+", 
           RowBox[{
            SubscriptBox["\[Kappa]", "off"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["k", "on"]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Kappa]", "cat"], "+", 
                 SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Kappa]", "cat", "2"]}], "-", 
                 RowBox[{
                  SubscriptBox["k", "off"], " ", 
                  SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["\[Kappa]", "cat"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["k", "off", "2"], "+", 
                 RowBox[{"3", " ", 
                  SubscriptBox["k", "off"], " ", 
                  SubscriptBox["\[Kappa]", "cat"]}], "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Kappa]", "cat", "2"]}]}], ")"}], " ", 
               SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
           RowBox[{
            SubscriptBox["k", "cat"], " ", 
            SubscriptBox["\[Kappa]", "cat"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["k", "on"], " ", 
               SubscriptBox["\[Kappa]", "off"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Kappa]", "cat"], "+", 
                 SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[Kappa]", "cat"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["\[Kappa]", "cat"], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["k", "off"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["\[Kappa]", "cat"], "-", 
                    SubscriptBox["\[Kappa]", "off"]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["k", "cat"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "on"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", "cat"], "+", 
           SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"]}], "-", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "cat", "2"]}], " ", 
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "on"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["\[Kappa]", "cat", "2"], "-", 
                RowBox[{
                 SubscriptBox["k", "off"], " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "off"], "+", 
                 SubscriptBox["\[Kappa]", "cat"]}], ")"}], "2"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "-", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.560388174526*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Kappa]", "cat"], " ", 
     SubscriptBox["\[Kappa]", "on"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "cat"], " ", 
        SubscriptBox["\[Kappa]", "cat"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "on"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "off"]}], " ", 
              SubscriptBox["\[Kappa]", "off"]}], "+", 
             RowBox[{
              SubscriptBox["k", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["\[Kappa]", "cat"]}], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["k", "cat"], " ", 
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "cat"], "+", 
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "on"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Kappa]", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "off"], "+", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "cat"], "+", 
                   SubscriptBox["k", "off"], "+", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{
        SubscriptBox["k", "off"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["k", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["k", "off"]}], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["k", "off", "2"], " ", 
              SubscriptBox["\[Kappa]", "on"]}], "-", 
             RowBox[{
              SubscriptBox["k", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "on"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Kappa]", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Kappa]", "cat"], " ", 
                 SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SubscriptBox["k", "on"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Kappa]", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Kappa]", "cat"], " ", 
                 SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
              SubscriptBox["\[Kappa]", "on"]}], "+", 
             RowBox[{
              SubsuperscriptBox["k", "off", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["\[Kappa]", "cat"]}], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}], "+", 
             RowBox[{
              SubscriptBox["k", "off"], " ", 
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "on"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Kappa]", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Kappa]", "off"], " ", 
                 SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", "cat", "2"], " ", 
     SubscriptBox["k", "on"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "on"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", "cat"], "+", 
           SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"]}], "-", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "cat", "2"]}], " ", 
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "on"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["\[Kappa]", "cat", "2"], "-", 
                RowBox[{
                 SubscriptBox["k", "off"], " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "off"], "+", 
                 SubscriptBox["\[Kappa]", "cat"]}], ")"}], "2"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "-", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.560388174991*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
     SubscriptBox["\[Kappa]", "on"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["k", "cat", "2"]}], " ", 
        SubscriptBox["\[Kappa]", "cat"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        SubscriptBox["\[Kappa]", "off"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["k", "on"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", "off", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"]}], "+", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "on"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["k", "cat"], " ", 
        SubscriptBox["k", "off"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "on"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"], "+", 
             SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Kappa]", "cat"], "+", 
             SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "off"], " ", 
              SubscriptBox["\[Kappa]", "off"]}], "+", 
             RowBox[{
              SubscriptBox["k", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["k", "cat"], "+", 
             SubscriptBox["k", "off"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "cat"], " ", 
              SubscriptBox["\[Kappa]", "cat"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "cat"], "+", 
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["k", "on"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    SubscriptBox["k", "cat"]}], "+", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Kappa]", "cat"], "+", 
                   SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "off"], "-", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["k", "cat"], "+", 
                   SubscriptBox["k", "off"], "+", 
                   SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
                 SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", "cat", "3"], " ", 
     SubscriptBox["k", "on"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["k", "on"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"], "+", 
          SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Kappa]", "cat"], "+", 
           SubscriptBox["\[Kappa]", "off"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"]}], "-", 
          RowBox[{
           SubscriptBox["k", "off"], " ", 
           SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", "cat"], "+", 
          SubscriptBox["k", "off"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["k", "cat", "2"]}], " ", 
           SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
           SubscriptBox["\[Kappa]", "on"]}], "+", 
          RowBox[{
           SubscriptBox["\[Kappa]", "off"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["k", "on"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["\[Kappa]", "cat", "2"], "-", 
                RowBox[{
                 SubscriptBox["k", "off"], " ", 
                 SubscriptBox["\[Kappa]", "off"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Kappa]", "cat"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["k", "off"], "+", 
                 SubscriptBox["\[Kappa]", "cat"]}], ")"}], "2"], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["k", "cat"], " ", 
           SubscriptBox["\[Kappa]", "cat"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["k", "on"], " ", 
              SubscriptBox["\[Kappa]", "off"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "+", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["k", "off"], "+", 
                SubscriptBox["\[Kappa]", "cat"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Kappa]", "cat"], "-", 
                SubscriptBox["\[Kappa]", "off"]}], ")"}], " ", 
              SubscriptBox["\[Kappa]", "on"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.559072142916*^9, 3.5590752997390003`*^9, 3.5590763846619997`*^9, 
   3.559952440663*^9, 3.560025015947*^9, {3.5600260576619997`*^9, 
   3.560026094115*^9}, 3.560033488293*^9, 3.5601395371879997`*^9, 
   3.560217511108*^9, 3.560386094513*^9, 3.56038642425*^9, 
   3.5603867115290003`*^9, 3.560388175245*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical values for the coefficients", "Subsection",
 CellChangeTimes->{{3.411442604891555*^9, 3.411442633440817*^9}, {
  3.411443210320794*^9, 3.411443218877493*^9}, {3.413475719000139*^9, 
  3.413475721720263*^9}, {3.559072046521*^9, 3.559072054002*^9}, {
  3.56014217237*^9, 3.56014217942*^9}}],

Cell["\<\
At the reference parameter values, the coefficients have the following \
numerical values (given in Table 3 in the main text).\
\>", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.559072062102*^9, 
  3.559072121705*^9}, {3.56002507787*^9, 3.560025090349*^9}, {
  3.5600335012019997`*^9, 3.5600335072799997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"aValues", "=", 
    RowBox[{"List", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a1", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a3", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a4", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a5", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a6", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "numericalValues"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.55887559035*^9, 3.558875611649*^9}, {
  3.5588757617139997`*^9, 3.558875783192*^9}, {3.559002839528*^9, 
  3.559002868498*^9}, {3.560024984467*^9, 3.560025015304*^9}, {
  3.560025096493*^9, 3.560025127459*^9}, {3.560026535936*^9, 
  3.560026565795*^9}, {3.560292443781*^9, 3.560292495908*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SubscriptBox[\(a\), \(1\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(3\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(4\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(5\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(6\)]\)\>\""}], "}"}], ",", 
     "aValues"}], "}"}], ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56028808025*^9, 3.5602880953529997`*^9}, {
  3.56029198215*^9, 3.560292037132*^9}, {3.560292206476*^9, 
  3.560292266046*^9}, {3.560292326174*^9, 3.560292361135*^9}, {
  3.5602925070699997`*^9, 3.560292544374*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(3\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(4\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(5\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(6\\)]\\)\"\>"},
    {"1", "31.099041272880953`", "11.657309401616736`", 
     RowBox[{"-", "234.82638650948888`"}], "10872.087415659746`", 
     RowBox[{"-", "7173.77939847544`"}]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{"Text"}}, "Rows" -> {{"Text"}}},
   GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5602924988719997`*^9, 3.560292545547*^9, 
  3.56038609598*^9, 3.560386425755*^9, 3.560386712915*^9, 3.560388175308*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3) Prediction of robustness from exact calculations with the invariant\
\>", "Section",
 CellChangeTimes->{{3.411417440142596*^9, 3.411417461256724*^9}, {
  3.411442037532863*^9, 3.411442039375865*^9}, {3.411443676335696*^9, 
  3.411443677223529*^9}, {3.5590721755550003`*^9, 3.559072189133*^9}, {
  3.5601421962869997`*^9, 3.560142198158*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving the invariant for ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input"],
 " "
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}}],

Cell[TextData[{
 "The invariant is quadratic in ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input"],
 " and thus yields two solutions. Only the second solution is positive at the \
reference parameter values.     "
}], "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590722689969997`*^9, 
  3.559072344686*^9}, {3.559072495887*^9, 3.559072508594*^9}, {
  3.560026746849*^9, 3.5600267478719997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"invar1a", " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["x", "2", "2"], " ", "+", " ", 
    RowBox[{"a2", "*", 
     SubsuperscriptBox["x", "3", "2"]}], " ", "+", " ", 
    RowBox[{"a3", "*", 
     SubsuperscriptBox["x", "10", "2"]}], " ", "+", " ", 
    RowBox[{"a4", "*", 
     SubscriptBox["x", "2"], "*", 
     SubscriptBox["x", "3"]}], " ", "+", " ", 
    RowBox[{"a5", "*", 
     SubscriptBox["x", "2"], "*", 
     SubscriptBox["x", "10"]}], " ", "+", " ", 
    RowBox[{"a6", "*", 
     SubscriptBox["x", "3"], "*", 
     SubscriptBox["x", "10"]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5588816588269997`*^9, 3.558881672182*^9}, {
  3.560025253667*^9, 3.560025257387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solall", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"invar1a", " ", "\[Equal]", "0"}], ",", " ", 
     SubscriptBox["x", "2"]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sol1", " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "2"], "/.", 
     RowBox[{"solall", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol2", " ", "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "2"], "/.", 
     RowBox[{"solall", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sol1", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
     "numericalValues"}], "/.", "xValues"}], ")"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sol2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
     "numericalValues"}], "/.", "xValues"}], ")"}]}], "Input",
 CellChangeTimes->{{3.5508008407683*^9, 3.5508008734753*^9}, 
   3.5518188051096*^9, {3.5518189381476*^9, 3.5518190102986*^9}, {
   3.55888172575*^9, 3.558881736474*^9}, {3.560026771533*^9, 
   3.560026786602*^9}, {3.560026963932*^9, 3.56002696688*^9}, 
   3.5600270128269997`*^9, {3.560027079158*^9, 3.560027081415*^9}, {
   3.560027124426*^9, 3.560027153601*^9}, 3.5600274815690002`*^9, {
   3.560027532021*^9, 3.560027609053*^9}}],

Cell[BoxData[
 RowBox[{"-", "190191.26109604363`"}]], "Output",
 CellChangeTimes->{{3.5508008632012997`*^9, 3.5508008745053*^9}, 
   3.551025868924*^9, 3.5510296139138002`*^9, 3.5510308783775997`*^9, 
   3.5517958058938*^9, 3.5518155129376*^9, {3.5518189504466*^9, 
   3.5518190132556*^9}, 3.5518191110956*^9, 3.5518194363236*^9, 
   3.5518219614286003`*^9, 3.5518241894316*^9, 3.5518244954096003`*^9, 
   3.5518246174716*^9, 3.552275087535*^9, 3.5522752593380003`*^9, 
   3.5523185640506*^9, 3.5523235727072*^9, 3.5524064020916*^9, 
   3.5524075662925997`*^9, 3.5539480522209997`*^9, 3.5539552295439997`*^9, 
   3.5557769114820004`*^9, 3.555783425170654*^9, {3.5588817403599997`*^9, 
   3.558881751909*^9}, 3.558892907892*^9, 3.558895076766*^9, 3.55889536954*^9,
    3.558895412849*^9, 3.5588968559230003`*^9, 3.558906512826*^9, 
   3.5589178681624002`*^9, 3.5589191120964003`*^9, 3.5589220974863997`*^9, 
   3.558966844291*^9, 3.558974523749*^9, 3.558975240951*^9, 3.558990125082*^9,
    3.558994307085*^9, 3.5590644550480003`*^9, 3.5590653772460003`*^9, 
   3.559065481133*^9, 3.55906566038*^9, 3.559066129984*^9, 
   3.5590666360109997`*^9, 3.559066848109*^9, 3.5590723581*^9, 
   3.559075301142*^9, 3.559076385723*^9, {3.560026753158*^9, 
   3.560026787227*^9}, 3.560026967641*^9, {3.560026999435*^9, 
   3.560027021547*^9}, {3.5600271315889997`*^9, 3.56002715415*^9}, {
   3.5600274683789997`*^9, 3.560027482141*^9}, {3.560027529078*^9, 
   3.560027609657*^9}, 3.5600335139300003`*^9, 3.560139538697*^9, 
   3.560217512638*^9, 3.560386096067*^9, 3.560386425795*^9, 
   3.5603867129519997`*^9, 3.560388175366*^9}],

Cell[BoxData["0.17923795094247907`"], "Output",
 CellChangeTimes->{{3.5508008632012997`*^9, 3.5508008745053*^9}, 
   3.551025868924*^9, 3.5510296139138002`*^9, 3.5510308783775997`*^9, 
   3.5517958058938*^9, 3.5518155129376*^9, {3.5518189504466*^9, 
   3.5518190132556*^9}, 3.5518191110956*^9, 3.5518194363236*^9, 
   3.5518219614286003`*^9, 3.5518241894316*^9, 3.5518244954096003`*^9, 
   3.5518246174716*^9, 3.552275087535*^9, 3.5522752593380003`*^9, 
   3.5523185640506*^9, 3.5523235727072*^9, 3.5524064020916*^9, 
   3.5524075662925997`*^9, 3.5539480522209997`*^9, 3.5539552295439997`*^9, 
   3.5557769114820004`*^9, 3.555783425170654*^9, {3.5588817403599997`*^9, 
   3.558881751909*^9}, 3.558892907892*^9, 3.558895076766*^9, 3.55889536954*^9,
    3.558895412849*^9, 3.5588968559230003`*^9, 3.558906512826*^9, 
   3.5589178681624002`*^9, 3.5589191120964003`*^9, 3.5589220974863997`*^9, 
   3.558966844291*^9, 3.558974523749*^9, 3.558975240951*^9, 3.558990125082*^9,
    3.558994307085*^9, 3.5590644550480003`*^9, 3.5590653772460003`*^9, 
   3.559065481133*^9, 3.55906566038*^9, 3.559066129984*^9, 
   3.5590666360109997`*^9, 3.559066848109*^9, 3.5590723581*^9, 
   3.559075301142*^9, 3.559076385723*^9, {3.560026753158*^9, 
   3.560026787227*^9}, 3.560026967641*^9, {3.560026999435*^9, 
   3.560027021547*^9}, {3.5600271315889997`*^9, 3.56002715415*^9}, {
   3.5600274683789997`*^9, 3.560027482141*^9}, {3.560027529078*^9, 
   3.560027609657*^9}, 3.5600335139300003`*^9, 3.560139538697*^9, 
   3.560217512638*^9, 3.560386096067*^9, 3.560386425795*^9, 
   3.5603867129519997`*^9, 3.560388175367*^9}]
}, Open  ]],

Cell["The second solution in terms of the coefficients.     ", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590722689969997`*^9, 
  3.559072344686*^9}, {3.559072495887*^9, 3.559072508594*^9}, {
  3.560026746849*^9, 3.5600267478719997`*^9}, {3.5600276218389997`*^9, 
  3.5600276306540003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "sol2", "]"}]], "Input",
 CellChangeTimes->{{3.5600276331280003`*^9, 3.560027642284*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a4"}], " ", 
     SubscriptBox["x", "3"]}], "-", 
    RowBox[{"a5", " ", 
     SubscriptBox["x", "10"]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a4", " ", 
          SubscriptBox["x", "3"]}], "+", 
         RowBox[{"a5", " ", 
          SubscriptBox["x", "10"]}]}], ")"}], "2"], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a2", " ", 
          SubsuperscriptBox["x", "3", "2"]}], "+", 
         RowBox[{"a6", " ", 
          SubscriptBox["x", "3"], " ", 
          SubscriptBox["x", "10"]}], "+", 
         RowBox[{"a3", " ", 
          SubsuperscriptBox["x", "10", "2"]}]}], ")"}]}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.5600276347139997`*^9, 3.560027643164*^9}, 
   3.560033518755*^9, 3.560139539157*^9, 3.560217513099*^9, 3.560386096551*^9,
    3.560386426275*^9, 3.560386713433*^9, 3.560388175818*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot of ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input"],
 " in terms of ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]]
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"sol2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
       "numericalValues"}], "/.", "xValues"}], ")"}], ",", "  ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "10"], ",", " ", "0", ",", " ", "35"}], "}"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "3"], ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", " ", "\[Rule]", " ", "Automatic"}], ",", " ", 
   RowBox[{"BaseStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", " ", "\[Rule]", " ", "\"\<Bold\>\""}], ",", " ", 
      RowBox[{"FontSize", " ", "\[Rule]", " ", "16"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.56003368794*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJytnXVUVNvbgM8gIoqNrQgqCgYKBoLBHgvBBK91RQU7MbBQUUYxMEHsBBUw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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mge0FMUShndne2YUVBRzeGYUzAFzRpAsOSNIBkEBQVAkJwERSSIISBAF
ASWKAioYkGDOzxwwJ8QcUN/3+/c75/apb/v2zsz2dFdVV9VR7Xs2vC4pFApf
lgoF/gq9QqEwrVgoXIuchzyD9gf9K5EraJ1pwxl4ifr44nI+X0gLtGW0B2nt
ae8yZgZj9kA+TxsH/8X4NWmh8Dv8ELIX43rSytA20ybqvrSnaGNoV9E+Z1yC
3IjshzyBthetK60LLaP1oHWn7UZ7iLaadg3tGdoEWjdaX1of2h60R2gP066j
raJdHK+zhnZpvE6ZrFA4F/kW990dXgTnyD/4LQ/z/CcgZ9Gaw8/xu6bzv6vg
zczbUsYuobWhPcCYFvS/wJim/O9g+i5CPo0cR2tHW0g7m/Y34x7hfn8iH0Y+
Tcs1H8ivuc4i+g9F7sG9zqf/bfoXICvTdvG/QH9T+FP655b8PC9x33vom09r
SJtE/5X0P0H/Q3B7+A14E/8bT+tEey31PG1F1o9r4FPG3YSsRCsHn5O4/1zk
0ciKtO/pP57vrEFuQR5MWwhvQp5F2wRvQ16U+JkvRp5OO033QDaOv+Uzxt2M
PIn2EXyKWOP4fUfF/n1oBzKPr/H/6vyOfeOz/cjnG+MYjb2X+31C34fIGkVf
a3vBz6vn5u/fdVWBtgPum5hvQM6M43+h/+6in/M3uCP3Owo5lTF94NPge+DZ
/H8WrZauy7Meg3yV+1bgObXHeiLn0jeHdiWtI61D3DtHx3k8Bnkc4/Zi/CQ9
S+LrHIcsxzWvh3dyzSeRo2ktaGtpVeI+ekbrteg5vws5g3YFbSWfD+eaVyJX
pJ4ncVna9ILX2N38llrwBv0WuCb8ONwa3g0eAbfT+oNvg9vDe8K3w23hMvBY
+Ab4aHga3A8+Br4TvhouC98Kt4F3h2+BW8E5PAyuzm/fT+sKOTR4njXferc/
FfzcLfjM4xYGMb4lzLQUhsDN4aC1A98Gnwc/CDeLuu0mvS8GlIcv5wIT6Dwf
Xkb/GPgs+H74dvgCeDk8FD4JngffCVfVHoXfh2+F/4E/gMfDukkPWkVwFv1D
4BPhufBq7neq9ACyL/2nwwvo7wUfBk+EB8MnwHPgG+EK8Az4DrgKvAauz/Mf
yFxcgLyF/sr0L6J/NHwmvBAeBZ8B3wcP0txp/cL94WPh6fBN8HHwXXAjrnUQ
17wQ2ZP+Q+mfQP+18MHwOPgNeDj8K/w2PBr+U++d7xwmvYn8L/0j6f9da4bP
h9J/CfJZ+vvT/w39b8Gj4D/gN+ER8G/wC/DN8A74JXgQvFNznllfPcJ17qO/
kXQs/ffCDeFn4FfgIVob8KvwUPgneCN8LfwR/CI8EP4efhkeDP8APwFfB38M
b9D7k66AW3C/Q6SjkNfQfyD9o+jvCu8PD4U7S+/AA+Eu8H7wYLhTyWtsANwN
PgAeDtfiWvtzzfOQ19F/CP3j6e8N/weeDE+DL5f+hzfDfeAv4I+D5+dm7X36
e8Lb6X8K7gV/Aj8N94Y/hbfB/eCv4Wfg6+HP4S1wX9l7eCt8A/wVfA7X/xA+
O1h3lo86tn/Uq9KvF7JJ1/OdrryTQ3mO+/U8spP0P0x/R/hieBPcHa4Cb9cz
wdXhH/RM8DnwGrgDfB78CNxJNg1eC3eGz4ZXyz7BF8Dr4C7wGfByuA18JrwC
bgufCi+BW8OnwUtl/+BL4Ne0DuCz4FVwO7gyvBK+Gt4fHqB5h8vD3eXfwIfA
Y+Ea0ru5fZqecHN4b+ZpdGa7PUp+CnNxXW57cBn9vXP7PT3gzczVZMbsB38G
t4LLZvZt2sJ7whcx/lHGd4NPoF2qd87/T4Svgb8TM2ahfA7ZQXg6XC+zjZNt
+hG5OLU/9htySWrf5nfkQMY/xvhrGL+WzyP1fuGb6O9Af3X5QJl9kX2Rten/
k/4BcA34R+1h+Ah4ClwXPhKeKn9Ctg6+C24AHw5Phuvot8AL4GZwhdw+UyP4
WHim9jB8NDwDrg/XgXeVvK62BO/H63jeZvTvyedR8nHgPeCR8AC4Ljwb7g93
gr9l/GC4vewt/ZXge7hmU/iG3Dr0I8bUhf+SXqD/eHge3BiuCM+Hm8D/gcfD
teHL4U+0l+DL4Pe09/Su4NelR+Cq8Kfat3A1+BvtN/gUeDHcCq4J/wTfCNeC
f4Zvgq+Av9WehE+G74dbwgfBI+Ar4MPgW+Fa8L657c2l8H657UoV+AD4Ztkq
+EB4IFwNPgleBLeAD4ZH6r1rL8Pj4JoypLQ7WQMJsiP9RzBXk7QXUvufWg/6
HZ3htxPvuS7wO4n3XFf43cRzcxe8Z8nzMQ/ev+T5mwvvh3wy+h6vpH6ujvB/
E//uTvBbid9DW42BD+FZ3oRrSV8W7RvLv9zA9wfI10U+RusOv5h63bWDX0v8
fibBacnvuQ38cuJ1cTX8qmwB3xmr/tT28C+4Na053Cz65z8X7J/sgzyI53kd
WUPX1D7l8xDmbHfkM/SfR/+szDpfdv/XgvlIzQty76L91+Oj/6lzzaGyo/TV
5rtp0bZVz1Qq2p7qd0qHyHF9HPkw4+vycZ30MXxxwWeHmcH+hs5ZL8Y5uRZZ
LNqu6fOm4N/3KP1zMt9L7+Iw+t+iv47mGX4britfAH4Drlnyupb+P6zkNbsY
/k/JOuMR+MSS1/hy+NiS9ccy+Bjk4UX7qDonaE9vQ15U8j5YAVcoeR3ulA+W
Wh+shU9CHiHdWfRZIuG7jyPPoL8Eb4DPLHlPr4NPRgb6N8KV4bLwFviCkvXH
VvhCuAy8GT5fcw4/AZ8Fr0r9rp7XuuKeA2nVaMdGW9mYMUfC78L1Zf/hl+Cq
8P7wy3A1eF/4RfhyeB/4efgy+Cj4PbiBrlP0mtB6KE//C8gqJZ8JdK76mHY0
/e8jG9K/gf6htLq0y1Lfa6b0MGM+gBuVfN6pHs8vdZC14/lF56xGRZ8Zdb6r
V/QZfyNyOK2B1hZtMK1m0bq8Hv9/MrHurw8/ldgP1VlV66910eflL+B6ic+n
9RPb/Af17NpnRfd/yed9U+sB6cDAntkZfYP9UusK6cNWie1X68S27Gv6v0F2
SXze6Spdkfq8+AuyXeLze/vEMQHxN1pjqXWR9GqveFb6tuCYQFXad/AeqeMV
0tXXJu5XYET29Cv5SMjy2icF28GFqc/EP6U+s+iMdUWwLdWamZJ47vUOthd8
jqwR38WguI7UPzCez8RD4nzrvKq5rxV5YslzvJFrXl/yvp4fz8114juVDdSZ
sg7y59Tr4j7ksJJ1wop4Xq8f3/Wvqd/zotRnY93ng9RrQWP029LUOlO2TL6r
nqcmclnq+duFvK3omIHezZyS9cmLif0+zdW+JfsaTaOPJH/n6rgGdnHdj0v2
D6Vfm8cxZ0eWvv2EezTknv1yxwYax3Ub6J9YsC2Wr65YS/NgH0c68tvEMaQ2
8V5ji44niRWHaQk3Cd4HuqbWkPy4JvEZbin6bK31vDHGoBRvubXomI3WxAOp
19cfyC9Tn+W/SB3XaR/H6BwkboV8rmRdvivxetL/Nf6dku1g2ZJjMJ3jfMqP
U4xA8QGds9TfJngP6P9fp4579YjrXP6O4l7tkH+mjnstRf4dHH+Tr/JVyTbz
kJL3h76reJf2mWJqioPJLsv2yNf9K3VM7kHkrOBYh/wQxe16xX3UpGR72J/f
9b32J+NuzO3zXh/3V5U4XjGK3YL197l8rzt8Q9G2U/G5vnH81KL7FZOZguwd
+xX/6xf7K0TeK+6ngXEf6fyiGNBHBcdA1C9bMjvqNO3BmpG17qvG+yrmpbOO
zjzl4p4dFK/5R3zXms+f4t7X/tKeGhb3yy9RF2lPaa2OiOtKa2pkXFdpZpYP
vj71Gt8tc4xueNybWnej49pTvGho3ON6NsXgFAeRrr0ljtG6HhPXttbmuLj2
dO7RHgkl692xccyyOEZremn8rvyJHzKfn3VW0p4eH9fhyshah5r/AXHONc+K
0+msqLjrhLh+9K4mx/d1bNHvckfUdXof0nd7Zx6js5Hmf0ocLx9Mvo7OTdKf
s+L70lq9Pa7zJ4qOe+6K62pSXIeK606M63lb0XFsxd3+Sb0+tU5nxGfYGder
+qW3Zd+nx/5dUb9pzSsGqnXxQ+prbqXdEd9Pyzj/em96f4qvzo+s9yh7Oye+
O52JhyF/TmxbZ8bfpXerdyzdLZ0u3S4d/lnm87zO0b+X7CtVKvl6c+M1pbvu
jfMgf+Du2K85mx2vr//fF8do7YkVH5YtkU2RbpVtkI2oF6z/58fnlw2TLZPO
HxyvKRsgP2He/9dqbp/mlsz+qNaRYubS54qZa31Pi+9D86YYu2L90ilPBsfP
dU5XHF7xeums8pm/p/2xuOh8wP/X+FNxrW7ku00LPk9tgJsUfFZ6HG5c8BlH
NuTsuO+G8pwPluwD351Z99+c+31ui+ukd3CcsEfwOtoc19ITfG5WcGxhR+r1
vVfmPfR03EfaH5viHpkQf4v2guJWil/pXLk9tS4owSvkMxR8Xl4F1yj4XLwS
rl7wuXg93KDgs/PwOO+a83mRZb/3Ysx6+k6Vzxvsm+mcuxyuVvCZWjkJ5QIU
M1ken1P7+4H4/NIZL2aOrym2oBhDB8a/yaSsDfb9dBZ+NnMMVDEHxR40z1sS
53yWxXkox/hH6T+N/2fwSvj4ks+al8GrGf933I/alzrXXgqvov85Pr+iPa2z
Ev33wAeV7BveDZdH/kKbDx+IPKDoXJLWrs6450o/Jz77ngMvSRyf0Bw+nTje
oPf4bOJYhdbPtsSxB62frYnP+noXj8K/wQvgg0s+H+t9rUt8/tY7Wq/fAi+B
jyg59qCzTRXk93yeTf8+WlB8fgBxlM7Emc+GZ/MbD6D/SficaAd1Bqiqayhm
Sv8l9F+eeA1XVewx+PxzOTKnrWJMRem0zDmpilzzHz4vhY9EfkGbCu+O3KGz
KLw38jvaTLhcyf7X7XAJ+SHtNm0v5Ee0CXBScm7wDrgM8nPaFNks5Ge0yXBe
sr8lv0t+zri4HtrH9fVAXBsTYjxfMQrF2I6HZyq+HRwzV4xiVeZ4q+Jvq+OZ
WfE06dv7o84drXh1wXGPqcHXUaxDMbyz4cVc87HMMW7F9Pok9hWU27mq5O+O
hhdlzm1cnDn2qhjs8cH7U/tU8bcFwetK8R+dB3X+Vz5C+/9fn4S+TZnzB4oT
zg9+BsVS7gleh4rVnJLY5zgVWTmxf34Wsk5i3VYXeUVi219d56fE+/sCZMXE
/k0l5Ozg3IHiNspLak7kP0hfyf4pp9kw8Z5uhGyTWKe2RfZKbI97K1YTvB8V
u1scnM9VvG5J8H5UfE+xT+mQtYxvnlhntEgcW5Rv+g6yY2Jd3ilxTvWRqDOf
DY7bKL4qXbgq6sM3g2M7ivFKZ8q3kF+rfOnSqNvfCY4pKc78VnCsSbHf94Lj
S4qRKve7Ol7zxeA4j2LFOis/WvR5+f3EcQ6dC8bE6+s88Gbm3Kfiz/LZV0S9
vSI+j1g+unx1+dvSl8tjv+zP4vicrwfHrBS7fjVYZyoGrviuzsPyDZRP1/Mo
9yf/R36GfAw9+0Px+ctG/19++/PB8SjFqDdHe6n5lJ//cOQJ8bvy9bcGx7IU
Az8k+vYdg/2r9UXnCrcUnSOU710p+hLy0dcVPUb90+OzaZ3JN5GPovUqn0K+
hdZrzcR+Z63E/v+6+N3Bcfz//RmNlx/SMncsYwzPciVchAfBjXPHXIbDu5DT
GDtRZ6jgHNOw1LUCOrOcRt8Bqe3ILPkXqXXXJOSBqXXgbJ2lgnNJw+HPg3NA
Q+H3g3NPN+nMFJyfGqEzr84o8AD57MH5oyHy64NzQ4PhDxLHn0+RvuHzavju
1Dl4xULPoH/31DbiTmQZ2r3wdORuqe3XNOTHmXNRg+Byqe3FDOThqW33nNR1
Eoo/nM41k9S2Y4rsZGrbMROZp7Z9dyD3Tq3n71JML7VunyzfObWtnIrcnjm/
pd/ySXBOTc/wTXAObmTq/JbigS2D6xJUn9As2MbI1nSTngiOt3YItm2ycZ2D
Y4ZXI3vkzh0qZto4uHZEPt91wfZMdq1acE5XsdMayPOD7feVwTHS2sjuufOa
iis1QG4PztkNTJ1HVPzzKj1Xah9jLvK3YBs0Hv4j2N5NgH8PtlO3yZcPzleO
gr+Tryr9nzoPLn1/rXIdwTbudvp+CM7njtFZL9gOjtN3E+fgTqXv52C7eSv9
O4NzwbfAPwbb0LHwR5lzinr+DzLnd7TePpSfWnIu76fMeVA95/eZc5O618+Z
86n6LX9mtsd6p79kzqHqOf/IbLO1TnZkzpvqvj9mztdqTnbL7aNoje3MnCvV
M++e21fQHP6V2ZZrXf2d2cZr3Wa5/TDtr98z57m1xn7NnAPWnp0PNy05ny6/
XXUJyh8tyJyPr0b/wsw5/hraE5nz8VX17jLn0bWX5RvrXKec1Lmyv4nty7eZ
c8Oa2x1RlymP9lzmGoVuqetCTkx8Xt+WOYfalf6yuX3Qedo7uf057d80tx8p
ffJu5pxjf/i9zHnGG+F3Mucl+8knzZxz7Am/DC8rOSf1Uub6nh7wF5nztdI/
X2bOs0rPvJ85Zyr983nmXKz02yeZ87j/6pzMeVzpq68y52W1N1/InOfuDr+a
OdfZC34tc+6yN5zk9u2kB0q5/U7pChVUyG+TLvonsy8oHVXM7f9J/3yXOS+u
df5N5jy99sXzmWtBroFfz5wzvR5+O3Oe9wb4rcw53L7wG5lztX2kYzPnnrXX
5CfJX6rIO7g3c93GFalrVKQ7++bOoSjuXRk5I7juoi3/vwu+UP4DPD24TqMN
/GBw3r8LfGdwjcdV8NNwt4LfhWpxFKc6Qee44FqIFqnr1eTnnEjfpOB6iZb0
zwmur2gHTw6uqWgFTwmuCWkNL4Jry29JXet1svwwnv+F4Fy83sWy4PoErb3H
gmur9O5UJyS/t5L0RHA9STP6x8Mnyz+BtwXXKmiNqebhJD4fx/UfCq4f0zp/
LrhWQWtgDdyy4Hf0WnB+X+/ileAaAL2Ll4JrA/TuTk2dK5Etvi+4tqcjfXOD
6w3apz4XK36rvFD1qKeVH54ZdbVyrKq5OiHqc9UOyS4ox6r816aC67wUB24W
bYFi142iPlcuR76PaqIU11VMWDVrilHXi7ZA8W3FTWQPFNtXTEW52oXBtUmd
Up/jW0U7pTyl8pWK7Siu2CfaLMU5u0ebtU9uv19+/rzgGp4OXOes4BoH1Tzo
+3dGm6X4tvxo5ZEVm5WvKTsnPacYhuIDisn0jHZQ+XvFtZVbVxxYNmpQ7lio
4p+q2zotdX5qrM4CWh8Fx0xUR/CczjLaV8E1JNKZfYNrS6QnbwyuP5H+7Bdc
f6J91D+4tqQ6fHNwPUkt2fTU+aOpXP+S1LmnO2QTgutJtH8vSp2HmkL/wOCa
n9r0XZo6hzVN56ng+p+a9A0KrlOqA/83uIZEuvHd4DoT6UzVHCpnqrUr+6Zc
o3wn1XxqL/bMXdMoH6dP7lpH7cVe8NvBtSjSw9Kv/xS8x3S2PVP7KvfZWXqi
DXxy6jPyPcjKqeMGC5BNcuf5RjC2QurztfT/mOA6qMbw2OA6qybwuOAaraZ6
xtR5RtUVnJg6h6h6g0qpc5q6ZhkVqgX7sfJn9R5P53kPS50DVS3BOanzibfJ
lqXOOU6A98odH/m3biR1HGA8fHrqHOU4+IzU+cdb4fNS5yhvh49MnUcbDB+V
Opc6BD46dY51KDw4+Axbl75hwTV49bR+EtcjSQ+PCq77akT/yOAas4bwiODa
sAbw8OCavfrwhanX5+TM8QXFGeS3H5M6VzsMPj91Dndi5nqBd3Rf5mTv3LEM
1Q8oJ668rd7lfZnr9rRuj6M9xfj5yIcy10XpvazPXK8mPbxH7niHxjyauTZO
Onlt5lpD6fZlmeux9MzLM9dj6besyFyzpd/4QOaaRc3Pg5nrtDQ/z2SuF5Q+
XJm5ZkvzszlzjaB0ztbMdXiyOxsz1/bJTi3NXBOpfbEkc42j9tETmWsHZb82
ZK7tk/16PHNN3r82K3MNn3TRU5lr+KSHn8xcwyd7tCVzPaLszuLMdZba449k
rhuT7ViTuW5Pa/iq3LlnrZ+uufPB2vtdcuePpRNa585Va721yp2fll5qkDtf
rrVUL3d+Xeutfu78utZbw9w5cr33brlz4dIVD2euZZRd65Q7L6410zl3nlt6
Zs/c8Urt2XWZa0Nlf1dnrjXU3iyXOy6mvdw+dy2C1n+H3LUIWmNX564F0f5q
m7suQfuoXe76Ce21a3Lrd+XE789cbyo99ktwHF61Ov8Dj4XS7Q==
         "]], Polygon3DBox[CompressedData["
1:eJxNmmWgHUW2hc9puwQPLoMkSLBkcIJrcLfgkAAhaEJwt+Ae3N19cCdAcHeH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         "]], Polygon3DBox[CompressedData["
1:eJwt2Heg1uMbx/Gn8zzPOUSlYUclOzMlkgrhR2ZRZDQ0yEjaOyVpikpbpSgr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         "]], Polygon3DBox[{{1390, 943, 1069, 1688, 1223, 1224}}]}]}, {}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkskuxEEQxrv/M/52Y5/BjOHihiAIMhFxdXJ1c3QgcZB4Axdnb+ANvIG4
jH0Q+77v+779KtWHL99X1V3VVdVV3T/UO+gZY7pBAKynGdMHx3xj0jjoQZfB
EewLa0wLPAeHwDIowc7nznDQmAPsBrAHLDF1+MPwH3YcXYoOgAQ6Aid5a1r8
5Cj39N1T7v5YzVmCr5mzdE/rmbV6/wvOxjeKjsIjIIVO4c9ED6Ar4DZinvCV
ww1gFx2Gx6m13ukycI1uhe/hDnALLsUHzkEVuabI+Y4+Bk3gECSIWbJafxJ+
5M48XOHrHFbpL0bsGP477Er0BPpReqSGhKtt0cVKjjh3JtEvVmuTHg+COn/p
awZ9w1kbuAJboBZsgKivta3x7hpcIzWAT9ANisl9AjcD39PepMcM9CvcCZ5B
ketX+g67f9xx+YPYTb7OSGaV4+nbUsOv1V2RnTmSXrhXiN0BP1jtN8/T+Xhw
I/ztapMaI2439tHbVv/I4Ftx+yZ7Vyn7hq/d1/5lDlnYuW7OMm/ZyQWJ97WG
LvQOMwm5+cs/SB7pdxv/mZuJzEZ2VHZ1E13g/kL+5MNqnjfwD4CPW/0=
         "]], Polygon3DBox[CompressedData["
1:eJwtkblKQ0EYhf8ZvAPugsYliUqagEgI7sQYRGytbO0sLbS2svVJfAPfwFJs
Iioq7mgZFVdcv+Hc4uM/Z+7cc8+dKaxuLK97MytAE0wEsxvHhDx6Fl7Q8zCE
rsI7egGG0ZMQCJjCHydm4/hL9Bjk0NOQ4/ka2f3oW9aXTPl38AG7prxPKLLn
NGaztkWhEXwDv41v4GfwefI28QPoFnTFKb/Za08V/+j07j1zxdTvAX6hBF2s
/TB72bOH3kfX0GXIeD3PoAeD3s/Gf0SfsG8UOuEQjPVy2veP2eb1/divFd0B
tbR/O/oi0f92o+fIu4rfNZ3XNfQF5Z3HM0R/OfVbZH5DNijvCSroOrNu6hS7
HcAzvsg8cjrD+L9n6dm+MndM9/nm1KHHKz92i3cY7yfxutt/KbE7UA==
         "]], 
        Polygon3DBox[{{1565, 519, 520, 311, 1496}, {1500, 151, 527, 528, 
         1566}, {1494, 61, 515, 516, 1564}, {1501, 166, 529, 530, 1567}, {
         1493, 46, 513, 514, 1563}, {1222, 311, 490, 489, 1560}, {1249, 313, 
         493, 492, 1561}, {1138, 242, 464, 463, 1557}, {1559, 478, 477, 46, 
         1165}, {1558, 465, 466, 271, 1483}, {1562, 499, 498, 151, 
         1277}}]}]}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt08lvzGEYwPEHtRUlXJzEoJ2ira3UUlstXabrtLXUXmstrVqiNCJC0ggi
Lg7uEudG/ANcJE6CWqqtf0AcHB183sThm8/7Pr/MvDPvZDLdffneSRHxXqUW
aZ2ZHLFES7VMxSpJTovIslTLtUIrtdq8jOWq0Ko0U5n5Gq7VOlVqvRabb2CV
NmqTNmuLMp5Vc6u2abt2pLPMd7JGu7Rbe9J55ntZqzrVq0FZ8xwb1aRmtag1
fX7P2phXuzrUmT6L+T7u1wEdVFf6XuaHeFhHdFTH0h2ZH+cJdeukTul0ujvP
zvCszqlH59N9mV/gRV1Sr/rSPZtfZr+u6Kqu6bpG/ChZFemWaqdEfPQ7zbOu
s/5kXc/PbOAIc/zCRn5lE7+xmS36bt3KUbbxB/McYzvH2cEJVhVEzHfWoH7a
DzCjmqkRH+wr+YYlfMWFfMFCPuNfrx/iLw5wguPqsX7LLr5mji9Zzecs5yMu
4rD3+sObzp3LG1ygp+6nyP4J5/AxZ/MhZ/EBCznEmbzPe5phfZfTeYeuP27T
MTHIgnQWXUH027xzlm0UW//+/1/5B5zkTNg=
       "]], Line3DBox[CompressedData["
1:eJwt0jtPU2EAh/G3tQW8YAuKgoKFhcQQbbDWppbGGFYnVzdGBk0YSJhcXZgY
/AZ+A7+BcQFUUGqVUsE7iFTrBUUUfydhePJ/3uftSZr2DIzdun4zFkKYwUQi
hLQ9J9zmGZ7l0/w8X0qGMOxc5hWe49f4c57nN3iVF/hDz4w7F/kan+Il3uB3
eJn/5Xd5zTNXnO/xFX6V3+d1Psof8Fme4kN46jwZt7yKZ5jHIhai79cSwpz9
g13s4LjPj+jHbD9+ab+xjZLeqXUggx/aT3zHZXdpLYUzaGrfUNS/2qNaO/rQ
cD6rf7FbOKIdRi8K+qb2GZ9wSDuI07jkbl3bwEe0aa3I66fse+0D3qHF+aKe
tD14o73Fa+T0hHYA3ViNfnu8wgV3cS2Gk1jR6hjWa9ELoO3ZE/alHdSX7Qv8
i/4rdLnL6o/5E8ziESpYip5Bc/89+g9GZU3/
       "]]}, {
      Line3DBox[{1164, 1368, 1720, 1163, 1367, 1719, 1162, 1366, 1718, 1161, 
       1365, 1717, 1160, 1364, 1716, 1159, 1811, 1600, 1158, 1810, 1599, 1715,
        1157, 1363, 1714, 1156, 1362, 1713, 1155, 1361, 1712, 1154, 1360, 
       1711, 1153, 1359, 1710, 1152, 868, 1459, 1485, 1913, 327, 328, 302, 
       1584}], Line3DBox[{1178, 1376, 1729, 1177, 1375, 1728, 1176, 1374, 
       1727, 1175, 1373, 1726, 1174, 1815, 1605, 1173, 1814, 1604, 1172, 1813,
        1603, 1725, 1171, 1372, 1724, 1170, 1371, 1723, 1169, 1370, 1722, 
       1168, 1369, 1721, 1167, 1812, 1602, 1166, 1902, 1601, 1460, 1486, 1692,
        1899, 1503, 1504, 1445, 1523, 1580}], 
      Line3DBox[{1192, 1382, 1736, 1191, 1381, 1735, 1190, 1380, 1734, 1189, 
       1821, 1611, 1188, 1820, 1610, 1187, 1819, 1609, 1186, 1818, 1608, 1733,
        1185, 1379, 1732, 1184, 1378, 1731, 1183, 1377, 1730, 1182, 1817, 
       1607, 1181, 1816, 1606, 1180, 1903, 1462, 1461, 1179, 1693, 1914, 1447,
        1524, 1446, 1525, 1568}], 
      Line3DBox[{1206, 1386, 1741, 1205, 1385, 1740, 1204, 1829, 1619, 1203, 
       1828, 1618, 1202, 1827, 1617, 1201, 1826, 1616, 1200, 1825, 1615, 1739,
        1199, 1384, 1738, 1198, 1383, 1737, 1197, 1824, 1614, 1196, 1823, 
       1613, 1195, 1822, 1612, 1194, 1904, 1464, 1463, 1193, 1909, 1505, 1449,
        1526, 1448, 1527, 1569}], 
      Line3DBox[{1220, 1388, 1744, 1219, 1840, 1629, 1218, 1839, 1628, 1217, 
       1838, 1627, 1216, 1837, 1626, 1215, 1836, 1625, 1214, 1835, 1624, 1743,
        1213, 1387, 1742, 1212, 1834, 1623, 1211, 1833, 1622, 1210, 1832, 
       1621, 1209, 1831, 1620, 1208, 1687, 1830, 1466, 1207, 1910, 1508, 1540,
        1509, 1541, 1465, 1553, 1507, 1539, 1506, 1578}], 
      Line3DBox[{1247, 1853, 1641, 1245, 1852, 1640, 1243, 1851, 1639, 1241, 
       1850, 1638, 1239, 1849, 1637, 1237, 1848, 1636, 1235, 1847, 1635, 1751,
        1233, 1846, 1634, 1231, 1845, 1633, 1229, 1844, 1632, 1227, 1843, 
       1631, 1225, 1842, 1630, 1223, 1688, 1841, 1468, 1221, 1694, 1915, 1543,
        1545, 1544, 1467, 1554, 1555, 1542, 1582}], 
      Line3DBox[{1262, 1414, 1772, 1261, 1413, 1771, 1260, 1412, 1770, 1259, 
       1411, 1769, 1258, 1410, 1768, 1257, 1409, 1767, 1256, 1854, 1643, 1766,
        1255, 1408, 1765, 1254, 1407, 1764, 1253, 1406, 1763, 1252, 1405, 
       1762, 1251, 1404, 1761, 1250, 1403, 1760, 1471, 1488, 1916, 1642, 1549,
        1511, 1472, 1498, 1548, 1576}], 
      Line3DBox[{1276, 1424, 1783, 1275, 1423, 1782, 1274, 1422, 1781, 1273, 
       1421, 1780, 1272, 1420, 1779, 1271, 1856, 1646, 1270, 1855, 1645, 1778,
        1269, 1419, 1777, 1268, 1418, 1776, 1267, 1417, 1775, 1266, 1416, 
       1774, 1265, 1415, 1773, 1264, 1905, 1644, 1473, 1489, 1917, 1513, 1512,
        1514, 1450, 1528, 1499, 1592}], 
      Line3DBox[{1290, 1432, 1792, 1289, 1431, 1791, 1288, 1430, 1790, 1287, 
       1429, 1789, 1286, 1860, 1651, 1285, 1859, 1650, 1284, 1858, 1649, 1788,
        1283, 1428, 1787, 1282, 1427, 1786, 1281, 1426, 1785, 1280, 1425, 
       1784, 1279, 1857, 1648, 1278, 1906, 1647, 1474, 1490, 1695, 1900, 1515,
        1516, 1451, 1529, 1581}], 
      Line3DBox[{1304, 1438, 1799, 1303, 1437, 1798, 1302, 1436, 1797, 1301, 
       1866, 1657, 1300, 1865, 1656, 1299, 1864, 1655, 1298, 1863, 1654, 1796,
        1297, 1435, 1795, 1296, 1434, 1794, 1295, 1433, 1793, 1294, 1862, 
       1653, 1293, 1861, 1652, 1292, 1907, 1476, 1475, 1291, 1696, 1918, 1453,
        1530, 1452, 1531, 1570}], 
      Line3DBox[{1318, 1442, 1804, 1317, 1441, 1803, 1316, 1874, 1665, 1315, 
       1873, 1664, 1314, 1872, 1663, 1313, 1871, 1662, 1312, 1870, 1661, 1802,
        1311, 1440, 1801, 1310, 1439, 1800, 1309, 1869, 1660, 1308, 1868, 
       1659, 1307, 1867, 1658, 1306, 1908, 1478, 1477, 1305, 1911, 1517, 1455,
        1532, 1454, 1533, 1571}], 
      Line3DBox[{1332, 1444, 1807, 1331, 1885, 1675, 1330, 1884, 1674, 1329, 
       1883, 1673, 1328, 1882, 1672, 1327, 1881, 1671, 1326, 1880, 1670, 1806,
        1325, 1443, 1805, 1324, 1879, 1669, 1323, 1878, 1668, 1322, 1877, 
       1667, 1321, 1876, 1666, 1320, 1689, 1875, 1480, 1319, 1912, 1520, 1551,
        1521, 1552, 1479, 1556, 1519, 1550, 1518, 1579}], 
      Line3DBox[{1346, 1484, 1898, 1691, 1345, 1897, 1686, 1344, 1896, 1685, 
       1343, 1895, 1684, 1342, 1894, 1683, 1341, 1893, 1682, 1340, 1892, 1681,
        1808, 1339, 1891, 1680, 1338, 1890, 1679, 1337, 1889, 1678, 1336, 
       1888, 1677, 1335, 1887, 1676, 1334, 1690, 1886, 1482, 1333, 1697, 1919,
        1522, 1481, 1492, 1572}], 
      Line3DBox[{1458, 1358, 1457, 1901, 1150, 1357, 1709, 1149, 1356, 1708, 
       1148, 1355, 1707, 1147, 1354, 1706, 1146, 1353, 1705, 1145, 1809, 1598,
        1704, 1144, 1352, 1703, 1143, 1351, 1702, 1142, 1350, 1701, 1141, 
       1349, 1700, 1140, 1348, 1699, 1139, 1347, 1698, 1534, 1535, 853, 1538, 
       1536, 1456, 1491, 1537, 1573}], 
      Line3DBox[{1575, 1546, 1497, 1470, 1510, 1547, 1920, 1389, 1487, 1469, 
       1745, 1390, 1224, 1746, 1391, 1226, 1747, 1392, 1228, 1748, 1393, 1230,
        1749, 1394, 1232, 1750, 1395, 1234, 1752, 1753, 1396, 1236, 1754, 
       1397, 1238, 1755, 1398, 1240, 1756, 1399, 1242, 1757, 1400, 1244, 1758,
        1401, 1246, 1759, 1402, 1248}]}, {
      Line3DBox[{633, 855, 1699, 634, 869, 1710, 661, 1812, 884, 676, 1816, 
       899, 691, 1822, 914, 706, 1831, 929, 721, 1842, 944, 1746, 736, 959, 
       1761, 751, 974, 1773, 766, 1857, 989, 781, 1861, 1004, 796, 1867, 1019,
        811, 1876, 1034, 826, 1887, 1049, 841}], 
      Line3DBox[{635, 856, 1700, 636, 870, 1711, 662, 885, 1721, 677, 1817, 
       900, 692, 1823, 915, 707, 1832, 930, 722, 1843, 945, 1747, 737, 960, 
       1762, 752, 975, 1774, 767, 990, 1784, 782, 1862, 1005, 797, 1868, 1020,
        812, 1877, 1035, 827, 1888, 1050, 842}], 
      Line3DBox[{637, 857, 1701, 638, 871, 1712, 663, 886, 1722, 678, 901, 
       1730, 693, 1824, 916, 708, 1833, 931, 723, 1844, 946, 1748, 738, 961, 
       1763, 753, 976, 1775, 768, 991, 1785, 783, 1006, 1793, 798, 1869, 1021,
        813, 1878, 1036, 828, 1889, 1051, 843}], 
      Line3DBox[{639, 858, 1702, 640, 872, 1713, 664, 887, 1723, 679, 902, 
       1731, 694, 917, 1737, 709, 1834, 932, 724, 1845, 947, 1749, 739, 962, 
       1764, 754, 977, 1776, 769, 992, 1786, 784, 1007, 1794, 799, 1022, 1800,
        814, 1879, 1037, 829, 1890, 1052, 844}], 
      Line3DBox[{641, 859, 1703, 642, 873, 1714, 665, 888, 1724, 680, 903, 
       1732, 695, 918, 1738, 710, 933, 1742, 725, 1846, 948, 1750, 740, 963, 
       1765, 755, 978, 1777, 770, 993, 1787, 785, 1008, 1795, 800, 1023, 1801,
        815, 1038, 1805, 830, 1891, 1053, 845}], 
      Line3DBox[{643, 860, 1704, 645, 874, 1715, 666, 889, 1725, 681, 904, 
       1733, 696, 919, 1739, 711, 934, 1743, 726, 949, 1751, 1752, 741, 964, 
       1766, 756, 979, 1778, 771, 994, 1788, 786, 1009, 1796, 801, 1024, 1802,
        816, 1039, 1806, 831, 1054, 1808, 846}], 
      Line3DBox[{647, 862, 1705, 648, 1811, 876, 668, 1814, 891, 683, 1819, 
       906, 698, 1826, 921, 713, 1836, 936, 728, 1848, 951, 1754, 743, 966, 
       1767, 758, 1856, 981, 773, 1859, 996, 788, 1864, 1011, 803, 1871, 1026,
        818, 1881, 1041, 833, 1893, 1056, 848}], 
      Line3DBox[{649, 863, 1706, 650, 877, 1716, 669, 1815, 892, 684, 1820, 
       907, 699, 1827, 922, 714, 1837, 937, 729, 1849, 952, 1755, 744, 967, 
       1768, 759, 982, 1779, 774, 1860, 997, 789, 1865, 1012, 804, 1872, 1027,
        819, 1882, 1042, 834, 1894, 1057, 849}], 
      Line3DBox[{651, 864, 1707, 652, 878, 1717, 670, 893, 1726, 685, 1821, 
       908, 700, 1828, 923, 715, 1838, 938, 730, 1850, 953, 1756, 745, 968, 
       1769, 760, 983, 1780, 775, 998, 1789, 790, 1866, 1013, 805, 1873, 1028,
        820, 1883, 1043, 835, 1895, 1058, 850}], 
      Line3DBox[{653, 865, 1708, 654, 879, 1718, 671, 894, 1727, 686, 909, 
       1734, 701, 1829, 924, 716, 1839, 939, 731, 1851, 954, 1757, 746, 969, 
       1770, 761, 984, 1781, 776, 999, 1790, 791, 1014, 1797, 806, 1874, 1029,
        821, 1884, 1044, 836, 1896, 1059, 851}], 
      Line3DBox[{655, 866, 1709, 656, 880, 1719, 672, 895, 1728, 687, 910, 
       1735, 702, 925, 1740, 717, 1840, 940, 732, 1852, 955, 1758, 747, 970, 
       1771, 762, 985, 1782, 777, 1000, 1791, 792, 1015, 1798, 807, 1030, 
       1803, 822, 1885, 1045, 837, 1897, 1060, 852}], 
      Line3DBox[{657, 1062, 1901, 1063, 658, 881, 1720, 673, 896, 1729, 688, 
       911, 1736, 703, 926, 1741, 718, 941, 1744, 733, 1853, 956, 1759, 748, 
       971, 1772, 763, 986, 1783, 778, 1001, 1792, 793, 1016, 1799, 808, 1031,
        1804, 823, 1046, 1807, 838, 1898, 1077, 1078, 1079}], 
      Line3DBox[CompressedData["
1:eJwV0MdJhFEUgNFrAAULENy5cGEHY86OOYyOOc5vDjMimHMHggUIFiBYgGAB
ggUIFiBYgODCM4vDve9+u1ebK2TyJRGRkC6LqC6P6KGbXXa4qYhIaZX2bbrY
4tR906zXftmwd7LOibZm1rh/k9g7uHbPmatUuX+yYt9zbzeXWeKvNOJdu3Jf
9G5jgXl+tFftUpvzbmWWGb60W/dnfdq7hSmyXLh/6I/apHczExy7Z8w37V4b
tzcxxpE2ar5od9qIvZFz92FziCftUBss/pl7gzlAPw9aop2593mnSNNb/CMt
q+Xt+xxQoI5/LBYsGg==
       "]], 
      Line3DBox[{840, 1048, 1076, 1886, 825, 1033, 1075, 1875, 810, 1018, 
       1908, 1074, 795, 1003, 1907, 1073, 780, 988, 1906, 1072, 765, 973, 
       1905, 1071, 750, 1760, 958, 1070, 735, 1745, 943, 1069, 1841, 720, 928,
        1068, 1830, 705, 913, 1904, 1067, 690, 898, 1903, 1066, 675, 883, 
       1902, 1065, 660, 868, 1064, 632, 1698, 854, 1132, 1137}], 
      Line3DBox[{847, 1055, 1892, 832, 1040, 1880, 817, 1025, 1870, 802, 1010,
        1863, 787, 995, 1858, 772, 980, 1855, 757, 965, 1854, 742, 1753, 950, 
       1847, 727, 935, 1835, 712, 920, 1825, 697, 905, 1818, 682, 890, 1813, 
       667, 875, 1810, 646, 861, 1809, 644}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXlUjd/7P2woERoRDTIVJRkzRC6i+ZzTPCrRJM2D5tJgqIhKI6VCVEgq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    "]],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["x", "10"], TraditionalForm], 
    FormBox[
     SubscriptBox["x", "3"], TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  BaseStyle->{FontWeight -> "Bold", FontSize -> 16},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 35}, {0, 1}, {-0.03752778211492114, 1.1866234071704271`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.560033699335*^9, 3.560139549158*^9, 3.560217526057*^9, 
  3.560386107665*^9, 3.560386437368*^9, 3.5603867238050003`*^9, 
  3.560388186585*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Partial derivative of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "2"], " "}]], "Input"],
 "with respect to ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 "   "
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 3.559072434646*^9}}],

Cell["\<\
The following expression is computed by differentiating the second solution \
to the invariant.  \
\>", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590722689969997`*^9, 
  3.559072344686*^9}, {3.559072495887*^9, 3.559072508594*^9}, {
  3.560026746849*^9, 3.5600267478719997`*^9}, {3.5600276218389997`*^9, 
  3.5600276306540003`*^9}, {3.560142251604*^9, 3.560142272508*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d2", " ", "=", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"D", "[", 
    RowBox[{"sol2", ",", 
     SubscriptBox["x", "10"]}], "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.559072451211*^9, 3.559072456942*^9}, {3.56002765465*^9, 
  3.560027666178*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "a5"}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a4", " ", "a5"}], "-", 
         RowBox[{"2", " ", "a6"}]}], ")"}], " ", 
       SubscriptBox["x", "3"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", "a3"}], "+", 
         SuperscriptBox["a5", "2"]}], ")"}], " ", 
       SubscriptBox["x", "10"]}]}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a4", " ", 
           SubscriptBox["x", "3"]}], "+", 
          RowBox[{"a5", " ", 
           SubscriptBox["x", "10"]}]}], ")"}], "2"], "-", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a2", " ", 
           SubsuperscriptBox["x", "3", "2"]}], "+", 
          RowBox[{"a6", " ", 
           SubscriptBox["x", "3"], " ", 
           SubscriptBox["x", "10"]}], "+", 
          RowBox[{"a3", " ", 
           SubsuperscriptBox["x", "10", "2"]}]}], ")"}]}]}]]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.559072457365*^9, 3.559075301168*^9, 3.559076385771*^9, {3.560027657554*^9,
    3.560027667888*^9}, 3.560033522947*^9, 3.560139550645*^9, 
   3.560217527543*^9, 3.5603861093*^9, 3.560386438986*^9, 
   3.5603867253129997`*^9, 3.5603881881879997`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot of the partial derivative in terms of ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]]
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073175014*^9}}],

Cell["The flatness of this plot indicates robust behavior. ", "Text",
 CellChangeTimes->{{3.411442011168613*^9, 3.411442072095045*^9}, {
  3.559069874384*^9, 3.559070007031*^9}, {3.5590722689969997`*^9, 
  3.559072344686*^9}, {3.559072495887*^9, 3.559072508594*^9}, {
  3.560026746849*^9, 3.5600267478719997`*^9}, {3.5600276218389997`*^9, 
  3.5600276306540003`*^9}, {3.560142251604*^9, 3.560142301609*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"d2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
       "numericalValues"}], "/.", "xValues"}], ")"}], ",", "  ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "10"], ",", " ", "0", ",", " ", "35"}], "}"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "3"], ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", " ", "\[Rule]", " ", "Automatic"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.5"}], ",", " ", "0.1"}], "}"}]}], ",", "  ", 
   RowBox[{"BaseStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontWeight", " ", "\[Rule]", " ", "\"\<Bold\>\""}], ",", " ", 
      RowBox[{"FontSize", " ", "\[Rule]", " ", "16"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.560034231293*^9, 3.5600342334639997`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJy1nWdYFcfbhxcrtogt9ogJsUbFGjUqxy6WhGJvHHtFsNfosUZjVDwoRVSO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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgXUVFXbhmfO7NkvKhLSqTQiCNIC0iAiJSkoIGHQEoIgggUqgo2B2KhY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         "]], Polygon3DBox[CompressedData["
1:eJwtmgf8V9Mfxr/fM+6PFJK2QqUiUbIyk0pEkohIhGQ17L0yM1Jm2Vtly17F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         "]], Polygon3DBox[CompressedData["
1:eJwt13mgFWMbAPDTPbcTEb6PLBWytd8WLbd9VdGuRYRCCWnfpSJKlha0Jwol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         "]], Polygon3DBox[{{1313, 866, 992, 1587, 1146, 1147}}]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkslOlFEQhf8Lffe8AWHBgo0JD0BC4oIQIAYJIaR3LlnAkrSATIIgs7YM
MokCKvM8BWhlVtoRFryAC9+C76Tu4supvn1v/VV1KudJ3ePajCiKHkImvHBR
NI+uoUnIhEa4gBrO29ETKCVuRQ8hm/gZegwPiJvRnyGP8n2BAuIWdAuqYQN2
fBSllANdR6tgFa4gwf3naC/8J25AdyEO2/AZKuCbs/90ZxgdgSI4grR+c96J
focu4g70wFsN8+gtrCgnuu+thjlvtRUTT4XzH+oP/YA+gnN4B2VwqlxQDpew
BJVwDa/gH999ii6GmlX7DLninO+hu/BVNaOFMat/w9sbvX0ZPJAXg87ul6DT
3mahmfwJff1CU+gbNIu3Tehv9Ufcpd5C/erjU6hZtdfz5ky+o3ksxA3xa/nl
zYtkzPyTj+Not7P7O8681w70oHfcH3CWR28/Ev+VvzAkH7x5IC8W0E1ve5Ug
f5p4LPQ+7azHSeWK2TzlUZuzuc2gE848euts57R7o+pXvTibrb6rOeTGrH/N
YTN8d1Zz87bH2ucpZ7uinVlG3wd/5XM/5EMf3AN+oHaj
         "]], Polygon3DBox[CompressedData["
1:eJwtkUsvg1EQhufQs/cPRPoL2FuLYIGIiF0TaWJRawsbunCLhWvirgsSldAL
bfUiQYqSaJHwByz8C8/JzOLJ+845M+ebb6YrNjOSaBORKESg6kT6oBNfQZ9g
GKaJ6+idF8miE3CLT1E0ik9DnXgD/SR3KtzDi9P7Wc6eLeccXRStPcQP4gfQ
I6hxf4mOQwl/BY/cLxH/4JfRX+JudA1eYczea6DHXt+7x7/jt9E/4jhahj3o
Je5H96FBzhzawVkGfwbX+CZn3/gK7DrNv8FX4cBpvwWvOS38pLNar/1cwBe+
hMas53U063W+O/CGL8OKzbsnoj0/EA/Zv7Rgweaf85oT/mfVae1J+LZofgpy
TvsP+8mHnp3OL/RXgA9qkraPvNcdhV21wyYUvb43j2+G+aOnovvI2AzjNq8t
9B86FlSH
         "]], 
        Polygon3DBox[{{1464, 452, 453, 335, 1441}, {1438, 46, 446, 447, 
         1462}, {1439, 61, 448, 449, 1463}, {1461, 430, 429, 151, 1200}, {
         1458, 409, 408, 46, 1088}, {1061, 354, 441, 401, 1457}, {1145, 335, 
         421, 420, 1459}, {1456, 399, 400, 259, 1399}, {1446, 166, 462, 463, 
         1466}, {1172, 337, 424, 423, 1460}, {1445, 151, 460, 461, 
         1465}}]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt08lvjGEcwPFn3s5MW0trrb1aajkgIkIiDSJu4uKGSEpF0gtH/gN3EncH
ZxcHFwlKkEYPus3oSjHUvm9dfH6Nw6ff5/29ybzzzPO2+dS5I2dzKaVu9lnE
+ok/PfTSRz8DlLhbSKmsTxlkiGFG6HJvVMd4xnPG6TR/oS95RYXXPDZ/oxO8
5R3v+UC3ex/1E5/5wlcemn/T7/zgJ7+4bf5b//CXSaa4Zz6tM7GxzP7IqOK+
e3ktUKSaGnrMa3UOc5nHfB6Y12k9C1jIIvrMF+sSltLAMpbT794KXckqVrOG
R+aNupYmmlnHHfP12sIGNrKJzdy0hxNknI69mvXaVj72HN/DejKeqVM6oNNa
0hkta6pydpLTjMEY6VB8jg5rQUe0qKNarWM6oUXPOhPn6/qkNsRZ5L0zriva
qWW9oV16TW/pFb2uF/WqXtDLeokO6/N6TDv0kB7XVj2sW+Pd1EY96vepaLvn
1mub1nDQ/upcH4iz0v1xbro3zlBb4zx1j9bqbt0V5229M85ed8R7oNvjndBt
6rFpSzb7s6WW+N652dcolQzG///P/APeG2it
       "]], Line3DBox[CompressedData["
1:eJwl0jlPVFEYBuCDDr3/gFBY0JhAT2JHDBADhBBCR0JILLQ0IIsbMIAIuLAo
26DDqixuhEVRAVlkE03wD1D4L3xOKJ687/nOvXfumZns6lulNzNCCP1cToRw
SdYa/JN51lmywPqqfkUfyQzhmnW+PqoX6kX6mF6sV+kp/bpe554b1iX6M71O
L9PH9aReri8kzj877Z4K6wl9Qq/UP+qTepW+qd/WL+o1/LbOuRDCU30lPp8G
eujmr2vb5SeW4rP4xan5sUzyng+8Y938SB7SFt+LReb5Yu9A7tPKW+b4Y/5G
/mSPFmb4YT4rp9llh4ecmE/KqXhOtuO1PIjvZu+1TPOKrXhmjs3vy1T83hhj
gyPz7/IeI4wyzGfzb/Ird3nJEC9Ys7cez0MzAwzGc5n3x3vjNTTRyar5I3mH
vrjmOY3xvPZ65TJPqKeDx3SRy5nfqDrj/H/1H5uoXFA=
       "]]}, {
      Line3DBox[{1087, 1291, 1619, 1086, 1290, 1618, 1085, 1289, 1617, 1084, 
       1288, 1616, 1083, 1287, 1615, 1082, 1710, 1499, 1081, 1709, 1498, 1614,
        1080, 1286, 1613, 1079, 1285, 1612, 1078, 1284, 1611, 1077, 1283, 
       1610, 1076, 1282, 1609, 1075, 791, 1370, 1402, 1813, 291, 1408, 304, 
       1483}], Line3DBox[{1101, 1299, 1628, 1100, 1298, 1627, 1099, 1297, 
       1626, 1098, 1296, 1625, 1097, 1714, 1504, 1096, 1713, 1503, 1095, 1712,
        1502, 1624, 1094, 1295, 1623, 1093, 1294, 1622, 1092, 1293, 1621, 
       1091, 1292, 1620, 1090, 1711, 1501, 1089, 1800, 1500, 1372, 1403, 1591,
        1799, 1422, 1409, 1371, 1475}], 
      Line3DBox[{1115, 1305, 1635, 1114, 1304, 1634, 1113, 1303, 1633, 1112, 
       1720, 1510, 1111, 1719, 1509, 1110, 1718, 1508, 1109, 1717, 1507, 1632,
        1108, 1302, 1631, 1107, 1301, 1630, 1106, 1300, 1629, 1105, 1716, 
       1506, 1104, 1715, 1505, 1103, 1801, 1376, 1375, 1102, 1593, 1816, 1374,
        1410, 1373, 1485}], 
      Line3DBox[{1129, 1309, 1640, 1128, 1308, 1639, 1127, 1728, 1518, 1126, 
       1727, 1517, 1125, 1726, 1516, 1124, 1725, 1515, 1123, 1724, 1514, 1638,
        1122, 1307, 1637, 1121, 1306, 1636, 1120, 1723, 1513, 1119, 1722, 
       1512, 1118, 1721, 1511, 1117, 1802, 1380, 1379, 1116, 1808, 1428, 1378,
        1411, 1377, 1486}], 
      Line3DBox[{1143, 1311, 1643, 1142, 1739, 1528, 1141, 1738, 1527, 1140, 
       1737, 1526, 1139, 1736, 1525, 1138, 1735, 1524, 1137, 1734, 1523, 1642,
        1136, 1310, 1641, 1135, 1733, 1522, 1134, 1732, 1521, 1133, 1731, 
       1520, 1132, 1730, 1519, 1131, 1586, 1729, 1381, 1130, 1809, 1429, 1430,
        1412, 1449, 1448, 1480}], 
      Line3DBox[{1170, 1752, 1540, 1168, 1751, 1539, 1166, 1750, 1538, 1164, 
       1749, 1537, 1162, 1748, 1536, 1160, 1747, 1535, 1158, 1746, 1534, 1650,
        1156, 1745, 1533, 1154, 1744, 1532, 1152, 1743, 1531, 1150, 1742, 
       1530, 1148, 1741, 1529, 1146, 1587, 1740, 1382, 1144, 1594, 1817, 1431,
        1413, 1450, 1472}], 
      Line3DBox[{1185, 1337, 1671, 1184, 1336, 1670, 1183, 1335, 1669, 1182, 
       1334, 1668, 1181, 1333, 1667, 1180, 1332, 1666, 1179, 1753, 1542, 1665,
        1178, 1331, 1664, 1177, 1330, 1663, 1176, 1329, 1662, 1175, 1328, 
       1661, 1174, 1327, 1660, 1173, 1326, 1659, 1384, 1405, 1814, 1541, 1424,
        1415, 1443, 1477}], 
      Line3DBox[{1199, 1347, 1682, 1198, 1346, 1681, 1197, 1345, 1680, 1196, 
       1344, 1679, 1195, 1343, 1678, 1194, 1755, 1545, 1193, 1754, 1544, 1677,
        1192, 1342, 1676, 1191, 1341, 1675, 1190, 1340, 1674, 1189, 1339, 
       1673, 1188, 1338, 1672, 1187, 1803, 1543, 1386, 1406, 1815, 1426, 1425,
        1416, 1385, 1444, 1491}], 
      Line3DBox[{1213, 1355, 1691, 1212, 1354, 1690, 1211, 1353, 1689, 1210, 
       1352, 1688, 1209, 1759, 1550, 1208, 1758, 1549, 1207, 1757, 1548, 1687,
        1206, 1351, 1686, 1205, 1350, 1685, 1204, 1349, 1684, 1203, 1348, 
       1683, 1202, 1756, 1547, 1201, 1805, 1546, 1388, 1407, 1592, 1804, 1427,
        1417, 1387, 1479}], 
      Line3DBox[{1227, 1361, 1698, 1226, 1360, 1697, 1225, 1359, 1696, 1224, 
       1765, 1556, 1223, 1764, 1555, 1222, 1763, 1554, 1221, 1762, 1553, 1695,
        1220, 1358, 1694, 1219, 1357, 1693, 1218, 1356, 1692, 1217, 1761, 
       1552, 1216, 1760, 1551, 1215, 1806, 1392, 1391, 1214, 1595, 1818, 1390,
        1418, 1389, 1493}], 
      Line3DBox[{1241, 1365, 1703, 1240, 1364, 1702, 1239, 1773, 1564, 1238, 
       1772, 1563, 1237, 1771, 1562, 1236, 1770, 1561, 1235, 1769, 1560, 1701,
        1234, 1363, 1700, 1233, 1362, 1699, 1232, 1768, 1559, 1231, 1767, 
       1558, 1230, 1766, 1557, 1229, 1807, 1396, 1395, 1228, 1810, 1432, 1394,
        1419, 1393, 1494}], 
      Line3DBox[{1255, 1367, 1706, 1254, 1784, 1574, 1253, 1783, 1573, 1252, 
       1782, 1572, 1251, 1781, 1571, 1250, 1780, 1570, 1249, 1779, 1569, 1705,
        1248, 1366, 1704, 1247, 1778, 1568, 1246, 1777, 1567, 1245, 1776, 
       1566, 1244, 1775, 1565, 1243, 1588, 1774, 1397, 1242, 1811, 1433, 1434,
        1420, 1452, 1451, 1481}], 
      Line3DBox[{1269, 1400, 1797, 1590, 1268, 1796, 1585, 1267, 1795, 1584, 
       1266, 1794, 1583, 1265, 1793, 1582, 1264, 1792, 1581, 1263, 1791, 1580,
        1707, 1262, 1790, 1579, 1261, 1789, 1578, 1260, 1788, 1577, 1259, 
       1787, 1576, 1258, 1786, 1575, 1257, 1589, 1785, 1398, 1256, 1596, 1819,
        1436, 1421, 1435, 1473}], 
      Line3DBox[{1369, 1281, 1368, 1798, 1073, 1280, 1608, 1072, 1279, 1607, 
       1071, 1278, 1606, 1070, 1277, 1605, 1069, 1276, 1604, 1068, 1708, 1497,
        1603, 1067, 1275, 1602, 1066, 1274, 1601, 1065, 1273, 1600, 1064, 
       1272, 1599, 1063, 1271, 1598, 1062, 1270, 1597, 1453, 1454, 776, 1455, 
       1401, 1437, 1474}], 
      Line3DBox[{1476, 1442, 1414, 1423, 1812, 1312, 1404, 1383, 1644, 1313, 
       1147, 1645, 1314, 1149, 1646, 1315, 1151, 1647, 1316, 1153, 1648, 1317,
        1155, 1649, 1318, 1157, 1651, 1652, 1319, 1159, 1653, 1320, 1161, 
       1654, 1321, 1163, 1655, 1322, 1165, 1656, 1323, 1167, 1657, 1324, 1169,
        1658, 1325, 1171}]}, {
      Line3DBox[{556, 778, 1598, 557, 792, 1609, 584, 1711, 807, 599, 1715, 
       822, 614, 1721, 837, 629, 1730, 852, 644, 1741, 867, 1645, 659, 882, 
       1660, 674, 897, 1672, 689, 1756, 912, 704, 1760, 927, 719, 1766, 942, 
       734, 1775, 957, 749, 1786, 972, 764}], 
      Line3DBox[{558, 779, 1599, 559, 793, 1610, 585, 808, 1620, 600, 1716, 
       823, 615, 1722, 838, 630, 1731, 853, 645, 1742, 868, 1646, 660, 883, 
       1661, 675, 898, 1673, 690, 913, 1683, 705, 1761, 928, 720, 1767, 943, 
       735, 1776, 958, 750, 1787, 973, 765}], 
      Line3DBox[{560, 780, 1600, 561, 794, 1611, 586, 809, 1621, 601, 824, 
       1629, 616, 1723, 839, 631, 1732, 854, 646, 1743, 869, 1647, 661, 884, 
       1662, 676, 899, 1674, 691, 914, 1684, 706, 929, 1692, 721, 1768, 944, 
       736, 1777, 959, 751, 1788, 974, 766}], 
      Line3DBox[{562, 781, 1601, 563, 795, 1612, 587, 810, 1622, 602, 825, 
       1630, 617, 840, 1636, 632, 1733, 855, 647, 1744, 870, 1648, 662, 885, 
       1663, 677, 900, 1675, 692, 915, 1685, 707, 930, 1693, 722, 945, 1699, 
       737, 1778, 960, 752, 1789, 975, 767}], 
      Line3DBox[{564, 782, 1602, 565, 796, 1613, 588, 811, 1623, 603, 826, 
       1631, 618, 841, 1637, 633, 856, 1641, 648, 1745, 871, 1649, 663, 886, 
       1664, 678, 901, 1676, 693, 916, 1686, 708, 931, 1694, 723, 946, 1700, 
       738, 961, 1704, 753, 1790, 976, 768}], 
      Line3DBox[{566, 783, 1603, 568, 797, 1614, 589, 812, 1624, 604, 827, 
       1632, 619, 842, 1638, 634, 857, 1642, 649, 872, 1650, 1651, 664, 887, 
       1665, 679, 902, 1677, 694, 917, 1687, 709, 932, 1695, 724, 947, 1701, 
       739, 962, 1705, 754, 977, 1707, 769}], 
      Line3DBox[{570, 785, 1604, 571, 1710, 799, 591, 1713, 814, 606, 1718, 
       829, 621, 1725, 844, 636, 1735, 859, 651, 1747, 874, 1653, 666, 889, 
       1666, 681, 1755, 904, 696, 1758, 919, 711, 1763, 934, 726, 1770, 949, 
       741, 1780, 964, 756, 1792, 979, 771}], 
      Line3DBox[{572, 786, 1605, 573, 800, 1615, 592, 1714, 815, 607, 1719, 
       830, 622, 1726, 845, 637, 1736, 860, 652, 1748, 875, 1654, 667, 890, 
       1667, 682, 905, 1678, 697, 1759, 920, 712, 1764, 935, 727, 1771, 950, 
       742, 1781, 965, 757, 1793, 980, 772}], 
      Line3DBox[{574, 787, 1606, 575, 801, 1616, 593, 816, 1625, 608, 1720, 
       831, 623, 1727, 846, 638, 1737, 861, 653, 1749, 876, 1655, 668, 891, 
       1668, 683, 906, 1679, 698, 921, 1688, 713, 1765, 936, 728, 1772, 951, 
       743, 1782, 966, 758, 1794, 981, 773}], 
      Line3DBox[{576, 788, 1607, 577, 802, 1617, 594, 817, 1626, 609, 832, 
       1633, 624, 1728, 847, 639, 1738, 862, 654, 1750, 877, 1656, 669, 892, 
       1669, 684, 907, 1680, 699, 922, 1689, 714, 937, 1696, 729, 1773, 952, 
       744, 1783, 967, 759, 1795, 982, 774}], 
      Line3DBox[{578, 789, 1608, 579, 803, 1618, 595, 818, 1627, 610, 833, 
       1634, 625, 848, 1639, 640, 1739, 863, 655, 1751, 878, 1657, 670, 893, 
       1670, 685, 908, 1681, 700, 923, 1690, 715, 938, 1697, 730, 953, 1702, 
       745, 1784, 968, 760, 1796, 983, 775}], 
      Line3DBox[{580, 985, 1798, 986, 581, 804, 1619, 596, 819, 1628, 611, 
       834, 1635, 626, 849, 1640, 641, 864, 1643, 656, 1752, 879, 1658, 671, 
       894, 1671, 686, 909, 1682, 701, 924, 1691, 716, 939, 1698, 731, 954, 
       1703, 746, 969, 1706, 761, 1797, 1000, 1001, 1002}], 
      Line3DBox[CompressedData["
1:eJwVzclJQ2EYRuEvg944G5NcM6gYxY1rOxAsIGABDmsVLECwAMECBAsQLECw
AMG9CzuI82wcn7s4vN9/Drlpr293tnIRsYFePuKiEDFVjHi3LdtEK4noamdc
wfvNNmyFr9tr7YTLu1/tpJ3QUnupHXE594tt8jV3FefaARfuYf7ZXcl+i1Nt
L/sW/2efUObHcazteKfar33EGD+KQ63Kr3E/eMBI9n00+H29w33jHkN8mR+0
u9oy94U7DGT/p5XsprbE9XCLOp/w/VjVFrhPJPyN7eOLWNFS7xr/YbuY4aex
qJW82+5ZzGMOV9w/ZBMp7A==
       "]], 
      Line3DBox[{763, 971, 999, 1785, 748, 956, 998, 1774, 733, 941, 1807, 
       997, 718, 926, 1806, 996, 703, 911, 1805, 995, 688, 896, 1803, 994, 
       673, 1659, 881, 993, 658, 1644, 866, 992, 1740, 643, 851, 991, 1729, 
       628, 836, 1802, 990, 613, 821, 1801, 989, 598, 806, 1800, 988, 583, 
       791, 987, 555, 1597, 777, 1055, 1060}], 
      Line3DBox[{770, 978, 1791, 755, 963, 1779, 740, 948, 1769, 725, 933, 
       1762, 710, 918, 1757, 695, 903, 1754, 680, 888, 1753, 665, 1652, 873, 
       1746, 650, 858, 1734, 635, 843, 1724, 620, 828, 1717, 605, 813, 1712, 
       590, 798, 1709, 569, 784, 1708, 567}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvXlcjc3/P37KnqUiskRJUYkoJHJGimSvlC3ak7Jkqyx1kqWsESFLWZOQ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    "]],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["x", "10"], TraditionalForm], 
    FormBox[
     SubscriptBox["x", "3"], TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  BaseStyle->{FontWeight -> "Bold", FontSize -> 16},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0, 35}, {0, 1}, {-0.5, 0.1}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.559073157459*^9, 3.559075301922*^9, 3.559076386748*^9, 
  3.560034246558*^9, 3.560139563092*^9, 3.560217545693*^9, 3.560386123242*^9, 
  3.560386452781*^9, 3.560386741666*^9, 
  3.560388201684*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4) Explanation for robustness using the approximate conservation law\
\>", "Section",
 CellChangeTimes->{{3.411417440142596*^9, 3.411417461256724*^9}, {
  3.411442037532863*^9, 3.411442039375865*^9}, {3.411443676335696*^9, 
  3.411443677223529*^9}, {3.5590721755550003`*^9, 3.559072189133*^9}, {
  3.5600335436210003`*^9, 3.560033557981*^9}, {3.560134857053*^9, 
  3.560134858163*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Elimination of ",
 Cell[BoxData[
  SubscriptBox["x", 
   RowBox[{"10", " "}]]], "Input"],
 "or ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input"],
 " using the approximate conservation law for total IDH ",
 Cell[BoxData["  "], "Input"],
 " "
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.5600459013640003`*^9, 3.560045903699*^9}}],

Cell[TextData[{
 "Replacement rules from the conservation law and for fixing ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input",
  CellChangeTimes->{{3.5588822490620003`*^9, 3.558882284967*^9}, {
    3.558882317318*^9, 3.5588823514449997`*^9}, {3.558884419734*^9, 
    3.558884436906*^9}, {3.558893009483*^9, 3.55889304246*^9}, 
    3.558966854041*^9}],
 " at \[Epsilon]."
}], "Text",
 CellChangeTimes->{{3.411442085015283*^9, 3.411442117974307*^9}, {
  3.559072740424*^9, 3.55907277045*^9}, {3.5590728028050003`*^9, 
  3.559072815461*^9}, {3.559072909561*^9, 3.559072922998*^9}, {
  3.559072990675*^9, 3.5590729915889997`*^9}, {3.560045888006*^9, 
  3.56004592537*^9}, {3.560046859803*^9, 3.560046860992*^9}, {
  3.560134867641*^9, 3.560134874936*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"conservation1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "10"], "\[Rule]", 
     RowBox[{"T", " ", "-", 
      SubscriptBox["x", "2"], "-", 
      SubscriptBox["x", "3"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"conservation2", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "2"], "\[Rule]", 
     RowBox[{"T", " ", "-", 
      SubscriptBox["x", "3"], "-", 
      SubscriptBox["x", "10"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"small", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "3"], "\[Rule]", "\[Epsilon]"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.560046869373*^9, 3.5600469841879997`*^9}}],

Cell[TextData[{
 "Expression for ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input",
  CellChangeTimes->{{3.5588822490620003`*^9, 3.558882284967*^9}, {
    3.558882317318*^9, 3.5588823514449997`*^9}, {3.558884419734*^9, 
    3.558884436906*^9}, {3.558893009483*^9, 3.55889304246*^9}, 
    3.558966854041*^9}],
 " in terms of \[Epsilon] and ",
 StyleBox["T",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.411442085015283*^9, 3.411442117974307*^9}, {
  3.559072740424*^9, 3.55907277045*^9}, {3.5590728028050003`*^9, 
  3.559072815461*^9}, {3.559072909561*^9, 3.559072922998*^9}, {
  3.559072990675*^9, 3.5590729915889997`*^9}, {3.560045888006*^9, 
  3.56004592537*^9}, {3.560046859803*^9, 3.560046860992*^9}, {
  3.560047103984*^9, 3.560047133526*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solx2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sol2", "/.", "conservation1"}], "/.", "small"}], ")"}], 
       "\[Equal]", 
       SubscriptBox["x", "2"]}], ",", " ", 
      SubscriptBox["x", "2"]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["x", "2"], "/.", 
  RowBox[{"solx2", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.560046991039*^9, 3.56004706477*^9}, {
   3.5600471937650003`*^9, 3.560047203903*^9}, {3.560047237816*^9, 
   3.56004725355*^9}, 3.5600478132546*^9, {3.5600478897566*^9, 
   3.5600479099356003`*^9}, {3.5600480137925997`*^9, 3.5600480234576*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "a3", "-", "a5"}], ")"}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "a3", " ", "T"}], "-", 
    RowBox[{"a5", " ", "T"}], "-", 
    RowBox[{"2", " ", "a3", " ", "\[Epsilon]"}], "-", 
    RowBox[{"a4", " ", "\[Epsilon]"}], "+", 
    RowBox[{"a5", " ", "\[Epsilon]"}], "+", 
    RowBox[{"a6", " ", "\[Epsilon]"}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a3", " ", "T"}], "-", 
         RowBox[{"a5", " ", "T"}], "-", 
         RowBox[{"2", " ", "a3", " ", "\[Epsilon]"}], "-", 
         RowBox[{"a4", " ", "\[Epsilon]"}], "+", 
         RowBox[{"a5", " ", "\[Epsilon]"}], "+", 
         RowBox[{"a6", " ", "\[Epsilon]"}]}], ")"}], "2"], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "a3", "-", "a5"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a3", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"T", "-", "\[Epsilon]"}], ")"}], "2"]}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a6", " ", 
             RowBox[{"(", 
              RowBox[{"T", "-", "\[Epsilon]"}], ")"}]}], "+", 
            RowBox[{"a2", " ", "\[Epsilon]"}]}], ")"}]}]}], ")"}]}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.560047204453*^9, {3.560047243365*^9, 3.560047254112*^9}, 
   3.5600478138996*^9, {3.5600478904175997`*^9, 3.5600479103716*^9}, {
   3.5600480199026003`*^9, 3.5600480264396*^9}, 3.560139563709*^9, 
   3.560217546318*^9, 3.56038612392*^9, 3.560386453459*^9, 3.560386743133*^9, 
   3.560388202337*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot of ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]],
 " in terms of total IDH (",
 StyleBox["T",
  FontSlant->"Italic"],
 ") at a particular \[Epsilon] value "
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"epsilonValue", "=", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0.5"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.560047527719*^9, 3.560047554631*^9}, 3.5600477687746*^9}
  ],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "2"], "/.", 
         RowBox[{"solx2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "/.", "coefficients"}], "/.", 
       "parameterClasses"}], "/.", "numericalValues"}], "/.", 
     "epsilonValue"}], ")"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"T", ",", " ", "0", ",", " ", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5600476334776*^9, 3.5600476372286*^9}, {
  3.5600476684426003`*^9, 3.5600476742116003`*^9}, {3.5600477309296*^9, 
  3.5600477386275997`*^9}, {3.5600477758756*^9, 3.5600477877316*^9}, {
  3.5600479223386*^9, 3.5600479224676*^9}, {3.5600480397256002`*^9, 
  3.5600480867256002`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAArDnqcuIJ4D8AAAAAAAAAAGc/0Zns
cuM/tEtVpacjvD8Aova624vjPybYaAbF97w/mAQc3Mqk4z84P2/eSsy9P8jJ
Zh6p1uM/YQVTSaZ2vz8oVPyiZTrkP5IdBgWpaME/6GgnrN4B5T/MoH2sKNPE
P4DLTM3NGuU/RyDWOm5CxT8YLnLuvDPlP6DL0yVAssU/SPO8MJtl5T/Nx+ZP
uJPGP6l9UrVXyeU/6IMP7KJfyD9C4HfWRuLlP6ivGsPv1Mg/2kKd9zX75T+E
b+SkXkvJPwoI6DkULeY/0e8ZeDE8yj9qkn2+0JDmP1DiN6xuM8w/AvWi37+p
5j8flO/alLfMP5pXyACvwuY/qbzQAEg/zT8yuu0hntvmP1qCtBRay80/yhwT
Q4305j8Oc5Is9FzOP2J/OGR8Dec/hwnjANL1zj/64V2FaybnP1jR40W+mM8/
kkSDplo/5z/WEpZQYSXQPyunqMdJWOc/GGcRI3SL0D/ECc7oOHHnPy/+VH9s
EdE/FLtgebB95z9cKNvdPZfRP/8Eypc=
     "]], LineBox[CompressedData["
1:eJwV1Xk81NsbB/BBKEuSUmSf5JIlbRR5juQirrKXUtfQhmwXWaIFWUqGbFFc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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["T", TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.5600477406666*^9, {3.5600477723816*^9, 3.5600477884186*^9}, 
   3.5600479231246*^9, {3.5600480373716*^9, 3.5600480908716*^9}, 
   3.560139567745*^9, 3.560217551961*^9, 3.5603861282799997`*^9, 
   3.560386457738*^9, 3.5603867479639997`*^9, 3.5603882064560003`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot of ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]],
 " in terms of ",
 StyleBox["T ",
  FontSlant->"Italic"],
 " at a fixed ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input",
  CellChangeTimes->CompressedData["
1:eJwtzEsow3EAB/B5xGLaYhbbEBKWltWS95pd3GgUNTYtU9bfazMSJ6bMYZQk
slkOK+PCAdEuzOTRsFrm1ZKyNiUHWVnJ7zsO3z5969s3Xz0g18TTaDQ+Cdw1
fkYrh8PSngiLWUUU9keLoF9VUAzZkrCimuiY3FBBe1lC73+noGt71vrXLTYY
2nuQ1hBN3vRGOOjx6yArdGuAl53j7FrijybCgRL3IxfaNp/50P0oaoXt59w2
KMhKU0D+m5eCMn6AVUfM5bxnwJlpts9MPD0QBqA9xSiaJyaejFVBxlCFC1qV
+pjOlx0PzMwJ+qB43X4PD/evnqCjy7pgIWbrfYsw50y2Zon93W1BNaujO9UQ
lr5ef/dCRnzyBCx88MWkglNHDKJ5yX4MRfRyD1x1GW+g4EIsnxoJS5M+tC2w
ob5ZAXW8UiVcoed1QzqvRwNLmCrtHNEp/6JgoMlE9Y2S3XKcDv4CkT/bgQ==

   "]],
 " value "
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073243922*^9}, {3.559076081921*^9, 
  3.559076090491*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"solx10", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sol2", "/.", "conservation2"}], "/.", "small"}], ")"}], 
       "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "/.", "conservation2"}], ")"}]}], ",", " ", 
      SubscriptBox["x", "10"]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.560046991039*^9, 3.56004706477*^9}, {
   3.5600471937650003`*^9, 3.560047203903*^9}, {3.560047237816*^9, 
   3.56004725355*^9}, 3.5600478132546*^9, {3.5600478897566*^9, 
   3.5600479099356003`*^9}, {3.5600480137925997`*^9, 3.5600480234576*^9}, {
   3.5600481346156*^9, 3.5600481640755997`*^9}, {3.5600482969816*^9, 
   3.5600482976146*^9}, {3.5600483525226*^9, 3.5600483590755997`*^9}, {
   3.5600484651296*^9, 3.5600484737406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "10"], "/.", 
          RowBox[{"solx10", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "/.", "coefficients"}], "/.", 
        "small"}], "/.", "parameterClasses"}], "/.", "numericalValues"}], "/.",
      "epsilonValue"}], ")"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"T", ",", " ", "0", ",", " ", "10"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "10"}], "}"}]}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5600481918496*^9, 3.5600482066436*^9}, {
  3.5600483776906*^9, 3.5600483778196*^9}, {3.5600484302546*^9, 
  3.5600484426706*^9}, {3.5600486323006*^9, 3.5600486423456*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtxQswGwYAh3GTjpJxiuhjRmo09RhF7Rodf5JNx1B6xaYV5GhQz7qEkGQO
LY61pDi2msc6nUfn6LXKaDPMSlyEFF0iKlzZggst571uu9t397vvODPlQqy2
lpaWx7/+e42AqeMcU+xJmTw7UHVVgAEZ2T+MHI9Q0AIdGQK8HXySRyZzofjF
QN4cJECN6BvLd8lF6G17PRHmJkCiBztp07IapfkSKnefD9luXPmqZROeNd9p
Ki/kg/O7xSlNezO8U6z0OFw+jt1+Ll6ht+KB+w+XqAl8MO28CEusNuiKElgx
X/CR2Ursej3VgbyEdxq93+NDVzFHWbHswlHnl5KnBTy8EPWyl//sAn8nv62M
w0NzY1X/Uns36mWTu56xPAReC4xU03vAmWVs2NJ4qNTrrlxkPYVTQO2g6042
jO88016b6sOxABN6AzMb9cO1aUuWQ+Domn3UY5SF9aqHdi9LhuDyiqFe3+TC
hyWeH98ewpan75Z6hotlwmZIt2wYQrvoNv1WLs54BLoXFYxAaboj3aJxIW3b
06ZoRkEyCxnLZmbCGHoMA0cpajuqWrY/zcTZE+XuBTFSCPv7w8iUTNxcb3qT
NSbFr+yQpWh1Bk6XTcQyW8bQZP69V2FiBr4edvBzjpThWxLPQhrBwU/tnSda
KmRoPKfx0XfnYLyKRrAZkSHnYPz5URIH1qwve45Qn+Mv2/rOVTEbw4R8Ry2T
CdRSb4b6u7Bh5qEwHh2cxMzywds6r9LhZX1F8/n+JMS5wogHj9MRT1wT97lO
gfvQKa63OB09f+hcf1Q3hQ9E5F65UzqYHJfNmqwXuGfeUCFJuYaf24oUiY5y
+GaogseGU6E2Vpf4RcsxVddnbVWZCgrHz/NkuRwSin/uj1GpqPuEWD+/LYe0
Mqw7aiEFwqGSK+G/KfD3vtte0fvJkDisHD6zpcAl320L17tJIJYGDJHsp3G+
gMZX2yUhP9TQYax0GjzL+7Rgl0Rw5m+tnbushLcJbTGXkoAOn9UGm1tKSLpJ
1da18dA0BV0k9CnxqCJngGkaj7jUQ51PKDMINiqISdtkIXxfyHN7M4OeAX6g
siYWtURx3qHPZtEUfXq8+qsoeHpkX85hzMLcNO4AlR6J6WR7N03GLEQ1QZq7
4ggcGS9eGGmeBXONcbJjIBxlVf6+hUYqpKctXNUNuohTw3vHN21VoFhssDu/
uwDJbutOLF2FG5PGkQJlEPQjDVrpHBXura192J/nhzwbieFbhQrUVeW+kPgx
rMIEi0kbKhxmrJYmN9hDVOgomjacQ/mBnvvcGyQcJTymZlnMQev//gE9Z9N1

     "]], LineBox[CompressedData["
1:eJwVkWs41HkcxWdIO80gg0Zoxsz/b5tMhH1C99+3bKVQEWlF20y5hLIVZTNK
7mnVJE9pJvdNcisWoVwiUcZQyqxMq3V9IuM6GClrX5znvDufc57D4gU6e6kQ
CATnRf3vqb/Px/H2y9HsE5Lm65HHiNng7NnsIkdndUaAqF+MErepREoD5Wgp
SeXDLyUlSK28KKc3Xo66O9jTIn4ZCrHkSkbvy5Em7pQ5QSxHQ7laU19r5Ui1
anPET8crkIdxrT5JJkdJc1F6mwoqUWtKINKdkSMO7d6sdOApKhFI4k3NRtEB
Kj9KalONLp//g+V5dxTxKdY593Y8R2RWFLt7wxgaKLxAIm1uQE1bbppf2jmG
MvYZeDoWNKCYw6k2dOcx5JY28WKU8RKpCMp3H/EfQ0LrAE4YoRHNff/iI00Z
Q0yK3d62qiY0LHPNaVUZR72heWZ+bDESJ7NNasXjKF8izsjxfYOuazVzMo5N
Iqv0SxMdw1LE63KpURVPI+t/q2TxAz3oTEMUL5A9h8QBspiJh59R0W/qB1fu
+YYY1+XZ0qlRlBHqP2ThRoCj67TllbxJFJE27zT1hQjeM+Fd4YJpRGj/BM8u
qsJCZ9e20QIlWh3kHeLCUYPGBgf/Qc1vqE9x5xClailcJSz3HjIgwN5+v7DE
MyTY2rN+rWUbEfb1CdYyGGTY/wh/FBCmCkP1vPCmAgo83x2cXqyhBuuoHXTb
XzXgY19at6RmKZCRgiub1AS/3MhMpQsJdo+4z2CuWsC/4kKfp5Dh77oTRHdT
Kni2efnPV1KgNO7FUaaCCsfqK3M0HTXAWy34k0SiDW4W9fVKwnI4fja0VF2o
A+s77Oa/2muBuc9aiQNXF/REIptQHSq0aptSgjeugBRritHgMBWeFkaITFVp
8NfOTPbHUm0IJXIOiD/SgB194kuNQAfIsot2p0v0gFdlY5Llowv92aykNP5K
MNFW7dGyWAFJa/SXVLjqg4107KT/MhoIhN6NXKYBVCSY3zrwjgbuSZ4S9UED
IJt0hFuL9GD25/vKtGpDCHKK3bXs3Ero7d8RUhe7Clao+3d6b9GHzK2Whi1c
Otxo9dhZRDOAguhgqo8ZA1qecBNjegwg1vW4vaqCAXfC85s8cg3BSpbxMLbF
CKKrWz4YRa6CZBNRQYs9E6bcOgdOOdLhcm1Csn0FE155mEpy1jDA0dD1/mtj
FpzPIeb1LTBg++nGI9SrLNCVuiflNRlB2iqesVjBgsSa+nxzJyYY1z+4ve8I
BhsuDOi3ljFBYFbHeVuNwUz6BXKgAQu8J5e8ecXBoc9a5hsdwwJe0QTz6g0c
Ct/fdOMOsyAg4uD83ps4XNuUXYyPsCD4YIlU/RYO7W8qNAbkLIhTBF8X3MZB
lPxPvd8ECwo3Kr/eScFBmMCwCFKyQPl8oSM7D4fuPSGk2B8wELxVT3jRiENd
blJ5Po6BMOuUb8wrHPLabugE/ohBVpDE1q4ZhxMW8act2RiU0QRzzRIczFL5
xmUcDGTuOr7t73Hw23hYUGOJAbtX37and7Ff+pDPW4SBRclFxp/9ODhf6qxL
2o7BpugupdcgDvy7jXQ3Wwwc2CmPPw/h0BaX0d61C4Oz/kzG+Pgi38kB9Tti
wN9yRVk8iUMq00r4YD8G0Ro974IUODxeR1ecdMIg+VHWtdlZHGjLhnPlLhhk
hi/xqZzD4cP7NrWiQ9hijtcO/vzi/p7SY+cOY1CCvaRv+46DwFz41Modg+rJ
1cqFBRymn4XRZhd/+Q9pqVZM
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["T", TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {0, 10}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.559073275401*^9, 3.5590753020030003`*^9, 3.559076386901*^9, 
   3.5600481714016*^9, {3.5600482022376003`*^9, 3.5600482331116*^9}, {
   3.5600483743416*^9, 3.5600483797256002`*^9}, {3.5600484364316*^9, 
   3.5600484459346*^9}, 3.5600484804056*^9, {3.5600486368196*^9, 
   3.5600486466486*^9}, 3.5601395726280003`*^9, 3.5602175580769997`*^9, 
   3.5603861329849997`*^9, 3.56038646255*^9, 3.560386752921*^9, 
   3.5603882111619997`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5) Dominant terms in the invariant", "Section",
 CellChangeTimes->{{3.411417440142596*^9, 3.411417461256724*^9}, {
  3.411442037532863*^9, 3.411442039375865*^9}, {3.411443676335696*^9, 
  3.411443677223529*^9}, {3.5590721755550003`*^9, 3.559072189133*^9}, {
  3.5600335436210003`*^9, 3.560033557981*^9}, {3.560124265645*^9, 
  3.560124274198*^9}}],

Cell[CellGroupData[{

Cell["Minimum and maximum terms in the coefficients", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}, {3.560135102718*^9, 3.560135111693*^9}}],

Cell[TextData[{
 "Each monomial in the numerator of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "2"], "..."}], 
   SubscriptBox["a", "6"]}]], "Input"],
 " is written below",
 Cell[BoxData[
  RowBox[{".", " "}]], "Input"]
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
   3.559073414949*^9, 3.559073439383*^9}, {3.5591755123310003`*^9, 
   3.559175546336*^9}, 3.5601243234040003`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"mon2", "=", 
  RowBox[{"MonomialList", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      SubscriptBox["x", "3"], ",", "2"}], "]"}], "/.", "parameterClasses"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mon3", "=", 
  RowBox[{"MonomialList", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      SubscriptBox["x", "10"], ",", "2"}], "]"}], "/.", "parameterClasses"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mon4", "=", 
  RowBox[{"MonomialList", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      RowBox[{
       SubscriptBox["x", "2"], 
       SubscriptBox["x", "3"]}], ",", "1"}], "]"}], "/.", 
    "parameterClasses"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mon5", "=", 
  RowBox[{"MonomialList", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      RowBox[{
       SubscriptBox["x", "2"], 
       SubscriptBox["x", "10"]}], ",", "1"}], "]"}], "/.", 
    "parameterClasses"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mon6", "=", 
  RowBox[{"MonomialList", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"invar1", ",", 
      RowBox[{
       SubscriptBox["x", "3"], 
       SubscriptBox["x", "10"]}], ",", "1"}], "]"}], "/.", 
    "parameterClasses"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5600485033026*^9, 3.5600485425436*^9}, {
  3.5602874148129997`*^9, 3.560287426499*^9}, {3.560287464418*^9, 
  3.560287467568*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "4"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559073378277*^9, 3.5590753020480003`*^9, 3.55907638694*^9, {
   3.5600484972956*^9, 3.5600485090755997`*^9}, 3.5600485430336*^9, 
   3.560101821197*^9, 3.5601395727060003`*^9, 3.560217558144*^9, 
   3.560287468092*^9, 3.560386133064*^9, 3.560386462611*^9, 3.560386752984*^9,
    3.560388211244*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "6"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{"2", " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "off", "5"]}], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "off", "4"]}], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559073378277*^9, 3.5590753020480003`*^9, 3.55907638694*^9, {
   3.5600484972956*^9, 3.5600485090755997`*^9}, 3.5600485430336*^9, 
   3.560101821197*^9, 3.5601395727060003`*^9, 3.560217558144*^9, 
   3.560287468092*^9, 3.560386133064*^9, 3.560386462611*^9, 3.560386752984*^9,
    3.560388211248*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "5"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "5"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "4"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "4"]}], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "4"]}], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"6", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "3"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "3"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "3"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559073378277*^9, 3.5590753020480003`*^9, 3.55907638694*^9, {
   3.5600484972956*^9, 3.5600485090755997`*^9}, 3.5600485430336*^9, 
   3.560101821197*^9, 3.5601395727060003`*^9, 3.560217558144*^9, 
   3.560287468092*^9, 3.560386133064*^9, 3.560386462611*^9, 3.560386752984*^9,
    3.5603882112530003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "5"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "5"}], " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "5"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubscriptBox["\[Kappa]", "cat"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"2", " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559073378277*^9, 3.5590753020480003`*^9, 3.55907638694*^9, {
   3.5600484972956*^9, 3.5600485090755997`*^9}, 3.5600485430336*^9, 
   3.560101821197*^9, 3.5601395727060003`*^9, 3.560217558144*^9, 
   3.560287468092*^9, 3.560386133064*^9, 3.560386462611*^9, 3.560386752984*^9,
    3.560388211292*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["k", "cat", "4"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "4"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "3"]}], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "cat", "2"]}], " ", 
    SubscriptBox["k", "off"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubscriptBox["k", "off"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "5"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "cat", "2"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{"3", " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubscriptBox["k", "cat"], " ", 
    SubsuperscriptBox["k", "off", "3"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["k", "cat"]}], " ", 
    SubsuperscriptBox["k", "off", "2"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "4"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "off", "5"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "off", "4"]}], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["k", "off", "4"]}], " ", 
    SubsuperscriptBox["k", "on", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
    SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
    SubscriptBox["\[Kappa]", "on"]}], ",", 
   RowBox[{
    SubsuperscriptBox["k", "off", "4"], " ", 
    SubscriptBox["k", "on"], " ", 
    SubsuperscriptBox["\[Kappa]", "cat", "3"], " ", 
    SubscriptBox["\[Kappa]", "off"], " ", 
    SubsuperscriptBox["\[Kappa]", "on", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559073378277*^9, 3.5590753020480003`*^9, 3.55907638694*^9, {
   3.5600484972956*^9, 3.5600485090755997`*^9}, 3.5600485430336*^9, 
   3.560101821197*^9, 3.5601395727060003`*^9, 3.560217558144*^9, 
   3.560287468092*^9, 3.560386133064*^9, 3.560386462611*^9, 3.560386752984*^9,
    3.560388211299*^9}]
}, Open  ]],

Cell["\<\
At the reference parameter values, the largest and smallest monomials in each \
coefficient have the following (normalized) values.\
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073492156*^9, 3.559073528608*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"max2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", "mon2", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Min", "[", "mon2", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", "mon3", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Min", "[", "mon3", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", "mon4", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Min", "[", "mon4", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max5", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", "mon5", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min5", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Min", "[", "mon5", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max6", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Max", "[", "mon6", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min6", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Min", "[", "mon6", "]"}], "/", "norm"}], ")"}], "/.", 
     "parameterClasses"}], "/.", "numericalValues"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max", "=", 
   RowBox[{"List", "[", 
    RowBox[{"max2", ",", "max3", ",", "max4", ",", "max5", ",", "max6"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"List", "[", 
    RowBox[{"min2", ",", "min3", ",", "min4", ",", "min5", ",", "min6"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.560101828731*^9, 3.560101930749*^9}, {3.5601021149*^9, 
  3.5601021603050003`*^9}, {3.560287477488*^9, 3.560287499561*^9}, {
  3.560292107212*^9, 3.560292159199*^9}, {3.560292374533*^9, 
  3.560292374776*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(3\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(4\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(5\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(a\), \(6\)]\)\>\""}], "}"}], ",", 
     RowBox[{"Prepend", "[", 
      RowBox[{"max", ",", "\"\<max\>\""}], "]"}], ",", 
     RowBox[{"Prepend", "[", 
      RowBox[{"min", ",", "\"\<min\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56028808025*^9, 3.5602880953529997`*^9}, {
  3.56029198215*^9, 3.560292037132*^9}, {3.560292206476*^9, 
  3.560292266046*^9}, {3.560292326174*^9, 3.560292361135*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(3\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(4\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(5\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(a\\), \\(6\\)]\\)\"\>"},
    {"\<\"max\"\>", "71.72406504955343`", "27.353948277827136`", 
     "62.17924716218979`", "25379.284555995826`", "9679.089390615758`"},
    {"\<\"min\"\>", 
     RowBox[{"-", "41.24133740349322`"}], 
     RowBox[{"-", "15.728520259750605`"}], 
     RowBox[{"-", "188.06577591588592`"}], 
     RowBox[{"-", "14593.0886196976`"}], 
     RowBox[{"-", "16833.198940201317`"}]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{"Text"}}, "Rows" -> {{"Text"}}},
   GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.560292349117*^9, 3.560292381653*^9}, 3.560386133144*^9, 
   3.560386462749*^9, 3.560386753119*^9, 3.560388211363*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Dominant terms for ",
 Cell[BoxData[
  SubscriptBox["a", "5"]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 " and ",
 Cell[BoxData[
  SubscriptBox["a", "6"]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"]
}], "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}, {3.560135137061*^9, 3.560135164969*^9}}],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "5"], " ", "and", " ", 
   SubscriptBox["a", "6"], " ", "are", " ", "approximated", " ", "to", " ", 
   "99", "%", " ", "accuarcy", " ", "by", " ", "their", " ", "two", " ", 
   "largest", " ", "terms", " "}]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox[".",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073492156*^9, 3.559073528608*^9}, {3.559073588304*^9, 
  3.559073617961*^9}, {3.560135172748*^9, 3.560135177499*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"approxa5", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"max5", "+", "min5"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"approxa6", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"max6", "+", "min6"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"approxa5", "/", "a5"}], "/.", "coefficients"}], "/.", 
   "parameterClasses"}], "/.", "numericalValues"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"approxa6", "/", "a6"}], "/.", "coefficients"}], "/.", 
   "parameterClasses"}], "/.", "numericalValues"}]}], "Input",
 CellChangeTimes->{
  3.560106752127*^9, {3.5601220842460003`*^9, 3.56012211188*^9}, {
   3.56012261084*^9, 3.560122617624*^9}, {3.560122649908*^9, 
   3.5601226805620003`*^9}}],

Cell[BoxData["10786.195936298225`"], "Output",
 CellChangeTimes->{
  3.5601221045690002`*^9, 3.560122617942*^9, {3.560122657848*^9, 
   3.560122680808*^9}, 3.560139572877*^9, 3.560217558316*^9, 
   3.560386133189*^9, 3.560386462793*^9, 3.560386753164*^9, 3.560388211427*^9}
  ],

Cell[BoxData[
 RowBox[{"-", "7154.109549585559`"}]], "Output",
 CellChangeTimes->{
  3.5601221045690002`*^9, 3.560122617942*^9, {3.560122657848*^9, 
   3.560122680808*^9}, 3.560139572877*^9, 3.560217558316*^9, 
   3.560386133189*^9, 3.560386462793*^9, 3.560386753164*^9, 
   3.5603882114300003`*^9}],

Cell[BoxData["0.9920998170748878`"], "Output",
 CellChangeTimes->{
  3.5601221045690002`*^9, 3.560122617942*^9, {3.560122657848*^9, 
   3.560122680808*^9}, 3.560139572877*^9, 3.560217558316*^9, 
   3.560386133189*^9, 3.560386462793*^9, 3.560386753164*^9, 3.560388211432*^9}
  ],

Cell[BoxData["0.9972580911961049`"], "Output",
 CellChangeTimes->{
  3.5601221045690002`*^9, 3.560122617942*^9, {3.560122657848*^9, 
   3.560122680808*^9}, 3.560139572877*^9, 3.560217558316*^9, 
   3.560386133189*^9, 3.560386462793*^9, 3.560386753164*^9, 3.560388211433*^9}
  ]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
  "The", " ", "symbolic", " ", "expressions", " ", "for", " ", "the", " ", 
   "dominant", " ", "terms", " "}]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 StyleBox[".",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073492156*^9, 3.559073528608*^9}, {3.559073588304*^9, 
  3.559073617961*^9}, {3.559073712104*^9, 3.559073728276*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"mon5", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
   ",", " ", 
   RowBox[{"Max", "[", 
    RowBox[{
     RowBox[{"mon5", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
    "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"mon5", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
   ",", " ", 
   RowBox[{"Min", "[", 
    RowBox[{
     RowBox[{"mon5", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
    "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"mon6", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
   ",", " ", 
   RowBox[{"Max", "[", 
    RowBox[{
     RowBox[{"mon6", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
    "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"mon6", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
   ",", " ", 
   RowBox[{"Min", "[", 
    RowBox[{
     RowBox[{"mon6", "/.", "parameterClasses"}], "/.", "numericalValues"}], 
    "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5601227176610003`*^9, 3.560122765288*^9}, {
  3.5601229353190002`*^9, 3.560123036475*^9}, {3.560123308922*^9, 
  3.560123318822*^9}, {3.560134939961*^9, 3.56013494201*^9}, {
  3.560386265955*^9, 3.560386283618*^9}, {3.560386882184*^9, 
  3.5603868887869997`*^9}, {3.56038694205*^9, 3.560386948125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "37", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.560386931046*^9, 3.560386948592*^9}, 3.56038821148*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "35", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.560386931046*^9, 3.560386948592*^9}, 
   3.5603882114820004`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "32", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.560386931046*^9, 3.560386948592*^9}, 3.560388211483*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "34", "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.560386931046*^9, 3.560386948592*^9}, 3.560388211484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"mon5", "[", 
  RowBox[{"[", "37", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"mon5", "[", 
  RowBox[{"[", "35", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"mon6", "[", 
  RowBox[{"[", "32", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"mon6", "[", 
  RowBox[{"[", "34", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.560123340803*^9, 3.560123349642*^9}, {3.560386451133*^9,
   3.560386460865*^9}, {3.56038695324*^9, 3.5603869608529997`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["k", "cat"], " ", 
  SubsuperscriptBox["k", "off", "4"], " ", 
  SubsuperscriptBox["k", "on", "2"], " ", 
  SubscriptBox["\[Kappa]", "cat"], " ", 
  SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
  SubscriptBox["\[Kappa]", "on"]}]], "Output",
 CellChangeTimes->{3.560386133388*^9, 3.560386462973*^9, 3.560386753343*^9, 
  3.560386961336*^9, 3.5603882115220003`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["k", "cat"]}], " ", 
  SubsuperscriptBox["k", "off", "5"], " ", 
  SubscriptBox["k", "on"], " ", 
  SubscriptBox["\[Kappa]", "cat"], " ", 
  SubscriptBox["\[Kappa]", "off"], " ", 
  SubsuperscriptBox["\[Kappa]", "on", "2"]}]], "Output",
 CellChangeTimes->{3.560386133388*^9, 3.560386462973*^9, 3.560386753343*^9, 
  3.560386961336*^9, 3.560388211523*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["k", "off", "5"], " ", 
  SubscriptBox["k", "on"], " ", 
  SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
  SubscriptBox["\[Kappa]", "off"], " ", 
  SubsuperscriptBox["\[Kappa]", "on", "2"]}]], "Output",
 CellChangeTimes->{3.560386133388*^9, 3.560386462973*^9, 3.560386753343*^9, 
  3.560386961336*^9, 3.560388211524*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubsuperscriptBox["k", "off", "4"]}], " ", 
  SubsuperscriptBox["k", "on", "2"], " ", 
  SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
  SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
  SubscriptBox["\[Kappa]", "on"]}]], "Output",
 CellChangeTimes->{3.560386133388*^9, 3.560386462973*^9, 3.560386753343*^9, 
  3.560386961336*^9, 3.560388211526*^9}]
}, Open  ]],

Cell["\<\
These are the dominant monomials, as shown in Eq. (6)-(8) in the main paper. \
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073492156*^9, 3.559073528608*^9}, {3.559073588304*^9, 
  3.559073617961*^9}, {3.559073712104*^9, 3.559073728276*^9}, {
  3.560287548934*^9, 3.56028757048*^9}, {3.560386322727*^9, 
  3.5603863269309998`*^9}, {3.562470438328*^9, 3.562470443142*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["k", "cat"], " ", 
  SubsuperscriptBox["k", "off", "4"], " ", 
  SubsuperscriptBox["k", "on", "2"], " ", 
  SubscriptBox["\[Kappa]", "cat"], " ", 
  SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
  SubscriptBox["\[Kappa]", "on"]}]], "Output",
 CellChangeTimes->{
  3.5590737606809998`*^9, 3.55907530233*^9, 3.559076387224*^9, {
   3.5601230717939997`*^9, 3.560123081042*^9}, 3.560123350086*^9, 
   3.560134949355*^9, 3.560139573002*^9, 3.560217558448*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["k", "cat"]}], " ", 
  SubsuperscriptBox["k", "off", "5"], " ", 
  SubscriptBox["k", "on"], " ", 
  SubscriptBox["\[Kappa]", "cat"], " ", 
  SubscriptBox["\[Kappa]", "off"], " ", 
  SubsuperscriptBox["\[Kappa]", "on", "2"]}]], "Output",
 CellChangeTimes->{
  3.5590737606809998`*^9, 3.55907530233*^9, 3.559076387224*^9, {
   3.5601230717939997`*^9, 3.560123081042*^9}, 3.560123350086*^9, 
   3.560134949355*^9, 3.560139573002*^9, 3.560217558449*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["k", "off", "5"], " ", 
  SubscriptBox["k", "on"], " ", 
  SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
  SubscriptBox["\[Kappa]", "off"], " ", 
  SubsuperscriptBox["\[Kappa]", "on", "2"]}]], "Output",
 CellChangeTimes->{
  3.5590737606809998`*^9, 3.55907530233*^9, 3.559076387224*^9, {
   3.5601230717939997`*^9, 3.560123081042*^9}, 3.560123350086*^9, 
   3.560134949355*^9, 3.560139573002*^9, 3.560217558451*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubsuperscriptBox["k", "off", "4"]}], " ", 
  SubsuperscriptBox["k", "on", "2"], " ", 
  SubsuperscriptBox["\[Kappa]", "cat", "2"], " ", 
  SubsuperscriptBox["\[Kappa]", "off", "2"], " ", 
  SubscriptBox["\[Kappa]", "on"]}]], "Output",
 CellChangeTimes->{
  3.5590737606809998`*^9, 3.55907530233*^9, 3.559076387224*^9, {
   3.5601230717939997`*^9, 3.560123081042*^9}, 3.560123350086*^9, 
   3.560134949355*^9, 3.560139573002*^9, 3.5602175584519997`*^9}],

Cell[TextData[{
 "Excluding the min and max terms, there are no terms in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "5"], " ", "and", " ", 
   SubscriptBox["a", "6"]}]], "Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"],
 " outside of [-200, 200]. "
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073492156*^9, 3.559073528608*^9}, {3.559073588304*^9, 
  3.559073617961*^9}, {3.560123103168*^9, 3.560123152689*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Delete", "[", 
       RowBox[{"mon5", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "37", "}"}], ",", 
          RowBox[{"{", "35", "}"}]}], "}"}]}], "]"}], "]"}], "/", "norm"}], 
    ")"}], "/.", "parameterClasses"}], "/.", 
  "numericalValues"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"Delete", "[", 
       RowBox[{"mon5", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "37", "}"}], ",", 
          RowBox[{"{", "35", "}"}]}], "}"}]}], "]"}], "]"}], "/", "norm"}], 
    ")"}], "/.", "parameterClasses"}], "/.", 
  "numericalValues"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Delete", "[", 
       RowBox[{"mon6", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "32", "}"}], ",", 
          RowBox[{"{", "34", "}"}]}], "}"}]}], "]"}], "]"}], "/", "norm"}], 
    ")"}], "/.", "parameterClasses"}], "/.", 
  "numericalValues"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"Delete", "[", 
       RowBox[{"mon6", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "32", "}"}], ",", 
          RowBox[{"{", "34", "}"}]}], "}"}]}], "]"}], "]"}], "/", "norm"}], 
    ")"}], "/.", "parameterClasses"}], "/.", "numericalValues"}]}], "Input",
 CellChangeTimes->{{3.560123357726*^9, 3.560123370066*^9}, {3.560123464836*^9,
   3.5601235150690002`*^9}, {3.560386346413*^9, 3.560386353307*^9}, {
  3.560386969587*^9, 3.560386974957*^9}}],

Cell[BoxData["143.44813009910686`"], "Output",
 CellChangeTimes->{{3.5601233553269997`*^9, 3.5601233714370003`*^9}, {
   3.560123465738*^9, 3.560123515715*^9}, 3.560139573072*^9, 
   3.560217558513*^9, 3.560386133486*^9, 3.560386463068*^9, 3.560386753442*^9,
    3.560386975392*^9, 3.560388211567*^9}],

Cell[BoxData[
 RowBox[{"-", "124.35849432437956`"}]], "Output",
 CellChangeTimes->{{3.5601233553269997`*^9, 3.5601233714370003`*^9}, {
   3.560123465738*^9, 3.560123515715*^9}, 3.560139573072*^9, 
   3.560217558513*^9, 3.560386133486*^9, 3.560386463068*^9, 3.560386753442*^9,
    3.560386975392*^9, 3.560388211568*^9}],

Cell[BoxData["123.72401221047967`"], "Output",
 CellChangeTimes->{{3.5601233553269997`*^9, 3.5601233714370003`*^9}, {
   3.560123465738*^9, 3.560123515715*^9}, 3.560139573072*^9, 
   3.560217558513*^9, 3.560386133486*^9, 3.560386463068*^9, 3.560386753442*^9,
    3.560386975392*^9, 3.5603882115690002`*^9}],

Cell[BoxData[
 RowBox[{"-", "143.44813009910686`"}]], "Output",
 CellChangeTimes->{{3.5601233553269997`*^9, 3.5601233714370003`*^9}, {
   3.560123465738*^9, 3.560123515715*^9}, 3.560139573072*^9, 
   3.560217558513*^9, 3.560386133486*^9, 3.560386463068*^9, 3.560386753442*^9,
    3.560386975392*^9, 3.5603882115699997`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6) Sensitivity analysis", "Section",
 CellChangeTimes->{{3.411417440142596*^9, 3.411417461256724*^9}, {
  3.411442037532863*^9, 3.411442039375865*^9}, {3.411443676335696*^9, 
  3.411443677223529*^9}, {3.5590721755550003`*^9, 3.559072189133*^9}, {
  3.5600335436210003`*^9, 3.560033557981*^9}, {3.560124293295*^9, 
  3.560124301933*^9}}],

Cell[CellGroupData[{

Cell["\<\
Generation of random parameter values according to constraints \
\>", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}, {3.560135008124*^9, 3.560135025352*^9}}],

Cell["\<\
We first randomly generate 200,000 combinations of parameters. Each of the \
six parameters is picked independently from the interval [v/2, 2v], where v \
is the reference value. \
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073868091*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomParameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["k", "on"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.5", "*", "1", "*", 
           RowBox[{"10", "^", "8"}]}], ",", 
          RowBox[{"2", "*", "1", "*", 
           RowBox[{"10", "^", "8"}]}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["k", "off"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.5", "*", "23"}], ",", " ", 
          RowBox[{"2", "*", "23"}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["k", "cat"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.0098", "*", "0.5"}], ",", " ", 
          RowBox[{"2", "*", "0.0098"}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Kappa]", "on"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.5", "*", "1", "*", 
           RowBox[{"10", "^", "8"}]}], ",", 
          RowBox[{"2", "*", "1", "*", 
           RowBox[{"10", "^", "8"}]}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Kappa]", "off"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.5", "*", "40"}], ",", " ", 
          RowBox[{"2", "*", "40"}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Kappa]", "cat"], "\[Rule]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.0065", "*", "0.5"}], ",", " ", 
          RowBox[{"2", "*", "0.0065"}]}], "}"}], ",", " ", 
        RowBox[{"{", "200000", "}"}]}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.560124359943*^9, 3.560124407733*^9}}],

Cell["The kinase and phosphatase Michaelis-Menten constants.", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.560287605127*^9, 
  3.56028761388*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["K", "M"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["k", "off"], "+", 
      SubscriptBox["k", "cat"]}], ")"}], "/", 
    SubscriptBox["k", "on"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Kappa]", "M"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", "off"], "+", 
      SubscriptBox["\[Kappa]", "cat"]}], ")"}], "/", 
    SubscriptBox["\[Kappa]", "on"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5590741893570004`*^9, 3.5590742020030003`*^9}}],

Cell["\<\
Parameter combinations are excluded if they correspond to one of the \
Michaelis-Menten constants being outside of [0.8v, 1.2v], where v is the \
reference value. The following code generates the list of the parameter \
combinations that lead to unacceptable Michaelis-Menten values.  The \
reference Michaelis-Menten values are experimentally determined and given in \
Table 2 in the main paper.  \
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
  3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
  3.559075829142*^9, 3.559075834108*^9}, {3.559076143174*^9, 
  3.5590761536099997`*^9}, {3.560125653932*^9, 3.560125712928*^9}, {
  3.560134697304*^9, 3.5601346979960003`*^9}, {3.560287618882*^9, 
  3.5602876360299997`*^9}, {3.562470507594*^9, 3.56247050846*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["K", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"x_", "/;", 
      RowBox[{"x", ">", 
       RowBox[{"1.2", "*", "2.3", "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "7"}]}]}]}]}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["K", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"x_", "/;", 
      RowBox[{"x", "<", 
       RowBox[{"0.8", "*", "2.3", "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "7"}]}]}]}]}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex3", " ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"x_", "/;", 
      RowBox[{"x", ">", 
       RowBox[{"1.2", "*", "4", "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "7"}]}]}]}]}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ex4", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], "/.", 
    RowBox[{
     RowBox[{"x_", "/;", 
      RowBox[{"x", "<", 
       RowBox[{"0.8", "*", "4", "*", 
        RowBox[{"10", "^", 
         RowBox[{"-", "7"}]}]}]}]}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos1", "=", 
   RowBox[{"Position", "[", 
    RowBox[{"ex1", ",", " ", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos2", "=", 
   RowBox[{"Position", "[", 
    RowBox[{"ex2", ",", " ", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos3", " ", "=", " ", 
   RowBox[{"Position", "[", 
    RowBox[{"ex3", ",", " ", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos4", " ", "=", " ", 
   RowBox[{"Position", "[", 
    RowBox[{"ex4", ",", " ", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"combined", " ", "=", " ", 
   RowBox[{"Union", "[", 
    RowBox[{"pos1", ",", " ", "pos2", ",", " ", "pos3", ",", " ", "pos4"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.560125570222*^9, 3.560125623892*^9}}],

Cell["\<\
Removing those leaves around 18,000 acceptable combinations.  \
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
  3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
  3.559074405663*^9, 3.5590744387720003`*^9}, {3.5601257170039997`*^9, 
  3.560125729599*^9}, {3.560134701026*^9, 3.5601347047209997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"200000", "-", 
   RowBox[{"Length", "[", "combined", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559074334498*^9, 3.559074343858*^9}}],

Cell[BoxData["18064"], "Output",
 CellChangeTimes->{
  3.559074344406*^9, 3.559075308835*^9, 3.5590763938599997`*^9, 
   3.560125661429*^9, 3.560125732258*^9, 3.5601395775699997`*^9, 
   3.560217564425*^9, {3.560287869418*^9, 3.56028787121*^9}, 
   3.560386138021*^9, 3.560386469292*^9, 3.560386758389*^9, 3.560387017704*^9,
    3.5603882157530003`*^9}]
}, Open  ]],

Cell["\<\
We check that the Michaelis-Menten constants for the remaining combinations \
are indeed restricted to [0.8v, 1.2v].\
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
  3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
  3.559074405663*^9, 3.5590744387720003`*^9}, {3.5601257170039997`*^9, 
  3.5601257575480003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Max", "[", 
  RowBox[{"Delete", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["K", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], ",", "combined"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Delete", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["K", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], ",", "combined"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Max", "[", 
  RowBox[{"Delete", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], ",", "combined"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Delete", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Kappa]", "M"], "/.", "parameterClasses"}], "/.", 
      "randomParameters"}], ")"}], ",", "combined"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.560126287486*^9, 3.560126307101*^9}}],

Cell[BoxData["2.7599949415791876`*^-7"], "Output",
 CellChangeTimes->{3.559074441926*^9, 3.5590753088719997`*^9, 
  3.559076393907*^9, 3.5601257433710003`*^9, 3.560126307995*^9, 
  3.5601395776540003`*^9, 3.560217564499*^9, 3.560287874064*^9, 
  3.560386138076*^9, 3.560386469365*^9, 3.560386758525*^9, 3.560387019847*^9, 
  3.560388215809*^9}],

Cell[BoxData["1.8400491218422438`*^-7"], "Output",
 CellChangeTimes->{3.559074441926*^9, 3.5590753088719997`*^9, 
  3.559076393907*^9, 3.5601257433710003`*^9, 3.560126307995*^9, 
  3.5601395776540003`*^9, 3.560217564499*^9, 3.560287874064*^9, 
  3.560386138076*^9, 3.560386469365*^9, 3.560386758525*^9, 3.560387019847*^9, 
  3.56038821583*^9}],

Cell[BoxData["4.799992301458266`*^-7"], "Output",
 CellChangeTimes->{3.559074441926*^9, 3.5590753088719997`*^9, 
  3.559076393907*^9, 3.5601257433710003`*^9, 3.560126307995*^9, 
  3.5601395776540003`*^9, 3.560217564499*^9, 3.560287874064*^9, 
  3.560386138076*^9, 3.560386469365*^9, 3.560386758525*^9, 3.560387019847*^9, 
  3.5603882158529997`*^9}],

Cell[BoxData["3.2000974171215283`*^-7"], "Output",
 CellChangeTimes->{3.559074441926*^9, 3.5590753088719997`*^9, 
  3.559076393907*^9, 3.5601257433710003`*^9, 3.560126307995*^9, 
  3.5601395776540003`*^9, 3.560217564499*^9, 3.560287874064*^9, 
  3.560386138076*^9, 3.560386469365*^9, 3.560386758525*^9, 3.560387019847*^9, 
  3.560388215885*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
One positive solution to the invariant is obtained for all parameter \
combinations \
\>", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}, {3.560135039226*^9, 3.560135046961*^9}, {
  3.5602876494189997`*^9, 3.5602876576470003`*^9}}],

Cell[TextData[{
 "sol1mod and sol2mod are matrices with five columns; each column contains \
the solutions for all parameter combinations at one of the ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 " values. Column 1: (",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 ") = (0.3, 17.5), Column 2: (",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 ") = (0.1, 5), Column 3: (",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 ") = (0.1, 30), Column 4: (",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 ") = (0.5, 5), Column 5: (",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 ") = (0.5, 30).  "
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
  3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
  3.559074405663*^9, 3.5590744387720003`*^9}, {3.559074499159*^9, 
  3.5590746037799997`*^9}, {3.559076176317*^9, 3.559076192896*^9}, {
  3.5601265400889997`*^9, 3.560126559927*^9}, {3.560128345285*^9, 
  3.560128353376*^9}, {3.5601318796210003`*^9, 3.5601319755550003`*^9}, {
  3.560132008383*^9, 3.5601321833640003`*^9}, {3.560132360384*^9, 
  3.560132361679*^9}, {3.5601323943269997`*^9, 3.560132418381*^9}, {
  3.560386483755*^9, 3.560386486142*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xGrid", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "3"], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "0.3", ",", " ", "0.1", ",", "0.1", ",", " ", "0.5", ",", "0.5"}], 
       "}"}]}], ",", 
     RowBox[{
      SubscriptBox["x", "10"], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"17.5", ",", " ", "5", ",", "30", ",", "5", ",", " ", "30"}], 
       "}"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.560126643259*^9, 3.560126672862*^9}, {
  3.5601267932530003`*^9, 3.560126804396*^9}, {3.560127734586*^9, 
  3.560127766791*^9}, {3.560128628837*^9, 3.560128664701*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol1mod", "=", 
   RowBox[{"Delete", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"sol1", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
        "randomParameters"}], "/.", "xGrid"}], ",", " ", "combined"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol2mod", "=", 
   RowBox[{"Delete", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"sol2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
        "randomParameters"}], "/.", "xGrid"}], ",", " ", "combined"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.560126398159*^9, 3.560126419755*^9}, 
   3.560126451763*^9, {3.560128670106*^9, 3.5601286797720003`*^9}}],

Cell[TextData[{
 "For all parameter combinations, only one positive ",
 Cell[BoxData[
  SubscriptBox["x", "2"]], "Input"],
 " solution is obtained ",
 "at the various ",
 Cell[BoxData[
  SubscriptBox["x", "3"]], "Input"],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "10"]], "Input"],
 " values",
 ". "
}], "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
  3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
  3.559074405663*^9, 3.5590744387720003`*^9}, {3.559074499159*^9, 
  3.5590746037799997`*^9}, {3.559076176317*^9, 3.559076192896*^9}, {
  3.5601265400889997`*^9, 3.560126559927*^9}, {3.560128345285*^9, 
  3.560128353376*^9}, {3.5601318796210003`*^9, 3.5601319755550003`*^9}, {
  3.560132008383*^9, 3.5601321833640003`*^9}, {3.560132360384*^9, 
  3.560132361679*^9}, {3.5601323943269997`*^9, 3.5601324284189997`*^9}, {
  3.560142490484*^9, 3.560142494244*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"count1", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol1mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count2", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol2mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count3", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol1mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count4", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol2mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count5", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol1mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count6", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol2mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count7", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol1mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count8", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol2mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count9", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol1mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count10", "=", 
   RowBox[{"BinCounts", "[", 
    RowBox[{
     RowBox[{"sol2mod", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "Infinity"}], "}"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"negsol", "=", 
   RowBox[{"List", "[", 
    RowBox[{
    "count1", ",", "count3", ",", "count5", ",", "count7", ",", "count9"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"possol", "=", 
   RowBox[{"List", "[", 
    RowBox[{
    "count2", ",", "count4", ",", "count6", ",", "count8", ",", "count10"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5601288114820004`*^9, 3.560128814186*^9}, 
   3.560131571601*^9, {3.560131705098*^9, 3.560131718604*^9}, {
   3.5601324387980003`*^9, 3.560132449542*^9}, {3.5602880295*^9, 
   3.560288065759*^9}, {3.560291916284*^9, 3.560291974574*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "3"], ",", "0.3", ",", "0.1", ",", "0.1", ",", "0.5",
        ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "10"], ",", "17.5", ",", "5", ",", "30", ",", "5", 
       ",", "30"}], "}"}], ",", 
     RowBox[{"Prepend", "[", 
      RowBox[{"negsol", ",", "\"\<positive sol1\>\""}], "]"}], ",", 
     RowBox[{"Prepend", "[", 
      RowBox[{"possol", ",", "\"\<positive sol2\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56028808025*^9, 3.5602880953529997`*^9}, {
  3.56029198215*^9, 3.560292037132*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     SubscriptBox["x", "3"], "0.3`", "0.1`", "0.1`", "0.5`", "0.5`"},
    {
     SubscriptBox["x", "10"], "17.5`", "5", "30", "5", "30"},
    {"\<\"positive sol1\"\>", 
     RowBox[{"{", "0", "}"}], 
     RowBox[{"{", "0", "}"}], 
     RowBox[{"{", "0", "}"}], 
     RowBox[{"{", "0", "}"}], 
     RowBox[{"{", "0", "}"}]},
    {"\<\"positive sol2\"\>", 
     RowBox[{"{", "18064", "}"}], 
     RowBox[{"{", "18064", "}"}], 
     RowBox[{"{", "18064", "}"}], 
     RowBox[{"{", "18064", "}"}], 
     RowBox[{"{", "18064", "}"}]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{"Text"}}, "Rows" -> {{"Text"}}},
   GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.560291998659*^9, 3.5602920375290003`*^9}, 
   3.560386182834*^9, 3.560386809519*^9, {3.560387139558*^9, 
   3.5603871448059998`*^9}, 3.560388260276*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Partial derivative values indicate parameter-independent robustness\
\>", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559072217801*^9, 3.5590722438*^9}, {3.55907239795*^9, 
  3.559072434646*^9}, {3.559072540666*^9, 3.559072590032*^9}, {
  3.559072718309*^9, 3.559072722494*^9}, {3.559072872902*^9, 
  3.559072884414*^9}, {3.559073041429*^9, 3.559073115262*^9}, {
  3.5590731690950003`*^9, 3.559073235059*^9}, {3.560134900359*^9, 
  3.560134905442*^9}, {3.560135056528*^9, 3.5601350711619997`*^9}}],

Cell["\<\
Additionally, the mean partial derivative values are on the order of 10^-4, \
confirming that robustness is maintained.  (d2, the partial derivative of the \
positive solution to the invariant, is defined earlier in the notebook.)\
\>", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
   3.559073810475*^9, 3.559073944495*^9}, {3.559074207134*^9, 
   3.559074274576*^9}, {3.55907434949*^9, 3.559074362959*^9}, {
   3.559074405663*^9, 3.5590744387720003`*^9}, {3.559074499159*^9, 
   3.5590746037799997`*^9}, {3.559076176317*^9, 3.559076192896*^9}, {
   3.5601265748780003`*^9, 3.560126628514*^9}, {3.560134575605*^9, 
   3.5601345780179996`*^9}, 3.562470533085*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"Mean", "[", 
    RowBox[{"Delete", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"d2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "randomParameters"}], "/.", "xGrid"}], ",", " ", "combined"}], "]"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s", "=", 
   RowBox[{"StandardDeviation", "[", 
    RowBox[{"Delete", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"d2", "/.", "coefficients"}], "/.", "parameterClasses"}], "/.",
         "randomParameters"}], "/.", "xGrid"}], ",", " ", "combined"}], "]"}],
     "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.560126509224*^9, 3.5601265119119997`*^9}, {
  3.560132503498*^9, 3.560132512403*^9}, {3.560132662453*^9, 
  3.560132664234*^9}, {3.560134464576*^9, 3.5601344676210003`*^9}, {
  3.560217199514*^9, 3.5602172137799997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "3"], ",", "0.3", ",", "0.1", ",", "0.1", ",", 
        "0.5", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["x", "10"], ",", "17.5", ",", "5", ",", "30", ",", "5", 
        ",", "30"}], "}"}], ",", 
      RowBox[{"Prepend", "[", 
       RowBox[{"m", ",", "\"\<mean\>\""}], "]"}], ",", 
      RowBox[{"Prepend", "[", 
       RowBox[{"s", ",", "\"\<SD\>\""}], "]"}]}], "}"}], ",", 
    RowBox[{"Alignment", "\[Rule]", "Left"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "All"}], ",", 
    RowBox[{"ItemStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.560134121013*^9, 3.560134140656*^9}, {3.560134213936*^9,
   3.560134286097*^9}, {3.560134363604*^9, 3.560134436691*^9}, {
  3.5602878414049997`*^9, 3.560287842487*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     SubscriptBox["x", "3"], "0.3`", "0.1`", "0.1`", "0.5`", "0.5`"},
    {
     SubscriptBox["x", "10"], "17.5`", "5", "30", "5", "30"},
    {"\<\"mean\"\>", 
     RowBox[{"-", "0.00014806527437445102`"}], 
     RowBox[{"-", "0.000148199834749969`"}], 
     RowBox[{"-", "0.00014770674290670094`"}], 
     RowBox[{"-", "0.00016037746441778343`"}], 
     RowBox[{"-", "0.00014804486143449736`"}]},
    {"\<\"SD\"\>", "0.00013839039460183277`", "0.00013844540719118215`", 
     "0.000138243881664959`", "0.00014348124701651184`", 
     "0.00013838205007955353`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{"Text"}}, "Rows" -> {{"Text"}}},
   GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.560134136908*^9, 3.560134141314*^9}, {3.560134216723*^9,
    3.560134232093*^9}, 3.560134286676*^9, {3.560134395407*^9, 
   3.560134437109*^9}, 3.5601396818129997`*^9, 3.560217691618*^9, 
   3.560386243592*^9, 3.5603868768859997`*^9, 3.560388322326*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7) Analysis of hypothetical model of IDH regulation ", "Section",
 CellChangeTimes->{{3.411417469959569*^9, 3.411417491269539*^9}, {
  3.411417963441329*^9, 3.411417968627964*^9}, {3.411442677258025*^9, 
  3.411442705282421*^9}, {3.411443492099749*^9, 3.411443502898328*^9}, {
  3.411443662386891*^9, 3.411443663565987*^9}, {3.559074823791*^9, 
  3.5590748304890003`*^9}, {3.560134491317*^9, 3.560134491501*^9}}],

Cell[CellGroupData[{

Cell["\<\
Groebner basis calculation for network with monomeric IDH and bifunctional \
IDHKP\
\>", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559074838315*^9, 3.5590748618059998`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["f", "1"], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Io"}], " ", "R", " ", 
     SubscriptBox["k", "1"]}], "+", 
    RowBox[{"RIo", " ", 
     SubscriptBox["k", "2"]}], "+", 
    RowBox[{"RIp", " ", 
     SubscriptBox["k", "6"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"RIo", " ", 
     SubscriptBox["k", "3"]}], "-", 
    RowBox[{"Ip", " ", "R", " ", 
     SubscriptBox["k", "4"]}], "+", 
    RowBox[{"RIp", " ", 
     SubscriptBox["k", "5"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", "3"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Io"}], " ", "R", " ", 
     SubscriptBox["k", "1"]}], "+", 
    RowBox[{"RIo", " ", 
     SubscriptBox["k", "2"]}], "+", 
    RowBox[{"RIo", " ", 
     SubscriptBox["k", "3"]}], "-", 
    RowBox[{"Ip", " ", "R", " ", 
     SubscriptBox["k", "4"]}], "+", 
    RowBox[{"RIp", " ", 
     SubscriptBox["k", "6"]}], "+", 
    RowBox[{"RIp", " ", 
     SubscriptBox["k", "5"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"4", " "}]], "=", " ", 
   RowBox[{
    RowBox[{"Io", " ", "R", " ", 
     SubscriptBox["k", "1"]}], "-", 
    RowBox[{"RIo", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "2"], "+", 
       SubscriptBox["k", "3"]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"5", " "}]], "=", " ", 
   RowBox[{
    RowBox[{"Ip", " ", "R", " ", 
     SubscriptBox["k", "4"]}], "-", 
    RowBox[{"RIp", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["k", "6"], "+", 
       SubscriptBox["k", "5"]}], ")"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.551835466554*^9, 3.551835543039*^9}, {3.559074881498*^9,
   3.559074886373*^9}, {3.559074992263*^9, 3.559074993457*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "R", ",", " ", "Io", ",", " ", "Ip", ",", " ", "RIo", ",", " ", "RIp"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"basis", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["f", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grbasis", "=", 
   RowBox[{"GroebnerBasis", "[", 
    RowBox[{"basis", ",", "vars", ",", 
     RowBox[{"MonomialOrder", " ", "\[Rule]", " ", "Lexicographic"}], ",", 
     " ", 
     RowBox[{
     "CoefficientDomain", " ", "\[Rule]", " ", "RationalFunctions"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gr", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Part", "[", 
    RowBox[{"grbasis", ",", "i"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.559074892804*^9, 3.5590748994440002`*^9}, {
  3.559074995554*^9, 3.559074996734*^9}}],

Cell["The Groebner basis has four terms.", "Text",
 CellChangeTimes->{{3.411442203069927*^9, 3.411442241353292*^9}, {
  3.559075031704*^9, 3.55907503823*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "grbasis", "]"}]], "Input"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.559075040099*^9, 3.559075312352*^9, 3.559076397462*^9, 
  3.5601346074119997`*^9, 3.560139681889*^9, 3.560217691711*^9, 
  3.560386243815*^9, 3.5603868769849997`*^9, 3.560388322359*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The robust ratio can be derived from Groebner basis terms 3 and 4\
\>", "Subsection",
 CellChangeTimes->{{3.411442568514907*^9, 3.411442596659302*^9}, {
  3.559074838315*^9, 3.5590748618059998`*^9}, {3.559075090178*^9, 
  3.559075100918*^9}, {3.5590762230299997`*^9, 3.559076226329*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gr", "[", "3", "]"}], "\[Equal]", "0"}], ",", " ", "RIp"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5508550482508*^9, 3.5508550527938004`*^9}, {
  3.5508551476228*^9, 3.5508551576588*^9}, {3.551836620289*^9, 
  3.551836620461*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"RIp", "\[Rule]", 
    FractionBox[
     RowBox[{"Ip", " ", "R", " ", 
      SubscriptBox["k", "4"]}], 
     RowBox[{
      SubscriptBox["k", "5"], "+", 
      SubscriptBox["k", "6"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5508551587228003`*^9, 3.551835792962*^9, 
  3.551836633764*^9, 3.559066140883*^9, 3.559066647139*^9, 3.559066858483*^9, 
  3.5590751172980003`*^9, 3.559075312376*^9, 3.559076397507*^9, 
  3.5601346091809998`*^9, 3.56013968194*^9, 3.5602176917860003`*^9, 
  3.5603862438450003`*^9, 3.5603868770480003`*^9, 3.560388322381*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gr", "[", "4", "]"}], "\[Equal]", "0"}], ",", " ", "RIp"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5508551618028*^9, 3.5508551735657997`*^9}, {
  3.551836636724*^9, 3.5518366369519997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"RIp", "\[Rule]", 
    FractionBox[
     RowBox[{"Io", " ", "R", " ", 
      SubscriptBox["k", "1"], " ", 
      SubscriptBox["k", "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "2"], "+", 
        SubscriptBox["k", "3"]}], ")"}], " ", 
      SubscriptBox["k", "6"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5508551748157997`*^9, 3.5518357954519997`*^9, 
  3.55183663915*^9, 3.5590661410039997`*^9, 3.559066647164*^9, 
  3.559066858505*^9, 3.5590751196549997`*^9, 3.559075312402*^9, 
  3.559076397558*^9, 3.560134612847*^9, 3.5601396819890003`*^9, 
  3.56021769185*^9, 3.560386243874*^9, 3.5603868780880003`*^9, 
  3.5603883224049997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"RIp", "/.", "t1"}], ")"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{"RIp", "/.", "t2"}], ")"}]}], ",", " ", "Io"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5508551841638002`*^9, 3.5508551909858*^9}, {
  3.5508555559888*^9, 3.5508555961218*^9}, {3.5518366593310003`*^9, 
  3.5518366621800003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"Io", "\[Rule]", 
    FractionBox[
     RowBox[{"Ip", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "2"], "+", 
        SubscriptBox["k", "3"]}], ")"}], " ", 
      SubscriptBox["k", "4"], " ", 
      SubscriptBox["k", "6"]}], 
     RowBox[{
      SubscriptBox["k", "1"], " ", 
      SubscriptBox["k", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", "5"], "+", 
        SubscriptBox["k", "6"]}], ")"}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.5508555716588*^9, 3.5508555965828*^9}, 
   3.5518357985880003`*^9, {3.551836644432*^9, 3.5518366625810003`*^9}, 
   3.5590661413190002`*^9, 3.559066647271*^9, 3.559066858613*^9, 
   3.559075121402*^9, 3.559075312457*^9, 3.559076397631*^9, 
   3.5601346145889997`*^9, 3.5601396820620003`*^9, 3.560217691955*^9, 
   3.560386243929*^9, 3.56038688005*^9, 3.560388322459*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1008, 647},
WindowMargins->{{Automatic, 139}, {Automatic, 0}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 764, 21, 153, "Subtitle"],
Cell[1346, 45, 1487, 29, 111, "Text"],
Cell[2836, 76, 1211, 20, 280, "Output"],
Cell[4050, 98, 1077, 25, 53, "Text"],
Cell[CellGroupData[{
Cell[5152, 127, 162, 2, 80, "Section"],
Cell[5317, 131, 960, 20, 47, "Text"],
Cell[6280, 153, 191, 3, 32, "Input"],
Cell[6474, 158, 567, 8, 32, "Input"],
Cell[CellGroupData[{
Cell[7066, 170, 205, 3, 44, "Subsection"],
Cell[7274, 175, 818, 15, 51, "Text"],
Cell[CellGroupData[{
Cell[8117, 194, 1974, 55, 99, "Input"],
Cell[CellGroupData[{
Cell[10116, 253, 468, 10, 23, "Print"],
Cell[10587, 265, 11177, 266, 165, "Print"]
}, Open  ]],
Cell[21779, 534, 8985, 177, 447, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30825, 718, 311, 6, 80, "Section"],
Cell[CellGroupData[{
Cell[31161, 728, 190, 3, 44, "Subsection"],
Cell[31354, 733, 384, 7, 49, "Text"],
Cell[31741, 742, 2290, 66, 77, "Input"],
Cell[34034, 810, 969, 28, 55, "Input"],
Cell[35006, 840, 493, 13, 32, "Text"],
Cell[35502, 855, 367, 10, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35906, 870, 224, 5, 69, "Subsection"],
Cell[36133, 877, 6842, 239, 253, "Input"],
Cell[42978, 1118, 1443, 40, 121, "Input"],
Cell[44424, 1160, 388, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[44837, 1169, 65, 1, 32, "Input"],
Cell[44905, 1172, 240, 3, 32, "Output"]
}, Open  ]],
Cell[45160, 1178, 1016, 19, 32, "Text"],
Cell[CellGroupData[{
Cell[46201, 1201, 1692, 47, 209, "Input"],
Cell[47896, 1250, 589, 12, 32, "Output"],
Cell[48488, 1264, 584, 12, 32, "Output"],
Cell[49075, 1278, 584, 12, 32, "Output"],
Cell[49662, 1292, 617, 13, 32, "Output"],
Cell[50282, 1307, 617, 13, 32, "Output"],
Cell[50902, 1322, 622, 13, 32, "Output"],
Cell[51527, 1337, 617, 13, 32, "Output"],
Cell[52147, 1352, 617, 13, 32, "Output"],
Cell[52767, 1367, 617, 13, 32, "Output"]
}, Open  ]],
Cell[53399, 1383, 1299, 29, 51, "Text"],
Cell[CellGroupData[{
Cell[54723, 1416, 610, 14, 77, "Input"],
Cell[55336, 1432, 33770, 920, 673, "Output"],
Cell[89109, 2354, 14288, 400, 314, "Output"],
Cell[103400, 2756, 16763, 469, 338, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120212, 3231, 828, 15, 44, "Subsection"],
Cell[CellGroupData[{
Cell[121065, 3250, 141, 4, 32, "Input"],
Cell[121209, 3256, 25569, 702, 459, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146827, 3964, 178, 2, 44, "Subsection"],
Cell[147008, 3968, 2014, 49, 53, "Text"],
Cell[149025, 4019, 501, 11, 32, "Input"],
Cell[149529, 4032, 278, 7, 32, "Input"],
Cell[149810, 4041, 1543, 48, 143, "Input"],
Cell[CellGroupData[{
Cell[151378, 4093, 1670, 33, 143, "Input"],
Cell[153051, 4128, 54855, 1417, 1132, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[207955, 5551, 277, 3, 44, "Subsection"],
Cell[208235, 5556, 356, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[208616, 5567, 1079, 28, 143, "Input"],
Cell[209698, 5597, 359, 6, 32, "Output"],
Cell[210060, 5605, 7348, 200, 185, "Output"],
Cell[217411, 5807, 6488, 179, 159, "Output"],
Cell[223902, 5988, 8626, 231, 209, "Output"],
Cell[232531, 6221, 9629, 253, 228, "Output"],
Cell[242163, 6476, 8337, 225, 202, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250549, 6707, 304, 4, 44, "Subsection"],
Cell[250856, 6713, 394, 7, 30, "Text"],
Cell[251253, 6722, 1717, 41, 165, "Input"],
Cell[CellGroupData[{
Cell[252995, 6767, 1008, 23, 55, "Input"],
Cell[254006, 6792, 1040, 20, 71, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[255107, 6819, 354, 6, 115, "Section"],
Cell[CellGroupData[{
Cell[255486, 6829, 228, 7, 44, "Subsection"],
Cell[255717, 6838, 473, 10, 51, "Text"],
Cell[256193, 6850, 722, 19, 34, "Input"],
Cell[CellGroupData[{
Cell[256940, 6873, 1468, 39, 121, "Input"],
Cell[258411, 6914, 1618, 24, 32, "Output"],
Cell[260032, 6940, 1602, 23, 32, "Output"]
}, Open  ]],
Cell[261649, 6966, 368, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[262042, 6975, 133, 2, 32, "Input"],
Cell[262178, 6979, 1049, 32, 65, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[263276, 7017, 1613, 37, 44, "Subsection"],
Cell[CellGroupData[{
Cell[264914, 7058, 832, 23, 77, "Input"],
Cell[265749, 7083, 112751, 1844, 285, 93230, 1523, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[378549, 8933, 358, 11, 44, "Subsection"],
Cell[378910, 8946, 459, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[379394, 8958, 289, 7, 32, "Input"],
Cell[379686, 8967, 1446, 45, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[381181, 9018, 1626, 35, 44, "Subsection"],
Cell[382810, 9055, 407, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[383242, 9064, 1003, 27, 77, "Input"],
Cell[384248, 9093, 98969, 1621, 278, 83151, 1361, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[483278, 10721, 395, 7, 115, "Section"],
Cell[CellGroupData[{
Cell[483698, 10732, 517, 15, 44, "Subsection"],
Cell[484218, 10749, 755, 15, 32, "Text"],
Cell[484976, 10766, 753, 23, 77, "Input"],
Cell[485732, 10791, 770, 18, 32, "Text"],
Cell[CellGroupData[{
Cell[486527, 10813, 773, 20, 55, "Input"],
Cell[487303, 10835, 1753, 47, 121, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489105, 10888, 1145, 26, 44, "Subsection"],
Cell[490253, 10916, 227, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[490505, 10926, 947, 24, 55, "Input"],
Cell[491455, 10952, 4969, 89, 255, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[496473, 11047, 1711, 40, 44, "Subsection"],
Cell[498187, 11089, 904, 21, 32, "Input"],
Cell[CellGroupData[{
Cell[499116, 11114, 899, 23, 55, "Input"],
Cell[500018, 11139, 4043, 75, 257, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[504122, 11221, 353, 5, 80, "Section"],
Cell[CellGroupData[{
Cell[504500, 11230, 513, 7, 44, "Subsection"],
Cell[505016, 11239, 434, 13, 32, "Text"],
Cell[CellGroupData[{
Cell[505475, 11256, 1525, 44, 121, "Input"],
Cell[507003, 11302, 4766, 118, 108, "Output"],
Cell[511772, 11422, 5888, 148, 154, "Output"],
Cell[517663, 11572, 8662, 218, 200, "Output"],
Cell[526328, 11792, 11653, 291, 269, "Output"],
Cell[537984, 12085, 9939, 250, 223, "Output"]
}, Open  ]],
Cell[547938, 12338, 264, 5, 30, "Text"],
Cell[548205, 12345, 3127, 104, 275, "Input"],
Cell[CellGroupData[{
Cell[551357, 12453, 1068, 24, 55, "Input"],
Cell[552428, 12479, 1206, 24, 97, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[553683, 12509, 728, 18, 44, "Subsection"],
Cell[554414, 12529, 591, 14, 31, "Text"],
Cell[CellGroupData[{
Cell[555030, 12547, 777, 20, 99, "Input"],
Cell[555810, 12569, 277, 5, 32, "Output"],
Cell[556090, 12576, 299, 6, 32, "Output"],
Cell[556392, 12584, 277, 5, 32, "Output"],
Cell[556672, 12591, 277, 5, 32, "Output"]
}, Open  ]],
Cell[556964, 12599, 472, 12, 31, "Text"],
Cell[CellGroupData[{
Cell[557461, 12615, 1518, 41, 187, "Input"],
Cell[558982, 12658, 152, 3, 32, "Output"],
Cell[559137, 12663, 162, 4, 32, "Output"],
Cell[559302, 12669, 153, 3, 32, "Output"],
Cell[559458, 12674, 153, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[559648, 12682, 476, 10, 99, "Input"],
Cell[560127, 12694, 406, 9, 34, "Output"],
Cell[560536, 12705, 410, 10, 34, "Output"],
Cell[560949, 12717, 367, 8, 34, "Output"],
Cell[561319, 12727, 396, 9, 34, "Output"]
}, Open  ]],
Cell[561730, 12739, 423, 7, 30, "Text"],
Cell[562156, 12748, 496, 11, 34, "Output"],
Cell[562655, 12761, 505, 12, 34, "Output"],
Cell[563163, 12775, 462, 10, 34, "Output"],
Cell[563628, 12787, 496, 11, 34, "Output"],
Cell[564127, 12800, 475, 12, 32, "Text"],
Cell[CellGroupData[{
Cell[564627, 12816, 1761, 54, 99, "Input"],
Cell[566391, 12872, 301, 4, 32, "Output"],
Cell[566695, 12878, 318, 5, 32, "Output"],
Cell[567016, 12885, 306, 4, 32, "Output"],
Cell[567325, 12891, 323, 5, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[567709, 12903, 342, 5, 80, "Section"],
Cell[CellGroupData[{
Cell[568076, 12912, 539, 9, 44, "Subsection"],
Cell[568618, 12923, 312, 6, 49, "Text"],
Cell[568933, 12931, 2327, 63, 143, "Input"],
Cell[571263, 12996, 221, 3, 30, "Text"],
Cell[571487, 13001, 593, 19, 55, "Input"],
Cell[572083, 13022, 879, 14, 87, "Text"],
Cell[572965, 13038, 2547, 82, 209, "Input"],
Cell[575515, 13122, 418, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[575958, 13133, 190, 4, 32, "Input"],
Cell[576151, 13139, 353, 6, 32, "Output"]
}, Open  ]],
Cell[576519, 13148, 432, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[576976, 13160, 1144, 36, 99, "Input"],
Cell[578123, 13198, 344, 5, 34, "Output"],
Cell[578470, 13205, 343, 5, 34, "Output"],
Cell[578816, 13212, 348, 5, 34, "Output"],
Cell[579167, 13219, 344, 5, 34, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[579560, 13230, 613, 11, 44, "Subsection"],
Cell[580176, 13243, 1657, 49, 72, "Text"],
Cell[581836, 13294, 667, 18, 32, "Input"],
Cell[582506, 13314, 769, 22, 55, "Input"],
Cell[583278, 13338, 966, 23, 32, "Text"],
Cell[584247, 13363, 3977, 126, 275, "Input"],
Cell[CellGroupData[{
Cell[588249, 13493, 949, 24, 77, "Input"],
Cell[589201, 13519, 1104, 28, 126, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[590354, 13553, 548, 9, 44, "Subsection"],
Cell[590905, 13564, 702, 11, 49, "Text"],
Cell[591610, 13577, 960, 26, 77, "Input"],
Cell[CellGroupData[{
Cell[592595, 13607, 1044, 26, 77, "Input"],
Cell[593642, 13635, 1238, 26, 122, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[594941, 13668, 418, 5, 80, "Section"],
Cell[CellGroupData[{
Cell[595384, 13677, 226, 5, 44, "Subsection"],
Cell[595613, 13684, 1946, 64, 121, "Input"],
Cell[597562, 13750, 1064, 30, 121, "Input"],
Cell[598629, 13782, 158, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[598812, 13788, 65, 1, 32, "Input"],
Cell[598880, 13791, 235, 3, 32, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[599164, 13800, 297, 5, 44, "Subsection"],
Cell[CellGroupData[{
Cell[599486, 13809, 335, 9, 32, "Input"],
Cell[599824, 13820, 615, 14, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600476, 13839, 295, 8, 32, "Input"],
Cell[600774, 13849, 743, 19, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601554, 13873, 440, 12, 32, "Input"],
Cell[601997, 13887, 929, 24, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
